@@ -68,6 +68,7 @@ ArchaeoLines::ArchaeoLines()
 	: flagShowArchaeoLines(false)
 	//, withDecimalDegree(false)
 	//, flagUseDmsFormat(false)
+	, lineWidth(1)
 	, flagShowEquinox(false)
 	, flagShowSolstices(false)
 	, flagShowCrossquarters(false)
@@ -248,39 +249,6 @@ void ArchaeoLines::init()
 	connect(this, SIGNAL(customDeclination1ColorChanged(Vec3f)),     customDeclination1Line      , SLOT(setColor(Vec3f)));
 	connect(this, SIGNAL(customDeclination2ColorChanged(Vec3f)),     customDeclination2Line      , SLOT(setColor(Vec3f)));
 
-	StelApp& app=StelApp::getInstance();
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), equinoxLine                 , SLOT(setFontSizeFromApp(const int)));
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), northernSolsticeLine        , SLOT(setFontSizeFromApp(const int)));
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), southernSolsticeLine        , SLOT(setFontSizeFromApp(const int)));
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), northernCrossquarterLine    , SLOT(setFontSizeFromApp(const int)));
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), southernCrossquarterLine    , SLOT(setFontSizeFromApp(const int)));
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), northernMajorStandstillLine0, SLOT(setFontSizeFromApp(const int)));
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), northernMajorStandstillLine1, SLOT(setFontSizeFromApp(const int)));
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), southernMajorStandstillLine6, SLOT(setFontSizeFromApp(const int)));
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), southernMajorStandstillLine7, SLOT(setFontSizeFromApp(const int)));
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), northernMinorStandstillLine2, SLOT(setFontSizeFromApp(const int)));
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), northernMinorStandstillLine3, SLOT(setFontSizeFromApp(const int)));
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), southernMinorStandstillLine4, SLOT(setFontSizeFromApp(const int)));
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), southernMinorStandstillLine5, SLOT(setFontSizeFromApp(const int)));
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), zenithPassageLine           , SLOT(setFontSizeFromApp(const int)));
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), nadirPassageLine            , SLOT(setFontSizeFromApp(const int)));
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), selectedObjectLine          , SLOT(setFontSizeFromApp(const int)));
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), selectedObjectAzimuthLine   , SLOT(setFontSizeFromApp(const int)));
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), selectedObjectHourAngleLine , SLOT(setFontSizeFromApp(const int)));
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), currentSunLine              , SLOT(setFontSizeFromApp(const int)));
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), currentMoonLine             , SLOT(setFontSizeFromApp(const int)));
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), currentPlanetLine           , SLOT(setFontSizeFromApp(const int)));
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), geographicLocation1Line     , SLOT(setFontSizeFromApp(const int)));
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), geographicLocation2Line     , SLOT(setFontSizeFromApp(const int)));
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), customAzimuth1Line          , SLOT(setFontSizeFromApp(const int)));
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), customAzimuth2Line          , SLOT(setFontSizeFromApp(const int)));
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), customDeclination1Line      , SLOT(setFontSizeFromApp(const int)));
-	connect(&app, SIGNAL(screenFontSizeChanged(int)), customDeclination2Line      , SLOT(setFontSizeFromApp(const int)));
-
-//	if (!conf->childGroups().contains("ArchaeoLines"))
-//	if (!conf->childGroups().contains("ArchaeoLines"))
-//		restoreDefaultSettings();
-
 	loadSettings();
 
 	// Create action for enable/disable & hook up signals
@@ -289,6 +257,7 @@ void ArchaeoLines::init()
 	addAction("actionShow_ArchaeoLines_dialog",  section, N_("Show settings dialog"),  configDialog,  "visible",           "Ctrl+Shift+U");
 
 	// Add a toolbar button
+	StelApp& app=StelApp::getInstance();
 	try
 	{
 		StelGui* gui = dynamic_cast<StelGui*>(app.getGui());
@@ -379,7 +348,7 @@ void ArchaeoLines::update(double deltaTime)
 	// compute parallax correction with Meeus 40.6. First, find H from h=0, then add corrections.
 
 	static const double b_over_a=0.99664719;
-	const double latRad=loc.latitude*M_PI/180.0;
+	const double latRad=static_cast<double>(loc.latitude)*M_PI_180;
 	const double u=std::atan(b_over_a*std::tan(latRad));
 	const double rhoSinPhiP=b_over_a*std::sin(u)+loc.altitude/6378140.0*std::sin(latRad);
 	const double rhoCosPhiP=         std::cos(u)+loc.altitude/6378140.0*std::cos(latRad);
@@ -424,8 +393,8 @@ void ArchaeoLines::update(double deltaTime)
 	southernMajorStandstillLine6->setDefiningAngle(lunarDEtopo[6] *180.0/M_PI);
 	southernMajorStandstillLine7->setDefiningAngle(lunarDEtopo[7] *180.0/M_PI);
 
-	zenithPassageLine->setDefiningAngle(loc.latitude);
-	nadirPassageLine->setDefiningAngle(-loc.latitude);
+	zenithPassageLine->setDefiningAngle(static_cast<double>(loc.latitude));
+	nadirPassageLine->setDefiningAngle(static_cast<double>(-loc.latitude));
 
 	// Selected object?
 	if (objMgr->getWasSelected())
@@ -442,7 +411,7 @@ void ArchaeoLines::update(double deltaTime)
 	}
 
 	// Updates for line brightness
-	lineFader.update((int)(deltaTime*1000));
+	lineFader.update(static_cast<int>(deltaTime*1000));
 	equinoxLine->update(deltaTime);
 	northernSolsticeLine->update(deltaTime);
 	southernSolsticeLine->update(deltaTime);
@@ -537,6 +506,7 @@ void ArchaeoLines::restoreDefaultSettings()
 
 void ArchaeoLines::loadSettings()
 {
+	setLineWidth(conf->value("ArchaeoLines/line_thickness", 1).toInt());
 	setEquinoxColor(                StelUtils::strToVec3f(conf->value("ArchaeoLines/color_equinox",                    "1.00,1.00,0.50").toString()));
 	setSolsticesColor(              StelUtils::strToVec3f(conf->value("ArchaeoLines/color_solstices",                  "1.00,0.15,0.15").toString()));
 	setCrossquartersColor(          StelUtils::strToVec3f(conf->value("ArchaeoLines/color_crossquarters",              "1.00,0.75,0.25").toString()));
@@ -562,8 +532,8 @@ void ArchaeoLines::loadSettings()
 	setGeographicLocation2Longitude(conf->value("ArchaeoLines/geographic_location_2_longitude",  35.235774).toDouble());
 	setGeographicLocation2Latitude( conf->value("ArchaeoLines/geographic_location_2_latitude",   31.778087).toDouble());
 	StelLocation loc=core->getCurrentLocation();
-	geographicLocation1Line->setDefiningAngle(getAzimuthForLocation(loc.longitude, loc.latitude, geographicLocation1Longitude, geographicLocation1Latitude));
-	geographicLocation2Line->setDefiningAngle(getAzimuthForLocation(loc.longitude, loc.latitude, geographicLocation2Longitude, geographicLocation2Latitude));
+	geographicLocation1Line->setDefiningAngle(getAzimuthForLocation(static_cast<double>(loc.longitude), static_cast<double>(loc.latitude), geographicLocation1Longitude, geographicLocation1Latitude));
+	geographicLocation2Line->setDefiningAngle(getAzimuthForLocation(static_cast<double>(loc.longitude), static_cast<double>(loc.latitude), geographicLocation2Longitude, geographicLocation2Latitude));
 	geographicLocation1Line->setLabel(conf->value("ArchaeoLines/geographic_location_1_label", "Mecca (Qibla)").toString());
 	geographicLocation2Line->setLabel(conf->value("ArchaeoLines/geographic_location_2_label", "Jerusalem").toString());
 
@@ -606,6 +576,16 @@ void ArchaeoLines::loadSettings()
 	enableArchaeoLines(conf->value("ArchaeoLines/enable_at_startup", false).toBool());
 }
 
+void ArchaeoLines::setLineWidth(int width)
+{
+	if (width!=lineWidth)
+	{
+		lineWidth=qBound(1, width, 8); // Force some sensible limit
+		conf->setValue("ArchaeoLines/line_thickness", lineWidth);
+		emit lineWidthChanged(lineWidth);
+	}
+}
+
 void ArchaeoLines::showEquinox(bool b)
 {
 	if (b!=flagShowEquinox)
@@ -893,7 +873,7 @@ void ArchaeoLines::updateObserverLocation(const StelLocation &loc)
 
 void ArchaeoLines::setCustomAzimuth1(double az)
 {
-	if (az!=customAzimuth1Line->getDefiningAngle())
+	if (!qFuzzyCompare(az, customAzimuth1Line->getDefiningAngle()))
 	{
 		customAzimuth1Line->setDefiningAngle(az);
 		conf->setValue("ArchaeoLines/custom_azimuth_1_angle", az);
@@ -902,7 +882,7 @@ void ArchaeoLines::setCustomAzimuth1(double az)
 }
 void ArchaeoLines::setCustomAzimuth2(double az)
 {
-	if (az!=customAzimuth1Line->getDefiningAngle())
+	if (!qFuzzyCompare(az, customAzimuth1Line->getDefiningAngle()))
 	{
 		customAzimuth2Line->setDefiningAngle(az);
 		conf->setValue("ArchaeoLines/custom_azimuth_2_angle", az);
@@ -923,7 +903,7 @@ void ArchaeoLines::setCustomAzimuth2Label(QString label)
 }
 void ArchaeoLines::setCustomDeclination1(double dec)
 {
-	if (dec!=customDeclination1Line->getDefiningAngle())
+	if (!qFuzzyCompare(dec, customDeclination1Line->getDefiningAngle()))
 	{
 		customDeclination1Line->setDefiningAngle(dec);
 		conf->setValue("ArchaeoLines/custom_declination_1_angle", dec);
@@ -932,7 +912,7 @@ void ArchaeoLines::setCustomDeclination1(double dec)
 }
 void ArchaeoLines::setCustomDeclination2(double dec)
 {
-	if (dec!=customDeclination1Line->getDefiningAngle())
+	if (!qFuzzyCompare(dec, customDeclination1Line->getDefiningAngle()))
 	{
 		customDeclination2Line->setDefiningAngle(dec);
 		conf->setValue("ArchaeoLines/custom_declination_2_angle", dec);
@@ -952,200 +932,6 @@ void ArchaeoLines::setCustomDeclination2Label(QString label)
 	emit customDeclination2LabelChanged(label);
 }
 
-/*
-// called by the dialog UI, converts QColor (0..255) to Stellarium's Vec3f float color.
-void ArchaeoLines::setLineColor(ArchaeoLine::Line whichLine, QColor color)
-{
-	switch (whichLine){
-		case ArchaeoLine::Equinox:
-			equinoxColor.set(color.redF(), color.greenF(), color.blueF());
-			conf->setValue("ArchaeoLines/color_equinox",        QString("%1,%2,%3").arg(equinoxColor.v[0]).arg(equinoxColor.v[1]).arg(equinoxColor.v[2]));
-			equinoxLine->setColor(equinoxColor);
-			break;
-		case ArchaeoLine::Solstices:
-			solsticesColor.set(color.redF(), color.greenF(), color.blueF());
-			conf->setValue("ArchaeoLines/color_solstices",        QString("%1,%2,%3").arg(solsticesColor.v[0]).arg(solsticesColor.v[1]).arg(solsticesColor.v[2]));
-			northernSolsticeLine->setColor(solsticesColor);
-			southernSolsticeLine->setColor(solsticesColor);
-			break;
-		case ArchaeoLine::Crossquarters:
-			crossquartersColor.set(color.redF(), color.greenF(), color.blueF());
-			conf->setValue("ArchaeoLines/color_crossquarters",    QString("%1,%2,%3").arg(crossquartersColor.v[0]).arg(crossquartersColor.v[1]).arg(crossquartersColor.v[2]));
-			northernCrossquarterLine->setColor(crossquartersColor);
-			southernCrossquarterLine->setColor(crossquartersColor);
-			break;
-		case ArchaeoLine::MajorStandstill:
-			majorStandstillColor.set(color.redF(), color.greenF(), color.blueF());
-			conf->setValue("ArchaeoLines/color_major_standstill", QString("%1,%2,%3").arg(majorStandstillColor.v[0]).arg(majorStandstillColor.v[1]).arg(majorStandstillColor.v[2]));
-			northernMajorStandstillLine0->setColor(majorStandstillColor);
-			southernMajorStandstillLine7->setColor(majorStandstillColor);
-			northernMajorStandstillLine1->setColor(majorStandstillColor);
-			southernMajorStandstillLine6->setColor(majorStandstillColor);
-			break;
-		case ArchaeoLine::MinorStandstill:
-			minorStandstillColor.set(color.redF(), color.greenF(), color.blueF());
-			conf->setValue("ArchaeoLines/color_minor_standstill", QString("%1,%2,%3").arg(minorStandstillColor.v[0]).arg(minorStandstillColor.v[1]).arg(minorStandstillColor.v[2]));
-			northernMinorStandstillLine2->setColor(minorStandstillColor);
-			southernMinorStandstillLine4->setColor(minorStandstillColor);
-			northernMinorStandstillLine3->setColor(minorStandstillColor);
-			southernMinorStandstillLine5->setColor(minorStandstillColor);
-			break;
-		case ArchaeoLine::ZenithPassage:
-			zenithPassageColor.set(color.redF(), color.greenF(), color.blueF());
-			conf->setValue("ArchaeoLines/color_zenith_passage",     QString("%1,%2,%3").arg(zenithPassageColor.v[0]).arg(zenithPassageColor.v[1]).arg(zenithPassageColor.v[2]));
-			zenithPassageLine->setColor(zenithPassageColor);
-			break;
-		case ArchaeoLine::NadirPassage:
-			nadirPassageColor.set(color.redF(), color.greenF(), color.blueF());
-			conf->setValue("ArchaeoLines/color_nadir_passage",      QString("%1,%2,%3").arg(nadirPassageColor.v[0]).arg(nadirPassageColor.v[1]).arg(nadirPassageColor.v[2]));
-			nadirPassageLine->setColor(nadirPassageColor);
-			break;
-		case ArchaeoLine::SelectedObject:
-			selectedObjectColor.set(color.redF(), color.greenF(), color.blueF());
-			conf->setValue("ArchaeoLines/color_selected_object",      QString("%1,%2,%3").arg(selectedObjectColor.v[0]).arg(selectedObjectColor.v[1]).arg(selectedObjectColor.v[2]));
-			selectedObjectLine->setColor(selectedObjectColor);
-			break;
-		case ArchaeoLine::SelectedObjectAzimuth:
-			selectedObjectAzimuthColor.set(color.redF(), color.greenF(), color.blueF());
-			conf->setValue("ArchaeoLines/color_selected_object_azimuth", QString("%1,%2,%3").arg(selectedObjectAzimuthColor.v[0]).arg(selectedObjectAzimuthColor.v[1]).arg(selectedObjectAzimuthColor.v[2]));
-			selectedObjectAzimuthLine->setColor(selectedObjectAzimuthColor);
-			break;
-		case ArchaeoLine::SelectedObjectHourAngle:
-			selectedObjectHourAngleColor.set(color.redF(), color.greenF(), color.blueF());
-			conf->setValue("ArchaeoLines/color_selected_object_hour_angle", QString("%1,%2,%3").arg(selectedObjectHourAngleColor.v[0]).arg(selectedObjectHourAngleColor.v[1]).arg(selectedObjectHourAngleColor.v[2]));
-			selectedObjectHourAngleLine->setColor(selectedObjectHourAngleColor);
-			break;
-		case ArchaeoLine::CurrentSun:
-			currentSunColor.set(color.redF(), color.greenF(), color.blueF());
-			conf->setValue("ArchaeoLines/color_current_sun",      QString("%1,%2,%3").arg(currentSunColor.v[0]).arg(currentSunColor.v[1]).arg(currentSunColor.v[2]));
-			currentSunLine->setColor(currentSunColor);
-			break;
-		case ArchaeoLine::CurrentMoon:
-			currentMoonColor.set(color.redF(), color.greenF(), color.blueF());
-			conf->setValue("ArchaeoLines/color_current_moon",      QString("%1,%2,%3").arg(currentMoonColor.v[0]).arg(currentMoonColor.v[1]).arg(currentMoonColor.v[2]));
-			currentMoonLine->setColor(currentMoonColor);
-			break;
-		case ArchaeoLine::CurrentPlanetNone:
-		case ArchaeoLine::CurrentPlanetMercury:
-		case ArchaeoLine::CurrentPlanetVenus:
-		case ArchaeoLine::CurrentPlanetMars:
-		case ArchaeoLine::CurrentPlanetJupiter:
-		case ArchaeoLine::CurrentPlanetSaturn:
-			currentPlanetColor.set(color.redF(), color.greenF(), color.blueF());
-			conf->setValue("ArchaeoLines/color_current_planet",      QString("%1,%2,%3").arg(currentPlanetColor.v[0]).arg(currentPlanetColor.v[1]).arg(currentPlanetColor.v[2]));
-			currentPlanetLine->setColor(currentPlanetColor);
-			break;
-		case ArchaeoLine::GeographicLocation1:
-			geographicLocation1Color.set(color.redF(), color.greenF(), color.blueF());
-			conf->setValue("ArchaeoLines/color_geographic_location_1", QString("%1,%2,%3").arg(geographicLocation1Color.v[0]).arg(geographicLocation1Color.v[1]).arg(geographicLocation1Color.v[2]));
-			geographicLocation1Line->setColor(geographicLocation1Color);
-			break;
-		case ArchaeoLine::GeographicLocation2:
-			geographicLocation2Color.set(color.redF(), color.greenF(), color.blueF());
-			conf->setValue("ArchaeoLines/color_geographic_location_2", QString("%1,%2,%3").arg(geographicLocation2Color.v[0]).arg(geographicLocation2Color.v[1]).arg(geographicLocation2Color.v[2]));
-			geographicLocation2Line->setColor(geographicLocation2Color);
-			break;
-		case ArchaeoLine::CustomAzimuth1:
-			customAzimuth1Color.set(color.redF(), color.greenF(), color.blueF());
-			conf->setValue("ArchaeoLines/color_custom_azimuth_1",    QString("%1,%2,%3").arg(customAzimuth1Color.v[0]).arg(customAzimuth1Color.v[1]).arg(customAzimuth1Color.v[2]));
-			customAzimuth1Line->setColor(customAzimuth1Color);
-			break;
-		case ArchaeoLine::CustomAzimuth2:
-			customAzimuth2Color.set(color.redF(), color.greenF(), color.blueF());
-			conf->setValue("ArchaeoLines/color_custom_azimuth_2",    QString("%1,%2,%3").arg(customAzimuth2Color.v[0]).arg(customAzimuth2Color.v[1]).arg(customAzimuth2Color.v[2]));
-			customAzimuth2Line->setColor(customAzimuth2Color);
-			break;
-		case ArchaeoLine::CustomDeclination1:
-			customDeclination1Color.set(color.redF(), color.greenF(), color.blueF());
-			conf->setValue("ArchaeoLines/color_custom_declination_1",    QString("%1,%2,%3").arg(customDeclination1Color.v[0]).arg(customDeclination1Color.v[1]).arg(customDeclination1Color.v[2]));
-			customDeclination1Line->setColor(customDeclination1Color);
-			break;
-		case ArchaeoLine::CustomDeclination2:
-			customDeclination2Color.set(color.redF(), color.greenF(), color.blueF());
-			conf->setValue("ArchaeoLines/color_custom_declination_2",    QString("%1,%2,%3").arg(customDeclination2Color.v[0]).arg(customDeclination2Color.v[1]).arg(customDeclination2Color.v[2]));
-			customDeclination2Line->setColor(customDeclination2Color);
-			break;
-		default:
-			Q_ASSERT(0);
-	}
-}
-*/
-
-// called by the dialog UI, converts Stellarium's Vec3f float color to QColor (0..255).
-/*
-QColor ArchaeoLines::getLineColor(ArchaeoLine::Line whichLine) const
-{
-	const Vec3f* vColor;
-	switch (whichLine){
-		case ArchaeoLine::Equinox:
-			vColor=&equinoxColor;
-			break;
-		case ArchaeoLine::Solstices:
-			vColor=&solsticesColor;
-			break;
-		case ArchaeoLine::Crossquarters:
-			vColor=&crossquartersColor;
-			break;
-		case ArchaeoLine::MajorStandstill:
-			vColor=&majorStandstillColor;
-			break;
-		case ArchaeoLine::MinorStandstill:
-			vColor=&minorStandstillColor;
-			break;
-		case ArchaeoLine::ZenithPassage:
-			vColor=&zenithPassageColor;
-			break;
-		case ArchaeoLine::NadirPassage:
-			vColor=&nadirPassageColor;
-			break;
-		case ArchaeoLine::SelectedObject:
-			vColor=&selectedObjectColor;
-			break;
-		case ArchaeoLine::SelectedObjectAzimuth:
-			vColor=&selectedObjectAzimuthColor;
-			break;
-		case ArchaeoLine::SelectedObjectHourAngle:
-			vColor=&selectedObjectHourAngleColor;
-			break;
-		case ArchaeoLine::CurrentSun:
-			vColor=&currentSunColor;
-			break;
-		case ArchaeoLine::CurrentMoon:
-			vColor=&currentMoonColor;
-			break;
-		case ArchaeoLine::CurrentPlanetNone:
-		case ArchaeoLine::CurrentPlanetMercury:
-		case ArchaeoLine::CurrentPlanetVenus:
-		case ArchaeoLine::CurrentPlanetMars:
-		case ArchaeoLine::CurrentPlanetJupiter:
-		case ArchaeoLine::CurrentPlanetSaturn:
-			vColor=&currentPlanetColor;
-			break;
-		case ArchaeoLine::GeographicLocation1:
-			vColor=&geographicLocation1Color;
-			break;
-		case ArchaeoLine::GeographicLocation2:
-			vColor=&geographicLocation2Color;
-			break;
-		case ArchaeoLine::CustomAzimuth1:
-			vColor=&customAzimuth1Color;
-			break;
-		case ArchaeoLine::CustomAzimuth2:
-			vColor=&customAzimuth2Color;
-			break;
-		case ArchaeoLine::CustomDeclination1:
-			vColor=&customDeclination1Color;
-			break;
-		case ArchaeoLine::CustomDeclination2:
-			vColor=&customDeclination2Color;
-			break;
-		default:
-			vColor=&selectedObjectColor; // this is only to silence compiler warning about uninitialized variable vColor.
-			Q_ASSERT(0);
-	}
-	return QColor.fromRgbF(vColor->v[0], vColor->v[1], vColor->v[2]);
-}
-*/
 void ArchaeoLines::setEquinoxColor(Vec3f color)
 {
 	if (color!=getEquinoxColor())
@@ -1306,68 +1092,48 @@ double ArchaeoLines::getLineAngle(ArchaeoLine::Line whichLine) const
 	switch (whichLine){
 		case ArchaeoLine::Equinox:
 			return equinoxLine->getDefiningAngle();
-			break;
 		case ArchaeoLine::Solstices:
 			return northernSolsticeLine->getDefiningAngle();
-			break;
 		case ArchaeoLine::Crossquarters:
 			return northernCrossquarterLine->getDefiningAngle();
-			break;
 		case ArchaeoLine::MajorStandstill:
 			return northernMajorStandstillLine0->getDefiningAngle();
-			break;
 		case ArchaeoLine::MinorStandstill:
 			return northernMinorStandstillLine2->getDefiningAngle();
-			break;
 		case ArchaeoLine::ZenithPassage:
 			return zenithPassageLine->getDefiningAngle();
-			break;
 		case ArchaeoLine::NadirPassage:
 			return nadirPassageLine->getDefiningAngle();
-			break;
 		case ArchaeoLine::SelectedObject:
 			return selectedObjectLine->getDefiningAngle();
-			break;
 		case ArchaeoLine::SelectedObjectAzimuth:
 			return selectedObjectAzimuthLine->getDefiningAngle();
-			break;
 		case ArchaeoLine::SelectedObjectHourAngle:
 			return selectedObjectHourAngleLine->getDefiningAngle();
-			break;
 		case ArchaeoLine::CurrentSun:
 			return currentSunLine->getDefiningAngle();
-			break;
 		case ArchaeoLine::CurrentMoon:
 			return currentMoonLine->getDefiningAngle();
-			break;
 		case ArchaeoLine::CurrentPlanetNone:
 			return 0.0;
-			break;
 		case ArchaeoLine::CurrentPlanetMercury:
 		case ArchaeoLine::CurrentPlanetVenus:
 		case ArchaeoLine::CurrentPlanetMars:
 		case ArchaeoLine::CurrentPlanetJupiter:
 		case ArchaeoLine::CurrentPlanetSaturn:
 			return currentPlanetLine->getDefiningAngle();
-			break;
 		case ArchaeoLine::GeographicLocation1:
 			return geographicLocation1Line->getDefiningAngle();
-			break;
 		case ArchaeoLine::GeographicLocation2:
 			return geographicLocation2Line->getDefiningAngle();
-			break;
 		case ArchaeoLine::CustomAzimuth1:
 			return customAzimuth1Line->getDefiningAngle();
-			break;
 		case ArchaeoLine::CustomAzimuth2:
 			return customAzimuth2Line->getDefiningAngle();
-			break;
 		case ArchaeoLine::CustomDeclination1:
 			return customDeclination1Line->getDefiningAngle();
-			break;
 		case ArchaeoLine::CustomDeclination2:
 			return customDeclination2Line->getDefiningAngle();
-			break;
 		default:
 			Q_ASSERT(0);
 	}
@@ -1379,40 +1145,28 @@ QString ArchaeoLines::getLineLabel(ArchaeoLine::Line whichLine) const
 	switch (whichLine){
 		case ArchaeoLine::Equinox:
 			return equinoxLine->getLabel();
-			break;
 		case ArchaeoLine::Solstices:
 			return northernSolsticeLine->getLabel();
-			break;
 		case ArchaeoLine::Crossquarters:
 			return northernCrossquarterLine->getLabel();
-			break;
 		case ArchaeoLine::MajorStandstill:
 			return northernMajorStandstillLine0->getLabel();
-			break;
 		case ArchaeoLine::MinorStandstill:
 			return northernMinorStandstillLine2->getLabel();
-			break;
 		case ArchaeoLine::ZenithPassage:
 			return zenithPassageLine->getLabel();
-			break;
 		case ArchaeoLine::NadirPassage:
 			return nadirPassageLine->getLabel();
-			break;
 		case ArchaeoLine::SelectedObject:
 			return selectedObjectLine->getLabel();
-			break;
 		case ArchaeoLine::SelectedObjectAzimuth:
 			return selectedObjectAzimuthLine->getLabel();
-			break;
 		case ArchaeoLine::SelectedObjectHourAngle:
 			return selectedObjectHourAngleLine->getLabel();
-			break;
 		case ArchaeoLine::CurrentSun:
 			return currentSunLine->getLabel();
-			break;
 		case ArchaeoLine::CurrentMoon:
 			return currentMoonLine->getLabel();
-			break;
 		case ArchaeoLine::CurrentPlanetNone:
 		case ArchaeoLine::CurrentPlanetMercury:
 		case ArchaeoLine::CurrentPlanetVenus:
@@ -1420,25 +1174,18 @@ QString ArchaeoLines::getLineLabel(ArchaeoLine::Line whichLine) const
 		case ArchaeoLine::CurrentPlanetJupiter:
 		case ArchaeoLine::CurrentPlanetSaturn:
 			return currentPlanetLine->getLabel();
-			break;
 		case ArchaeoLine::GeographicLocation1:
 			return geographicLocation1Line->getLabel();
-			break;
 		case ArchaeoLine::GeographicLocation2:
 			return geographicLocation2Line->getLabel();
-			break;
 		case ArchaeoLine::CustomAzimuth1:
 			return customAzimuth1Line->getLabel();
-			break;
 		case ArchaeoLine::CustomAzimuth2:
 			return customAzimuth2Line->getLabel();
-			break;
 		case ArchaeoLine::CustomDeclination1:
 			return customDeclination1Line->getLabel();
-			break;
 		case ArchaeoLine::CustomDeclination2:
 			return customDeclination2Line->getLabel();
-			break;
 		default:
 			Q_ASSERT(0);
 			return "ArchaeoLines::getLineLabel(): Error!";
@@ -1454,7 +1201,10 @@ double ArchaeoLines::getAzimuthForLocation(double longObs, double latObs, double
 
 	return (180.0/M_PI) * atan2(sin(longTarget-longObs), cos(latObs)*tan(latTarget)-sin(latObs)*cos(longTarget-longObs));
 }
-
+double ArchaeoLines::getAzimuthForLocation(float longObs, float latObs, double longTarget, double latTarget)
+{
+	return getAzimuthForLocation(static_cast<double>(longObs), static_cast<double>(latObs), longTarget, latTarget);
+}
 
 // callback stuff shamelessly taken from GridLinesMgr. Changes: Text MUST be filled, can also be empty for no label!
 struct ALViewportEdgeIntersectCallbackData
@@ -1483,15 +1233,15 @@ void alViewportEdgeIntersectCallback(const Vec3d& screenPos, const Vec3d& direct
 	if (text.isEmpty())
 		return;
 
-	double angleDeg = std::atan2(-direc[1], -direc[0])*180./M_PI;
+	float angleDeg = static_cast<float>(std::atan2(-direc[1], -direc[0])*M_180_PI);
 	float xshift=6.f;
-	if (angleDeg>90. || angleDeg<-90.)
+	if (angleDeg>90.f || angleDeg<-90.f)
 	{
-		angleDeg+=180.;
-		xshift=-d->sPainter->getFontMetrics().width(text)-6.f;
+		angleDeg+=180.f;
+		xshift=-d->sPainter->getFontMetrics().boundingRect(text).width()-6.f;
 	}
 
-	d->sPainter->drawText(screenPos[0], screenPos[1], text, angleDeg, xshift, 3);
+	d->sPainter->drawText(static_cast<float>(screenPos[0]), static_cast<float>(screenPos[1]), text, angleDeg, xshift, 3);
 	//d->sPainter->setColor(tmpColor[0], tmpColor[1], tmpColor[2], tmpColor[3]); // RESTORE
 	d->sPainter->setBlending(true);
 }
@@ -1510,6 +1260,7 @@ ArchaeoLine::ArchaeoLine(ArchaeoLine::Line lineType, double definingAngle) :
 	// Initialize the message strings and make sure they are translated when the language changes.
 	StelApp& app = StelApp::getInstance();
 	connect(&app, SIGNAL(languageChanged()), this, SLOT(updateLabel()));
+	connect(&app, SIGNAL(screenFontSizeChanged(int)), this, SLOT(setFontSizeFromApp(const int)));
 }
 
 void ArchaeoLine::updateLabel()
@@ -1597,6 +1348,7 @@ void ArchaeoLine::draw(StelCore *core, float intensity) const
 	StelPainter sPainter(prj);
 	sPainter.setBlending(true);
 	sPainter.setLineSmooth(true);
+	sPainter.setLineWidth(GETSTELMODULE(ArchaeoLines)->getLineWidth());
 	sPainter.setColor(color[0], color[1], color[2], intensity*fader.getInterstate());
 	//Vec4f textColor(color[0], color[1], color[2], intensity*fader.getInterstate());
 
@@ -1703,6 +1455,7 @@ void ArchaeoLine::draw(StelCore *core, float intensity) const
 	sPainter.drawSmallCircleArc(p1, middlePoint, rotCenter,alViewportEdgeIntersectCallback, &userData);
 	sPainter.drawSmallCircleArc(p2, middlePoint, rotCenter, alViewportEdgeIntersectCallback, &userData);
 
+	sPainter.setLineWidth(1); // restore
 	sPainter.setLineSmooth(false);
 	sPainter.setBlending(false);
 }
@@ -1717,7 +1470,7 @@ void ArchaeoLine::setColor(const Vec3f& c)
 }
 void ArchaeoLine::setDefiningAngle(const double angle)
 {
-	if (angle != definingAngle)
+	if (!qFuzzyCompare(angle, definingAngle))
 	{
 		definingAngle=angle;
 		emit definingAngleChanged(angle);
