@@ -71,13 +71,12 @@ StelPluginInfo ObservabilityStelPluginInterface::getPluginInfo() const
 	return info;
 }
 
-// TODO: Migrate to static const? --BM ==> GZ during JDfix for 0.14: SURE!
 // Some useful constants:
-const double Observability::Rad2Deg = 180./M_PI;         // Convert degrees into radians
+const double Observability::Rad2Deg = M_180_PI;         // Convert degrees into radians
 const double Observability::Rad2Hr = 12./M_PI;           // Convert hours into radians
 const double Observability::UA =  AU;                    // 1.4958e+8;         // Astronomical Unit in Km. ==> HAS BEEN DEFINED IN StelUtils.hpp!
 const double Observability::TFrac = 0.9972677595628414;  // Convert sidereal time into Solar time
-const double Observability::halfpi = M_PI * 0.5;         //  1.57079632675; // pi/2
+const double Observability::halfpi = M_PI_2;         //  1.57079632675; // pi/2
 const double Observability::MoonT = 29.530588;           // Moon synodic period (used as first estimate of Full Moon). ==> FIND MORE DEC. PLACES!
 const double Observability::RefFullMoon = 2451564.696; // Reference Julian date of a Full Moon.
 const double Observability::MoonPerilune = 0.0024236308; // Smallest Earth-Moon distance (in AU).
@@ -96,17 +95,25 @@ Observability::Observability()
 	, horizonAltDeg(0.)
 	, selRA(0.)
 	, selDec(0.)
+	, mylat(1000.)
+	, mylon(1000.)
 	, alti(0.)
 	, horizH(0.)
 	, culmAlt(0.)
+	, myJD(0., 0.)
 	, MoonRise(0.)
 	, MoonSet(0.)
 	, MoonCulm(0.)	
 	, lastJDMoon(0.)	
 	, ObserverLoc(0.)
 	, myPlanet(Q_NULLPTR)
+	, curYear(0)
 	, nDays(0)
 	, dmyFormat(false)
+	, isStar(true)
+	, isMoon(false)
+	, isSun(false)
+	, isScreen(true)
 	, hasRisen(false)
 	, configChanged(false)
 	, souChanged(false)
@@ -122,17 +129,6 @@ Observability::Observability()
 {
 	setObjectName("Observability");
 
-	// Dummy initial values for parameters and data vectors:
-	mylat = 1000.;
-	mylon = 1000.;
-	myJD.first = 0.;
-	myJD.second = 0.;
-	curYear = 0;
-	isStar = true;
-	isMoon = false;
-	isSun = false;
-	isScreen = true;
-
 	//Get pointer to the Earth:
 	PlanetP Earth = GETSTELMODULE(SolarSystem)->getEarth();
 	myEarth = Earth.data();
@@ -141,16 +137,9 @@ Observability::Observability()
 	PlanetP Moon = GETSTELMODULE(SolarSystem)->getMoon();
 	myMoon = Moon.data();
 
-	// I think this can be done in a more simple way...--BM
 	for (int i=0;i<366;i++) {
-//		sunRA[i] = 0.0; sunDec[i] = 0.0;
-//		objectRA[i] = 0.0; objectDec[i]=0.0;
-//		sunSidT[0][i]=0.0; sunSidT[1][i]=0.0;
-//		objectSidT[0][i]=0.0; objectSidT[1][i]=0.0;
-//		objectH0[i] = 0.0;
 		yearJD[i]=QPair<double, double>(0.0, 0.0);
 	};
-	// GZ Sure:
 	memset(sunRA,      0,   366*sizeof(double));
 	memset(sunDec,     0,   366*sizeof(double));
 	memset(objectRA,   0,   366*sizeof(double));
@@ -169,21 +158,6 @@ Observability::~Observability()
 
 void Observability::updateMessageText()
 {
-	// Set names of the months:
-	monthNames.clear();
-	monthNames << qc_("Jan", "short month name")
-	           << qc_("Feb", "short month name")
-	           << qc_("Mar", "short month name")
-	           << qc_("Apr", "short month name")
-	           << qc_("May", "short month name")
-	           << qc_("Jun", "short month name")
-	           << qc_("Jul", "short month name")
-	           << qc_("Aug", "short month name")
-	           << qc_("Sep", "short month name")
-	           << qc_("Oct", "short month name")
-	           << qc_("Nov", "short month name")
-	           << qc_("Dec", "short month name");
-
 	// TRANSLATORS: Short for "hours".
 	msgH		= q_("h");
 	// TRANSLATORS: Short for "minutes".
@@ -282,8 +256,8 @@ void Observability::draw(StelCore* core)
 	painter.setFont(font);
 
 // Get current date, location, and check if there is something selected.
-	double currlat = (core->getCurrentLocation().latitude)/Rad2Deg;
-	double currlon = (core->getCurrentLocation().longitude)/Rad2Deg;
+	double currlat = static_cast<double>(core->getCurrentLocation().latitude)/Rad2Deg;
+	double currlon = static_cast<double>(core->getCurrentLocation().longitude)/Rad2Deg;
 	double currheight = (6371.+(core->getCurrentLocation().altitude)/1000.)/UA;
 	double currJD = core->getJD();
 	double currJDint;
@@ -829,9 +803,9 @@ void Observability::draw(StelCore* core)
 
 // Print all results:
 	StelProjector::StelProjectorParams params = core->getCurrentStelProjectorParams();
-	int lineSpacing = (int) (params.devicePixelsPerPixel * 1.3 * ( (double) fontSize));  // between lines
-	int groupSpacing = 6*fontSize*params.devicePixelsPerPixel;  // between daily and yearly results
-	int yLine = 8*fontSize*params.devicePixelsPerPixel + 110;
+	int lineSpacing = static_cast<int>(params.devicePixelsPerPixel * 1.3 * fontSize);  // between lines
+	int groupSpacing = static_cast<int>(6*fontSize*params.devicePixelsPerPixel);  // between daily and yearly results
+	int yLine = static_cast<int>(8*fontSize*params.devicePixelsPerPixel) + 110;
 	int xLine = 80;
 
 	if (show_Today) 
@@ -918,9 +892,9 @@ double Observability::HourAngle2(double RA, double ST)
 // Converts a float time/angle span (in hours/degrees) in the (integer) format hh/dd,mm,ss:
 void Observability::double2hms(double hfloat, int &h1, int &h2, int &h3)
 {
-	h1 = (int)hfloat;
-	h2 = (int)((qAbs(hfloat)-qAbs(double(h1)))*60);
-	h3 = (int)(((qAbs(hfloat)-qAbs(double(h1)))*60)-h2)*60;
+	h1 = static_cast<int>(hfloat);
+	h2 = static_cast<int>((qAbs(hfloat)-qAbs(double(h1)))*60);
+	h3 = static_cast<int>(((qAbs(hfloat)-qAbs(double(h1)))*60)-h2)*60;
 } 
 ////////////////////////////////////
 
@@ -947,7 +921,7 @@ QString Observability::formatAsDate(int dayNumber)
 	StelUtils::getDateFromJulianDay(yearJD[dayNumber].first, &year, &month, &day);
 
 	QString formatString = (getDateFormat()) ? "%1 %2" : "%2 %1";
-	QString result = formatString.arg(day).arg(monthNames[month-1]);
+	QString result = formatString.arg(day).arg(StelLocaleMgr::shortMonthName(month));
 	return result;
 }
 
@@ -974,16 +948,16 @@ QString Observability::formatAsDateRange(int startDay, int endDay)
 	if (sMonth == eMonth)
 	{
 		QString formatString = (getDateFormat()) ? "%1 - %2 %3" : "%3 %1 - %2";
-		range = formatString.arg(sDay).arg(eDay).arg(monthNames[sMonth-1]);
+		range = formatString.arg(sDay).arg(eDay).arg(StelLocaleMgr::shortMonthName(sMonth));
 	}
 	else
 	{
 		QString formatString = (getDateFormat()) ? "%1 %2 - %3 %4" 
 		                                         : "%2 %1 - %4 %3";
 		range = formatString.arg(sDay)
-		                    .arg(monthNames[sMonth-1])
+				    .arg(StelLocaleMgr::shortMonthName(sMonth))
 		                    .arg(eDay)
-		                    .arg(monthNames[eMonth-1]);
+				    .arg(StelLocaleMgr::shortMonthName(sMonth));
 	}
 
 	return range;
@@ -1027,7 +1001,7 @@ void Observability::updateSunData(StelCore* core)
 	Vec3d pos, sunPos;
 	for (int i=0; i<nDays; i++)
 	{
-		yearJD[i].first = Jan1stJD + (double)i;
+		yearJD[i].first = Jan1stJD + i;
 		yearJD[i].second = yearJD[i].first+core->computeDeltaT(yearJD[i].first)/86400.0;
 		myEarth->computePosition(yearJD[i].second);
 		myEarth->computeTransMatrix(yearJD[i].first, yearJD[i].second);
@@ -1091,12 +1065,12 @@ bool Observability::CheckRise(int day)
 	int nBin = 1000;
 	double auxSid1 = sunSidT[0][day];
 	auxSid1 += (sunSidT[0][day] < sunSidT[1][day]) ? 24.0 : 0.0;
-	double deltaT = (auxSid1-sunSidT[1][day]) / ((double)nBin);
+	double deltaT = (auxSid1-sunSidT[1][day]) / static_cast<double>(nBin);
 
 	double hour; 
 	for (int j=0; j<nBin; j++)
 	{
-		hour = toUnsignedRA(sunSidT[1][day]+deltaT*(double)j - objectRA[day]);
+		hour = toUnsignedRA(sunSidT[1][day]+deltaT*static_cast<double>(j) - objectRA[day]);
 		hour -= (hour>12.) ? 24.0 : 0.0;
 		if (qAbs(hour)<objectH0[day] || (objectH0[day] < 0.0 && alti>0.0))
 			return true;
@@ -1359,7 +1333,7 @@ bool Observability::calculateSolarSystemEvents(StelCore* core, int bodyType)
 {
 	const int NUM_ITER = 100;
 	int i;
-	double hHoriz, ra, dec, raSun, decSun, tempH, /* tempJd, */ tempEphH, curSidT, eclLon;
+	double hHoriz, ra, dec, raSun = 0.0, decSun = 0.0, tempH, /* tempJd, */ tempEphH, curSidT, eclLon;
 	QPair<double, double> tempJd;
 	//Vec3d Observer;
 
@@ -1625,17 +1599,17 @@ bool Observability::calculateSolarSystemEvents(StelCore* core, int bodyType)
 			StelUtils::getDateFromJulianDay(intMoon, &fullYear, &fullMonth, &fullDay);
 			double2hms(toUnsignedRA(LocalTMoon),fullHour,fullMinute,fullSecond);
 			if (getDateFormat())
-				lineBestNight = msgPrevFullMoon.arg(fullDay).arg(monthNames[fullMonth-1]).arg(fullHour).arg(fullMinute,2,10,QLatin1Char('0'));
+				lineBestNight = msgPrevFullMoon.arg(fullDay).arg(StelLocaleMgr::shortMonthName(fullMonth)).arg(fullHour).arg(fullMinute,2,10,QLatin1Char('0'));
 			else
-				lineBestNight = msgPrevFullMoon.arg(monthNames[fullMonth-1]).arg(fullDay).arg(fullHour).arg(fullMinute,2,10,QLatin1Char('0'));
+				lineBestNight = msgPrevFullMoon.arg(StelLocaleMgr::shortMonthName(fullMonth)).arg(fullDay).arg(fullHour).arg(fullMinute,2,10,QLatin1Char('0'));
 
 			LocalTMoon = 24.*modf(LocalNext,&intMoon);
 			StelUtils::getDateFromJulianDay(intMoon,&fullYear,&fullMonth,&fullDay);
 			double2hms(toUnsignedRA(LocalTMoon),fullHour,fullMinute,fullSecond);			
 			if (getDateFormat())
-				lineBestNight += msgNextFullMoon.arg(fullDay).arg(monthNames[fullMonth-1]).arg(fullHour).arg(fullMinute,2,10,QLatin1Char('0'));
+				lineBestNight += msgNextFullMoon.arg(fullDay).arg(StelLocaleMgr::shortMonthName(fullMonth)).arg(fullHour).arg(fullMinute,2,10,QLatin1Char('0'));
 			else
-				lineBestNight += msgNextFullMoon.arg(monthNames[fullMonth-1]).arg(fullDay).arg(fullHour).arg(fullMinute,2,10,QLatin1Char('0'));
+				lineBestNight += msgNextFullMoon.arg(StelLocaleMgr::shortMonthName(fullMonth)).arg(fullDay).arg(fullHour).arg(fullMinute,2,10,QLatin1Char('0'));
 
 			lineObservableRange.clear(); 
 			lineAcroCos.clear();
@@ -1643,7 +1617,7 @@ bool Observability::calculateSolarSystemEvents(StelCore* core, int bodyType)
 	// Now, compute the days of all the Full Moons of the current year, and get the Earth/Moon distance:
 //			double monthFrac, monthTemp, maxMoonDate;
 //			monthFrac = std::modf((nextFullMoon-Jan1stJD)/MoonT,&monthTemp);
-//			int PrevMonths = (int)(monthTemp+0.0*monthFrac); 
+//			int PrevMonths = static_cast<int>(monthTemp+0.0*monthFrac);
 //			double BestDistance = 1.0; // initial dummy value for Sun-Moon distance;
 //			double Distance; // temporal variable to save Earth-Moon distance at each month.
 
@@ -1844,14 +1818,14 @@ void Observability::setFontSize(int size)
 
 void Observability::setTwilightAltitude(int altitude)
 {
-	twilightAltRad  = ((double) altitude)/Rad2Deg ;
+	twilightAltRad  = static_cast<double>(altitude)/Rad2Deg ;
 	twilightAltDeg = altitude;
 	configChanged = true;
 }
 
 void Observability::setHorizonAltitude(int altitude)
 {
-	horizonAltitude = ((double) altitude)/Rad2Deg ;
+	horizonAltitude = static_cast<double>(altitude)/Rad2Deg ;
 	horizonAltDeg = altitude;
 	configChanged = true;
 }
