@@ -172,11 +172,15 @@ Oculars::Oculars()
 	, flagInitDirectionUsage(false)
 	, flagAutosetMountForCCD(false)
 	, flagScalingFOVForTelrad(false)
+	, flagScalingFOVForCCD(true)
 	, flagShowResolutionCriterions(false)
 	, equatorialMountEnabledMain(false)
 	, reticleRotation(0.)
 	, flagShowCcdCropOverlay(false)
 	, ccdCropOverlaySize(DEFAULT_CCD_CROP_OVERLAY_SIZE)
+	, flagShowContour(false)
+	, flagShowCardinals(false)
+	, flagAlignCrosshair(false)
 {
 	// Design font size is 14, based on default app fontsize 13.
 	setFontSizeFromApp(StelApp::getInstance().getScreenFontSize());
@@ -314,6 +318,9 @@ void Oculars::deinit()
 	disconnect(this, SIGNAL(selectedOcularChanged(int)), this, SLOT(updateOcularReticle()));
 	//disconnect(&StelApp::getInstance(), SIGNAL(colorSchemeChanged(const QString&)), this, SLOT(setStelStyle(const QString&)));
 	disconnect(&StelApp::getInstance(), SIGNAL(languageChanged()), this, SLOT(retranslateGui()));
+
+	cardinalsNormalTexture.clear();
+	cardinalsMirroredTexture.clear();
 }
 
 //! Draw any parts on the screen which are for our module
@@ -325,45 +332,24 @@ void Oculars::draw(StelCore* core)
 	}
 	else if (flagShowOculars)
 	{
-		// Ensure there is a selected ocular & telescope
-		if (selectedCCDIndex > ccds.count())
+		if (selectedOcularIndex >= 0)
 		{
-			qWarning() << "Oculars: the selected sensor index of "
-				   << selectedCCDIndex << " is greater than the sensor count of "
-				   << ccds.count() << ". Module disabled!";
-			ready = false;
-		}
-		if (selectedOcularIndex > oculars.count())
-		{
-			qWarning() << "Oculars: the selected ocular index of "
-				   << selectedOcularIndex << " is greater than the ocular count of "
-				   << oculars.count() << ". Module disabled!";
-			ready = false;
-		}
-		else if (selectedTelescopeIndex > telescopes.count())
-		{
-			qWarning() << "Oculars: the selected telescope index of "
-				   << selectedTelescopeIndex << " is greater than the telescope count of "
-				   << telescopes.count() << ". Module disabled!";
-			ready = false;
-		}
-		
-		if (ready)
-		{
-			if (selectedOcularIndex > -1)
-			{
-				paintOcularMask(core);
-				if (flagShowCrosshairs)
-				{
-					paintCrosshairs();
-				}
-			}
+			paintOcularMask(core);
+			if (flagShowCrosshairs)
+				paintCrosshairs();
+
 			if (!flagGuiPanelEnabled)
 			{
 				// Paint the information in the upper-right hand corner
 				paintText(core);
 			}
 		}
+		else
+		{
+			qWarning() << "Oculars: the selected ocular index of "
+				   << selectedOcularIndex << " is greater than the ocular count of "
+				   << oculars.count() << ". Module disabled!";
+		}
 	}
 	else if (flagShowCCD)
 	{
@@ -401,7 +387,7 @@ void Oculars::handleMouseClicks(class QMouseEvent* event)
 	StelCore *core = StelApp::getInstance().getCore();
 	const StelProjectorP prj = core->getProjection(StelCore::FrameJ2000, StelCore::RefractionAuto);
 	StelProjector::StelProjectorParams params = core->getCurrentStelProjectorParams();
-	float ppx = params.devicePixelsPerPixel;
+	qreal ppx = params.devicePixelsPerPixel;
 	
 	if (guiPanel)
 	{
@@ -417,19 +403,19 @@ void Oculars::handleMouseClicks(class QMouseEvent* event)
 	// https://sourceforge.net/p/stellarium/discussion/278769/thread/57893bb3/?limit=25#75c0
 	if ((flagShowOculars) ) //&& !getFlagUseSemiTransparency()) // Not sure: ignore or allow selection of semi-hidden stars?
 	{
-		float wh = prj->getViewportWidth()/2.; // get half of width of the screen
-		float hh = prj->getViewportHeight()/2.; // get half of height of the screen
+		float wh = prj->getViewportWidth()*0.5f; // get half of width of the screen
+		float hh = prj->getViewportHeight()*0.5f; // get half of height of the screen
 		float mx = event->x()-wh; // point 0 in center of the screen, axis X directed to right
 		float my = event->y()-hh; // point 0 in center of the screen, axis Y directed to bottom
 
 		double inner = 0.5 * params.viewportFovDiameter * ppx;
 		// See if we need to scale the mask
-		if (flagScaleImageCircle && oculars[selectedOcularIndex]->appearentFOV() > 0.0 && !oculars[selectedOcularIndex]->isBinoculars())
+		if (flagScaleImageCircle && oculars[selectedOcularIndex]->apparentFOV() > 0.0 && !oculars[selectedOcularIndex]->isBinoculars())
 		{
-			inner = oculars[selectedOcularIndex]->appearentFOV() * inner / maxEyepieceAngle;
+			inner = oculars[selectedOcularIndex]->apparentFOV() * inner / maxEyepieceAngle;
 		}
 
-		if (mx*mx+my*my>inner*inner) // click outside ocular circle? Gobble event.
+		if (mx*mx+my*my>static_cast<float>(inner*inner)) // click outside ocular circle? Gobble event.
 		{
 			event->setAccepted(true);
 			return;
@@ -630,7 +616,7 @@ void Oculars::init()
 		}
 		else
 		{
-			selectedOcularIndex = qMin(settings->value("ocular_index", 0).toInt(), actualOcularCount-1);
+			selectedOcularIndex = settings->value("ocular_index", 0).toInt();
 		}
 
 		int ccdCount = settings->value("ccd_count", 0).toInt();
@@ -652,7 +638,7 @@ void Oculars::init()
 			qWarning() << "The Oculars ini file appears to be corrupt; delete it.";
 			ready = false;
 		}
-		selectedCCDIndex = qMin(settings->value("ccd_index", 0).toInt(), actualCcdCount-1);
+		selectedCCDIndex = settings->value("ccd_index", 0).toInt();
 
 		int telescopeCount = settings->value("telescope_count", 0).toInt();
 		int actualTelescopeCount = telescopeCount;
@@ -682,7 +668,7 @@ void Oculars::init()
 		}
 		else
 		{
-			selectedTelescopeIndex = qMin(settings->value("telescope_index", 0).toInt(), actualTelescopeCount-1);
+			selectedTelescopeIndex = settings->value("telescope_index", 0).toInt();
 		}
 
 		int lensCount = settings->value("lens_count", 0).toInt();
@@ -703,7 +689,7 @@ void Oculars::init()
 		{
 			qWarning() << "The Oculars ini file appears to be corrupt; delete it.";
 		}
-		selectedLensIndex=qMin(settings->value("lens_index", -1).toInt(), actualLensCount-1); // Lens is not selected by default!
+		selectedLensIndex=settings->value("lens_index", -1).toInt(); // Lens is not selected by default!
 
 		pxmapGlow = new QPixmap(":/graphicGui/glow32x32.png");
 		pxmapOnIcon = new QPixmap(":/ocular/bt_ocular_on.png");
@@ -729,6 +715,7 @@ void Oculars::init()
 		setFlagHideGridsLines(settings->value("hide_grids_and_lines", true).toBool());
 		setFlagAutosetMountForCCD(settings->value("use_mount_autoset", false).toBool());
 		setFlagScalingFOVForTelrad(settings->value("use_telrad_fov_scaling", true).toBool());
+		setFlagScalingFOVForCCD(settings->value("use_ccd_fov_scaling", true).toBool());
 		setFlagShowResolutionCriterions(settings->value("show_resolution_criterions", false).toBool());
 		setArrowButtonScale(settings->value("arrow_scale", 1.5).toDouble());
 		setFlagShowOcularsButton(settings->value("show_toolbar_button", false).toBool());
@@ -737,7 +724,10 @@ void Oculars::init()
 		relativeStarScaleCCD=settings->value("stars_scale_relative_ccd", 1.0).toDouble();
 		absoluteStarScaleCCD=settings->value("stars_scale_absolute_ccd", 1.0).toDouble();
 		setFlagShowCcdCropOverlay(settings->value("show_ccd_crop_overlay", false).toBool());
-		setCcdCropOverlaySize(settings->value("ccd_crop_overlay_size", DEFAULT_CCD_CROP_OVERLAY_SIZE).toDouble());
+		setCcdCropOverlaySize(settings->value("ccd_crop_overlay_size", DEFAULT_CCD_CROP_OVERLAY_SIZE).toInt());
+		setFlagShowContour(settings->value("show_ocular_contour", false).toBool());
+		setFlagShowCardinals(settings->value("show_ocular_cardinals", false).toBool());
+		setFlagAlignCrosshair(settings->value("align_crosshair", false).toBool());
 	}
 	catch (std::runtime_error& e)
 	{
@@ -745,6 +735,9 @@ void Oculars::init()
 		ready = false;
 	}
 
+	cardinalsNormalTexture = StelApp::getInstance().getTextureManager().createTexture(":/ocular/cardinals.png");
+	cardinalsMirroredTexture = StelApp::getInstance().getTextureManager().createTexture(":/ocular/cardinals-mirrored.png");
+
 	connect(&StelApp::getInstance(), SIGNAL(languageChanged()), this, SLOT(retranslateGui()));
 	connect(this, SIGNAL(selectedOcularChanged(int)), this, SLOT(updateOcularReticle()));
 }
@@ -761,9 +754,9 @@ void Oculars::determineMaxEyepieceAngle()
 	{
 		for (const auto* ocular : oculars)
 		{
-			if (ocular->appearentFOV() > maxEyepieceAngle)
+			if (ocular->apparentFOV() > maxEyepieceAngle)
 			{
-				maxEyepieceAngle = ocular->appearentFOV();
+				maxEyepieceAngle = ocular->apparentFOV();
 			}
 		}
 	}
@@ -787,11 +780,6 @@ void Oculars::instrumentChanged()
 	}
 }
 
-//void Oculars::setFlagRequireSelection(bool state)
-//{
-//	flagRequireSelection = state;
-//}
-
 void Oculars::setFlagScaleImageCircle(bool state)
 {
 	if (state)
@@ -806,6 +794,10 @@ void Oculars::setFlagScaleImageCircle(bool state)
 
 void Oculars::setScreenFOVForCCD()
 {
+	// CCD is not shown and FOV scaling is disabled, but telescope is changed - do not change FOV!
+	if (!(getFlagScalingFOVForCCD() && flagShowCCD))
+		return;
+
 	Lens * lens = selectedLensIndex >=0  ? lenses[selectedLensIndex] : Q_NULLPTR;
 	if (selectedCCDIndex > -1 && selectedTelescopeIndex > -1)
 	{
@@ -1023,17 +1015,17 @@ void Oculars::enableOcular(bool enableOcularMode)
 	LabelMgr* labelManager = GETSTELMODULE(LabelMgr);
 
 	// Toggle the ocular view on & off. To toggle on, we want to ensure there is a selected object.
-	if (!flagShowOculars && flagRequireSelection && !StelApp::getInstance().getStelObjectMgr().getWasSelected() )
+	if (!flagShowOculars && !flagShowTelrad && flagRequireSelection && !StelApp::getInstance().getStelObjectMgr().getWasSelected() )
 	{
 		if (usageMessageLabelID == -1)
 		{
 			QFontMetrics metrics(font);
 			QString labelText = q_("Please select an object before switching to ocular view.");
 			StelProjector::StelProjectorParams projectorParams = core->getCurrentStelProjectorParams();
-			int xPosition = projectorParams.viewportCenter[0] + projectorParams.viewportCenterOffset[0];
-			xPosition = xPosition - 0.5 * (metrics.width(labelText));
-			int yPosition = projectorParams.viewportCenter[1] + projectorParams.viewportCenterOffset[1];
-			yPosition = yPosition - 0.5 * (metrics.height());
+			int xPosition = qRound(projectorParams.viewportCenter[0] + projectorParams.viewportCenterOffset[0]);
+			xPosition -= 0.5 * (metrics.width(labelText));
+			int yPosition = qRound(projectorParams.viewportCenter[1] + projectorParams.viewportCenterOffset[1]);
+			yPosition -= 0.5 * (metrics.height());
 			const char *tcolor = "#99FF99";
 			usageMessageLabelID = labelManager->labelScreen(labelText, xPosition, yPosition,
 									true, font.pixelSize(), tcolor);
@@ -1085,7 +1077,6 @@ void Oculars::decrementOcularIndex()
 		if (selectedTelescopeIndex == -1)
 			selectedTelescopeIndex = 0;
 	}
-
 	emit(selectedOcularChanged(selectedOcularIndex));
 }
 
@@ -1301,7 +1292,6 @@ void Oculars::incrementOcularIndex()
 		if (selectedTelescopeIndex == -1)
 			selectTelescopeAtIndex(0);
 	}
-
 	emit(selectedOcularChanged(selectedOcularIndex));
 }
 
@@ -1452,7 +1442,7 @@ void Oculars::toggleCCD(bool show)
 		//Zoom out
 		if (getFlagInitFovUsage())
 			movementManager->zoomTo(movementManager->getInitFov());
-		else
+		else if (!flagShowTelrad)
 			movementManager->zoomTo(initialFOV);
 
 		if (getFlagInitDirectionUsage())
@@ -1587,7 +1577,7 @@ void Oculars::paintCCDBounds()
 	Lens *lens = selectedLensIndex >=0  ? lenses[selectedLensIndex] : Q_NULLPTR;
 
 	const StelProjectorP projector = core->getProjection(StelCore::FrameEquinoxEqu);
-	double screenFOV = params.fov;
+	double screenFOV = static_cast<double>(params.fov);
 
 	Vec2i centerScreen(projector->getViewportPosX() + projector->getViewportWidth() / 2,
 			   projector->getViewportPosY() + projector->getViewportHeight() / 2);
@@ -1616,19 +1606,19 @@ void Oculars::paintCCDBounds()
 			{
 				aspectIndex = 3;
 			}
-			float width = params.viewportXywh[aspectIndex] * ccdXRatio * params.devicePixelsPerPixel;
-			float height = params.viewportXywh[aspectIndex] * ccdYRatio * params.devicePixelsPerPixel;
+			const float width = params.viewportXywh[aspectIndex] * static_cast<float>(ccdXRatio * params.devicePixelsPerPixel);
+			const float height = params.viewportXywh[aspectIndex] * static_cast<float>(ccdYRatio * params.devicePixelsPerPixel);
 
 			// Calculate the size of the CCD crop overlay
-			float overlayWidth = width * ccdCropOverlaySize / ccd->resolutionX();
-			float overlayHeight = height * ccdCropOverlaySize / ccd->resolutionY();
+			const float overlayWidth = width * ccdCropOverlaySize / ccd->resolutionX();
+			const float overlayHeight = height * ccdCropOverlaySize / ccd->resolutionY();
 
 			double polarAngle = 0;
 			// if the telescope is Equatorial derotate the field
 			if (telescope->isEquatorial())
 			{
 				Vec3d CPos;
-				Vec2f cpos = projector->getViewportCenter();
+				Vector2<qreal> cpos = projector->getViewportCenter();
 				projector->unProject(cpos[0], cpos[1], CPos);
 				Vec3d CPrel(CPos);
 				CPrel[2]*=0.2;
@@ -1646,44 +1636,45 @@ void Oculars::paintCCDBounds()
 				polarAngle = 0;
 			}
 
-			if (width > 0.0 && height > 0.0)
+			if (width > 0.0f && height > 0.0f)
 			{
 				QPoint a, b;
 				QTransform transform = QTransform().translate(centerScreen[0], centerScreen[1]).rotate(-(ccd->chipRotAngle() + polarAngle));
 				// bottom line
-				a = transform.map(QPoint(-width/2.0, -height/2.0));
-				b = transform.map(QPoint(width/2.0, -height/2.0));
+				a = transform.map(QPoint(static_cast<int>(-width*0.5f), static_cast<int>(-height*0.5f)));
+				b = transform.map(QPoint(static_cast<int>(width*0.5f), static_cast<int>(-height*0.5f)));
 				painter.drawLine2d(a.x(), a.y(), b.x(), b.y());
 				// top line
-				a = transform.map(QPoint(-width/2.0, height/2.0));
-				b = transform.map(QPoint(width/2.0, height/2.0));
+				a = transform.map(QPoint(static_cast<int>(-width*0.5f), static_cast<int>(height*0.5f)));
+				b = transform.map(QPoint(static_cast<int>(width*0.5f), static_cast<int>(height*0.5f)));
 				painter.drawLine2d(a.x(), a.y(), b.x(), b.y());
 				// left line
-				a = transform.map(QPoint(-width/2.0, -height/2.0));
-				b = transform.map(QPoint(-width/2.0, height/2.0));
+				a = transform.map(QPoint(static_cast<int>(-width*0.5f), static_cast<int>(-height*0.5f)));
+				b = transform.map(QPoint(static_cast<int>(-width*0.5f), static_cast<int>(height*0.5f)));
 				painter.drawLine2d(a.x(), a.y(), b.x(), b.y());
 				// right line
-				a = transform.map(QPoint(width/2.0, height/2.0));
-				b = transform.map(QPoint(width/2.0, -height/2.0));
+				a = transform.map(QPoint(static_cast<int>(width*0.5f), static_cast<int>(height*0.50f)));
+				b = transform.map(QPoint(static_cast<int>(width*0.5f), static_cast<int>(-height*0.5f)));
 				painter.drawLine2d(a.x(), a.y(), b.x(), b.y());
 
 				// Tool for showing a resolution box overlay
-				if (flagShowCcdCropOverlay) {
+				if (flagShowCcdCropOverlay)
+				{
 					// bottom line
-					a = transform.map(QPoint(-overlayWidth/2.0, -overlayHeight/2.0));
-					b = transform.map(QPoint(overlayWidth/2.0, -overlayHeight/2.0));
+					a = transform.map(QPoint(static_cast<int>(-overlayWidth*0.5f), static_cast<int>(-overlayHeight*0.5f)));
+					b = transform.map(QPoint(static_cast<int>(overlayWidth*0.5f), static_cast<int>(-overlayHeight*0.5f)));
 					painter.drawLine2d(a.x(), a.y(), b.x(), b.y());
 					// top line
-					a = transform.map(QPoint(-overlayWidth/2.0, overlayHeight/2.0));
-					b = transform.map(QPoint(overlayWidth/2.0, overlayHeight/2.0));
+					a = transform.map(QPoint(static_cast<int>(-overlayWidth*0.5f), static_cast<int>(overlayHeight*0.5f)));
+					b = transform.map(QPoint(static_cast<int>(overlayWidth*0.5f), static_cast<int>(overlayHeight*0.5f)));
 					painter.drawLine2d(a.x(), a.y(), b.x(), b.y());
 					// left line
-					a = transform.map(QPoint(-overlayWidth/2.0, -overlayHeight/2.0));
-					b = transform.map(QPoint(-overlayWidth/2.0, overlayHeight/2.0));
+					a = transform.map(QPoint(static_cast<int>(-overlayWidth*0.5f), static_cast<int>(-overlayHeight*0.5f)));
+					b = transform.map(QPoint(static_cast<int>(-overlayWidth*0.5f), static_cast<int>(overlayHeight*0.5f)));
 					painter.drawLine2d(a.x(), a.y(), b.x(), b.y());
 					// right line
-					a = transform.map(QPoint(overlayWidth/2.0, overlayHeight/2.0));
-					b = transform.map(QPoint(overlayWidth/2.0, -overlayHeight/2.0));
+					a = transform.map(QPoint(static_cast<int>(overlayWidth*0.5f), static_cast<int>(overlayHeight*0.5f)));
+					b = transform.map(QPoint(static_cast<int>(overlayWidth*0.5f), static_cast<int>(-overlayHeight*0.5f)));
 					painter.drawLine2d(a.x(), a.y(), b.x(), b.y());
 				}
 
@@ -1692,11 +1683,10 @@ void Oculars::paintCCDBounds()
 					const double InnerOAGRatio = ccd->getInnerOAGRadius(telescope, lens) / screenFOV;
 					const double OuterOAGRatio = ccd->getOuterOAGRadius(telescope, lens) / screenFOV;
 					const double prismXRatio = ccd->getOAGActualFOVx(telescope, lens) / screenFOV;
-					float in_oag_r = params.viewportXywh[aspectIndex] * InnerOAGRatio * params.devicePixelsPerPixel;
-					float out_oag_r = params.viewportXywh[aspectIndex] * OuterOAGRatio * params.devicePixelsPerPixel;
-					float h_width = params.viewportXywh[aspectIndex] * prismXRatio * params.devicePixelsPerPixel / 2.0;
+					const int in_oag_r = qRound(params.viewportXywh[aspectIndex] * InnerOAGRatio * params.devicePixelsPerPixel);
+					const int out_oag_r = qRound(params.viewportXywh[aspectIndex] * OuterOAGRatio * params.devicePixelsPerPixel);
+					const int h_width = qRound(params.viewportXywh[aspectIndex] * prismXRatio * params.devicePixelsPerPixel * 0.5);
 
-					//painter.setColor(0.60f, 0.20f, 0.20f, .5f);
 					painter.drawCircle(centerScreen[0], centerScreen[1], in_oag_r);
 					painter.drawCircle(centerScreen[0], centerScreen[1], out_oag_r);
 
@@ -1724,17 +1714,17 @@ void Oculars::paintCCDBounds()
 				// frame and equatorial coordinates for epoch J2000.0 of that center.
 				// Details: https://bugs.launchpad.net/stellarium/+bug/1404695
 
-				float ratioLimit = 0.25f;
-				float ratioLimitCrop = 0.75f;
+				const double ratioLimit = 0.25;
+				const double ratioLimitCrop = 0.75;
 				if (ccdXRatio>=ratioLimit || ccdYRatio>=ratioLimit)
 				{
 					// draw cross at center
-					float cross = width>height ? height/50.f : width/50.f;
-					a = transform.map(QPoint(0.f, -cross));
-					b = transform.map(QPoint(0.f, cross));
+					int cross = static_cast<int>(width>height ? height/50.f : width/50.f);
+					a = transform.map(QPoint(0, -cross));
+					b = transform.map(QPoint(0, cross));
 					painter.drawLine2d(a.x(), a.y(), b.x(), b.y());
-					a = transform.map(QPoint(-cross, 0.f));
-					b = transform.map(QPoint(cross, 0.f));
+					a = transform.map(QPoint(-cross, 0));
+					b = transform.map(QPoint(cross, 0));
 					painter.drawLine2d(a.x(), a.y(), b.x(), b.y());
 					// calculate coordinates of the center and show it
 					Vec3d centerPosition;
@@ -1753,13 +1743,17 @@ void Oculars::paintCCDBounds()
 						cxt = StelUtils::radToHmsStr(cx, true);
 						cyt = StelUtils::radToDmsStr(cy, true);
 					}
+					float scaleFactor = static_cast<float>(1.2 * params.devicePixelsPerPixel);
 					// Coordinates of center of visible field of view for CCD (red rectangle)
-					QString coords = QString("%1: %2/%3").arg(qc_("RA/Dec (J2000.0) of cross", "abbreviated in the plugin")).arg(cxt).arg(cyt);
-					a = transform.map(QPoint(-width/2.0, height/2.0 + 5.f));
-					painter.drawText(a.x(), a.y(), coords, -(ccd->chipRotAngle() + polarAngle));
+					QString coords = QString("%1:").arg(qc_("RA/Dec (J2000.0) of cross", "abbreviated in the plugin"));
+					a = transform.map(QPoint(qRound(-width*0.5f), qRound(height*0.5f + 5.f + fontSize*scaleFactor)));
+					painter.drawText(a.x(), a.y(), coords, static_cast<float>(-(ccd->chipRotAngle() + polarAngle)));
+					coords = QString("%1/%2").arg(cxt.simplified()).arg(cyt);
+					a = transform.map(QPoint(qRound(-width*0.5f), qRound(height*0.5f + 5.f)));
+					painter.drawText(a.x(), a.y(), coords, static_cast<float>(-(ccd->chipRotAngle() + polarAngle)));
 					// Dimensions of visible field of view for CCD (red rectangle)
-					a = transform.map(QPoint(-width/2.0, -height/2.0 - fontSize*1.2f));
-					painter.drawText(a.x(), a.y(), getDimensionsString(fovX, fovY), -(ccd->chipRotAngle() + polarAngle));
+					a = transform.map(QPoint(qRound(-width*0.5f), qRound(-height*0.5f - fontSize*scaleFactor)));
+					painter.drawText(a.x(), a.y(), getDimensionsString(fovX, fovY), static_cast<float>(-(ccd->chipRotAngle() + polarAngle)));
 					// Horizontal and vertical scales of visible field of view for CCD (red rectangle)
 					//TRANSLATORS: Unit of measure for scale - arcseconds per pixel
 					QString unit = q_("\"/px");
@@ -1768,12 +1762,12 @@ void Oculars::paintCCDBounds()
 							.arg(QString::number(fovY*3600*ccd->binningY()/ccd->resolutionY(), 'f', 4))
 							.arg(unit)
 							.arg(QChar(0x00D7));
-					a = transform.map(QPoint(width/2.0 - painter.getFontMetrics().width(scales), -height/2.0 - fontSize*1.2f));
-					painter.drawText(a.x(), a.y(), scales, -(ccd->chipRotAngle() + polarAngle));
+					a = transform.map(QPoint(qRound(width*0.5f - painter.getFontMetrics().width(scales)*params.devicePixelsPerPixel), qRound(-height*0.5f - fontSize*scaleFactor)));
+					painter.drawText(a.x(), a.y(), scales, static_cast<float>(-(ccd->chipRotAngle() + polarAngle)));
 					// Rotation angle of visible field of view for CCD (red rectangle)
 					QString angle = QString("%1%2").arg(QString::number(ccd->chipRotAngle(), 'f', 1)).arg(QChar(0x00B0));
-					a = transform.map(QPoint(width/2.0 - painter.getFontMetrics().width(angle), height/2.0 + 5.f));
-					painter.drawText(a.x(), a.y(), angle, -(ccd->chipRotAngle() + polarAngle));
+					a = transform.map(QPoint(qRound(width*0.5f - painter.getFontMetrics().width(angle)*params.devicePixelsPerPixel), qRound(height*0.5f + 5.f)));
+					painter.drawText(a.x(), a.y(), angle, static_cast<float>(-(ccd->chipRotAngle() + polarAngle)));
 
 					if(flagShowCcdCropOverlay && (ccdXRatio>=ratioLimitCrop || ccdYRatio>=ratioLimitCrop))
 					{
@@ -1782,8 +1776,8 @@ void Oculars::paintCCDBounds()
 								.arg(QString::number(ccdCropOverlaySize, 'd', 0))
 								.arg(qc_("px", "pixel"))
 								.arg(QChar(0x00D7));
-						a = transform.map(QPoint(overlayWidth/2.0 - painter.getFontMetrics().width(resolutionOverlayText), -overlayHeight/2.0 - fontSize*1.2f));
-						painter.drawText(a.x(), a.y(), resolutionOverlayText, -(ccd->chipRotAngle() + polarAngle));
+						a = transform.map(QPoint(qRound(overlayWidth*0.5f - painter.getFontMetrics().width(resolutionOverlayText)*params.devicePixelsPerPixel), qRound(-overlayHeight*0.5f - fontSize*scaleFactor)));
+						painter.drawText(a.x(), a.y(), resolutionOverlayText, static_cast<float>(-(ccd->chipRotAngle() + polarAngle)));
 					}
 				}
 			}
@@ -1799,18 +1793,39 @@ void Oculars::paintCrosshairs()
 	// Center of screen
 	Vec2i centerScreen(projector->getViewportPosX()+projector->getViewportWidth()/2,
 			   projector->getViewportPosY()+projector->getViewportHeight()/2);
-	float length = 0.5 * params.viewportFovDiameter;
+	float length = 0.5f * static_cast<float>(params.viewportFovDiameter);
 	// See if we need to scale the length
-	if (flagScaleImageCircle && oculars[selectedOcularIndex]->appearentFOV() > 0.0 && !oculars[selectedOcularIndex]->isBinoculars())
+	if (flagScaleImageCircle && oculars[selectedOcularIndex]->apparentFOV() > 0.0 && !oculars[selectedOcularIndex]->isBinoculars())
 	{
-		length = oculars[selectedOcularIndex]->appearentFOV() * length / maxEyepieceAngle;
+		length *= static_cast<float>(oculars[selectedOcularIndex]->apparentFOV() / maxEyepieceAngle);
+	}
+	length *= static_cast<float>(params.devicePixelsPerPixel);
+	double polarAngle = 0.;
+	if (getFlagAlignCrosshair())
+	{
+		Vec3d CPos;
+		Vector2<qreal> cpos = projector->getViewportCenter();
+		projector->unProject(cpos[0], cpos[1], CPos);
+		Vec3d CPrel(CPos);
+		CPrel[2]*=0.2;
+		Vec3d crel;
+		projector->project(CPrel, crel);
+		polarAngle = atan2(cpos[1] - crel[1], cpos[0] - crel[0]) * (-180.0)/M_PI; // convert to degrees
+		if (CPos[2] > 0) polarAngle += 90.0;
+		else polarAngle -= 90.0;
 	}
-	length *= params.devicePixelsPerPixel;
 	// Draw the lines
 	StelPainter painter(projector);
 	painter.setColor(0.77f, 0.14f, 0.16f, 1.f);
-	painter.drawLine2d(centerScreen[0], centerScreen[1] - length, centerScreen[0], centerScreen[1] + length);
-	painter.drawLine2d(centerScreen[0] - length, centerScreen[1], centerScreen[0] + length, centerScreen[1]);
+	QPoint a, b;
+	int hw = qRound(length);
+	QTransform ch_transform = QTransform().translate(centerScreen[0], centerScreen[1]).rotate(-polarAngle);
+	a = ch_transform.map(QPoint(0, -hw));
+	b = ch_transform.map(QPoint(0, hw));
+	painter.drawLine2d(a.x(), a.y(), b.x(), b.y());
+	a = ch_transform.map(QPoint(-hw, 0));
+	b = ch_transform.map(QPoint(hw, 0));
+	painter.drawLine2d(a.x(), a.y(), b.x(), b.y());
 }
 
 void Oculars::paintTelrad()
@@ -1824,19 +1839,17 @@ void Oculars::paintTelrad()
 		painter.setColor(0.77f, 0.14f, 0.16f, 1.f);
 		Vec2i centerScreen(projector->getViewportPosX()+projector->getViewportWidth()/2,
 				   projector->getViewportPosY()+projector->getViewportHeight()/2);
-		float pixelsPerRad = projector->getPixelPerRadAtCenter(); // * params.devicePixelsPerPixel;
-		painter.drawCircle(centerScreen[0], centerScreen[1], 0.5 * pixelsPerRad * (M_PI/180) * (0.5));
-		painter.drawCircle(centerScreen[0], centerScreen[1], 0.5 * pixelsPerRad * (M_PI/180) * (2.0));
-		painter.drawCircle(centerScreen[0], centerScreen[1], 0.5 * pixelsPerRad * (M_PI/180) * (4.0));
+		const float pixelsPerRad = projector->getPixelPerRadAtCenter(); // * params.devicePixelsPerPixel;
+		painter.drawCircle(centerScreen[0], centerScreen[1], 0.5f * pixelsPerRad * static_cast<float>(M_PI/180) * (0.5f));
+		painter.drawCircle(centerScreen[0], centerScreen[1], 0.5f * pixelsPerRad * static_cast<float>(M_PI/180) * (2.0f));
+		painter.drawCircle(centerScreen[0], centerScreen[1], 0.5f * pixelsPerRad * static_cast<float>(M_PI/180) * (4.0f));
 	}
 }
 
 void Oculars::paintOcularMask(const StelCore *core)
 {
 	if (oculars[selectedOcularIndex]->hasPermanentCrosshair())
-	{
 		paintCrosshairs();
-	}
 
 	const StelProjectorP prj = core->getProjection(StelCore::FrameAltAz);
 	StelPainter painter(prj);
@@ -1844,27 +1857,24 @@ void Oculars::paintOcularMask(const StelCore *core)
 
 	double inner = 0.5 * params.viewportFovDiameter * params.devicePixelsPerPixel;
 	// See if we need to scale the mask
-	if (flagScaleImageCircle && oculars[selectedOcularIndex]->appearentFOV() > 0.0 && !oculars[selectedOcularIndex]->isBinoculars())
+	if (flagScaleImageCircle && oculars[selectedOcularIndex]->apparentFOV() > 0.0 && !oculars[selectedOcularIndex]->isBinoculars())
 	{
-		inner = oculars[selectedOcularIndex]->appearentFOV() * inner / maxEyepieceAngle;
+		inner = oculars[selectedOcularIndex]->apparentFOV() * inner / maxEyepieceAngle;
 	}
-
-	painter.setBlending(true);
-
 	Vec2i centerScreen(prj->getViewportPosX()+prj->getViewportWidth()/2, prj->getViewportPosY()+prj->getViewportHeight()/2);
 
+	painter.setBlending(true);
 	// Paint the reticale, if needed
 	if (!reticleTexture.isNull())
 	{
 		painter.setColor(0.77f, 0.14f, 0.16f, 1.f);
-
 		reticleTexture->bind();
-
+		/* Why it need?
 		int textureHeight;
 		int textureWidth;
 		reticleTexture->getDimensions(textureWidth, textureHeight);
-
-		painter.drawSprite2dMode(centerScreen[0], centerScreen[1], inner / params.devicePixelsPerPixel, reticleRotation);
+		*/
+		painter.drawSprite2dMode(centerScreen[0], centerScreen[1], static_cast<float>(inner / params.devicePixelsPerPixel), static_cast<float>(reticleRotation));
 	}
 
 	float alpha = 1.f;
@@ -1873,7 +1883,7 @@ void Oculars::paintOcularMask(const StelCore *core)
 
 	painter.setColor(0.f,0.f,0.f,alpha);
 
-	GLfloat outerRadius = params.viewportXywh[2] * params.devicePixelsPerPixel + params.viewportXywh[3] * params.devicePixelsPerPixel;
+	GLfloat outerRadius = static_cast<GLfloat>(params.viewportXywh[2] * params.devicePixelsPerPixel + params.viewportXywh[3] * params.devicePixelsPerPixel);
 	GLint slices = 239;
 
 	GLfloat sinCache[240];
@@ -1883,14 +1893,14 @@ void Oculars::paintOcularMask(const StelCore *core)
 	GLfloat radiusHigh;
 
 	/* Compute length (needed for normal calculations) */
-	deltaRadius=outerRadius-inner;
+	deltaRadius=outerRadius-static_cast<GLfloat>(inner);
 
 	/* Cache is the vertex locations cache */
 	for (int i=0; i<=slices; i++)
 	{
-		GLfloat angle=(M_PI*2.0f)*i/slices;
-		sinCache[i]=(GLfloat)sin(angle);
-		cosCache[i]=(GLfloat)cos(angle);
+		GLfloat angle=static_cast<GLfloat>(M_PI*2.0)*i/slices;
+		sinCache[i]=static_cast<GLfloat>(sinf(angle));
+		cosCache[i]=static_cast<GLfloat>(cosf(angle));
 	}
 
 	sinCache[slices]=sinCache[0];
@@ -1912,6 +1922,40 @@ void Oculars::paintOcularMask(const StelCore *core)
 	}
 	painter.drawFromArray(StelPainter::TriangleStrip, (slices+1)*2, 0, false);
 	painter.enableClientStates(false);
+
+	if (getFlagShowContour())
+	{
+		// TODO: Make it configurable?
+		painter.setColor(0.77f, 0.14f, 0.16f, 1.f);
+		painter.drawCircle(centerScreen[0], centerScreen[1], static_cast<float>(inner));
+	}
+
+	if (getFlagShowCardinals())
+	{
+		// Compute polar angle for cardinals and show it
+		double polarAngle = 0;
+		const StelProjectorP projector = core->getProjection(StelCore::FrameEquinoxEqu);
+		Vec3d CPos;
+		Vector2<qreal> cpos = projector->getViewportCenter();
+		projector->unProject(cpos[0], cpos[1], CPos);
+		Vec3d CPrel(CPos);
+		CPrel[2]*=0.2;
+		Vec3d crel;
+		projector->project(CPrel, crel);
+		polarAngle = atan2(cpos[1] - crel[1], cpos[0] - crel[0]) * (-180.0)/M_PI; // convert to degrees
+		if (CPos[2] > 0)
+			polarAngle += 90.0;
+		else
+			polarAngle -= 90.0;
+
+		painter.setColor(0.77f, 0.14f, 0.16f, 1.f);
+		if (core->getFlipHorz() && !core->getFlipVert())
+			cardinalsMirroredTexture->bind();
+		else
+			cardinalsNormalTexture->bind();
+		painter.drawSprite2dMode(centerScreen[0], centerScreen[1], static_cast<float>(inner / params.devicePixelsPerPixel), static_cast<float>(-polarAngle));
+	}
+
 }
 
 void Oculars::paintText(const StelCore* core)
@@ -1944,11 +1988,11 @@ void Oculars::paintText(const StelCore* core)
 	// Get the X & Y positions, and the line height
 	painter.setFont(font);
 	QString widthString = "MMMMMMMMMMMMMMMMMMM";
-	float insetFromRHS = painter.getFontMetrics().width(widthString);
+	const float insetFromRHS = painter.getFontMetrics().width(widthString);
 	StelProjector::StelProjectorParams projectorParams = core->getCurrentStelProjectorParams();
-	int xPosition = projectorParams.viewportXywh[2] - projectorParams.viewportCenterOffset[0];
+	int xPosition = projectorParams.viewportXywh[2] - qRound(projectorParams.viewportCenterOffset[0]);
 	xPosition -= insetFromRHS;
-	int yPosition = projectorParams.viewportXywh[3] - projectorParams.viewportCenterOffset[1];
+	int yPosition = projectorParams.viewportXywh[3] - qRound(projectorParams.viewportCenterOffset[1]);
 	yPosition -= 40;
 	const int lineHeight = painter.getFontMetrics().height();
 	
@@ -1972,7 +2016,7 @@ void Oculars::paintText(const StelCore* core)
 		// The name of the ocular could be really long.
 		if (name.length() > widthString.length())
 		{
-			xPosition -= (insetFromRHS / 2.0);
+			xPosition -= (insetFromRHS*0.5f);
 		}
 		painter.drawText(xPosition, yPosition, ocularNumberLabel);
 		yPosition-=lineHeight;
@@ -1984,7 +2028,7 @@ void Oculars::paintText(const StelCore* core)
 			painter.drawText(xPosition, yPosition, eFocalLengthLabel);
 			yPosition-=lineHeight;
 			
-			QString ocularFov = QString::number(ocular->appearentFOV(), 'f', 2);
+			QString ocularFov = QString::number(ocular->apparentFOV(), 'f', 2);
 			ocularFov.append(QChar(0x00B0));//Degree sign
 			// TRANSLATORS: aFOV = apparent field of view
 			QString ocularFOVLabel = QString(q_("Ocular aFOV: %1")).arg(ocularFov);
@@ -2103,7 +2147,7 @@ void Oculars::validateAndLoadIniFile()
 {
 	// Insure the module directory exists
 	StelFileMgr::makeSureDirExistsAndIsWritable(StelFileMgr::getUserDir()+"/modules/Oculars");
-	StelFileMgr::Flags flags = (StelFileMgr::Flags)(StelFileMgr::Directory|StelFileMgr::Writable);
+	StelFileMgr::Flags flags = static_cast<StelFileMgr::Flags>(StelFileMgr::Directory|StelFileMgr::Writable);
 	QString ocularIniPath = StelFileMgr::findFile("modules/Oculars/", flags) + "ocular.ini";
 	if (ocularIniPath.isEmpty())
 		return;
@@ -2202,7 +2246,7 @@ void Oculars::unzoomOcular()
 
 	if (getFlagInitFovUsage())
 		movementManager->zoomTo(movementManager->getInitFov());
-	else
+	else if (!flagShowTelrad)
 		movementManager->zoomTo(initialFOV);
 
 	if (getFlagInitDirectionUsage())
@@ -2250,7 +2294,7 @@ void Oculars::zoom(bool zoomedIn)
 			flagMoonScaleMain		= propMgr->getStelPropertyValue("SolarSystem.flagMoonScale").toBool();
 			flagMinorBodiesScaleMain	= propMgr->getStelPropertyValue("SolarSystem.flagMinorBodyScale").toBool();
 
-			milkyWaySaturation	= propMgr->getStelPropertyValue("MilkyWay.saturation").toFloat();
+			milkyWaySaturation	= propMgr->getStelPropertyValue("MilkyWay.saturation").toDouble();
 
 			flipHorzMain = core->getFlipHorz();
 			flipVertMain = core->getFlipVert();
@@ -2372,9 +2416,9 @@ void Oculars::zoomOcular()
 
 	actualFOV = ocular->actualFOV(telescope, lens);
 	// See if the mask was scaled; if so, correct the actualFOV.
-	if (flagScaleImageCircle && ocular->appearentFOV() > 0.0 && !ocular->isBinoculars())
+	if (flagScaleImageCircle && ocular->apparentFOV() > 0.0 && !ocular->isBinoculars())
 	{
-		actualFOV = maxEyepieceAngle * actualFOV / ocular->appearentFOV();
+		actualFOV = maxEyepieceAngle * actualFOV / ocular->apparentFOV();
 	}
 	movementManager->zoomTo(actualFOV, 0.0);
 }
@@ -2559,6 +2603,19 @@ bool Oculars::getFlagScalingFOVForTelrad() const
 	return  flagScalingFOVForTelrad;
 }
 
+void Oculars::setFlagScalingFOVForCCD(const bool b)
+{
+	flagScalingFOVForCCD = b;
+	settings->setValue("use_ccd_fov_scaling", b);
+	settings->sync();
+	emit flagScalingFOVForCCDChanged(b);
+}
+
+bool Oculars::getFlagScalingFOVForCCD() const
+{
+	return  flagScalingFOVForCCD;
+}
+
 void Oculars::setFlagUseSemiTransparency(const bool b)
 {
 	flagSemiTransparency = b;
@@ -2605,6 +2662,45 @@ bool Oculars::getFlagShowCcdCropOverlay(void) const
 	return flagShowCcdCropOverlay;
 }
 
+void Oculars::setFlagShowContour(const bool b)
+{
+	flagShowContour = b;
+	settings->setValue("show_ocular_contour", b);
+	settings->sync();
+	emit flagShowContourChanged(b);
+}
+
+bool Oculars::getFlagShowContour(void) const
+{
+	return flagShowContour;
+}
+
+void Oculars::setFlagShowCardinals(const bool b)
+{
+	flagShowCardinals = b;
+	settings->setValue("show_ocular_cardinals", b);
+	settings->sync();
+	emit flagShowCardinalsChanged(b);
+}
+
+bool Oculars::getFlagShowCardinals(void) const
+{
+	return flagShowCardinals;
+}
+
+void Oculars::setFlagAlignCrosshair(const bool b)
+{
+	flagAlignCrosshair = b;
+	settings->setValue("align_crosshair", b);
+	settings->sync();
+	emit flagAlignCrosshairChanged(b);
+}
+
+bool Oculars::getFlagAlignCrosshair(void) const
+{
+	return flagAlignCrosshair;
+}
+
 void Oculars::setArrowButtonScale(const double val)
 {
 	arrowButtonScale = val;
@@ -2659,25 +2755,25 @@ QString Oculars::getDimensionsString(double fovX, double fovY) const
 	{
 		if (fovX >= 1.0)
 		{
-			int degrees = (int)fovX;
-			float minutes = (int)((fovX - degrees) * 60);
+			int degrees = static_cast<int>(fovX);
+			double minutes = (fovX - degrees) * 60.;
 			stringFovX = QString::number(degrees) + QChar(0x00B0) + QString::number(minutes, 'f', 2) + QChar(0x2032);
 		}
 		else
 		{
-			float minutes = (fovX * 60);
+			double minutes = fovX * 60.;
 			stringFovX = QString::number(minutes, 'f', 2) + QChar(0x2032);
 		}
 
 		if (fovY >= 1.0)
 		{
-			int degrees = (int)fovY;
-			float minutes = ((fovY - degrees) * 60);
+			int degrees = static_cast<int>(fovY);
+			double minutes = (fovY - degrees) * 60.;
 			stringFovY = QString::number(degrees) + QChar(0x00B0) + QString::number(minutes, 'f', 2) + QChar(0x2032);
 		}
 		else
 		{
-			float minutes = (fovY * 60);
+			double minutes = fovY * 60;
 			stringFovY = QString::number(minutes, 'f', 2) + QChar(0x2032);
 		}
 	}
