@@ -163,6 +163,10 @@ class Satellites : public StelObjectModule
 	Q_PROPERTY(bool realisticMode
 		   READ getFlagRealisticMode
 		   WRITE setFlagRelisticMode)
+	Q_PROPERTY(bool flagOrbitLines
+		   READ getFlagOrbitLines
+		   WRITE setFlagOrbitLines
+		   NOTIFY flagOrbitLinesChanged)
 	
 public:
 	//! @enum UpdateState
@@ -199,22 +203,24 @@ public:
 	virtual double getCallOrder(StelModuleActionName actionName) const;
 
 	///////////////////////////////////////////////////////////////////////////
-	// Methods defined in StelObjectManager class
+	// Methods defined in StelObjectModule class
 	//! Used to get a list of objects which are near to some position.
 	//! @param v a vector representing the position in th sky around which to search for satellites.
 	//! @param limitFov the field of view around the position v in which to search for satellites.
 	//! @param core the StelCore to use for computations.
-	//! @return an list containing the satellites located inside the limitFov circle around position v.
+	//! @return a list containing the satellites located inside the limitFov circle around position v.
 	virtual QList<StelObjectP> searchAround(const Vec3d& v, double limitFov, const StelCore* core) const;
 
 	//! Return the matching satellite object's pointer if exists or Q_NULLPTR.
-	//! @param nameI18n The case in-sensistive satellite name
+	//! @param nameI18n The case in-sensitive satellite name
 	virtual StelObjectP searchByNameI18n(const QString& nameI18n) const;
 
 	//! Return the matching satellite if exists or Q_NULLPTR.
-	//! @param name The case in-sensistive standard program name
+	//! @param name The case in-sensitive standard program name
 	virtual StelObjectP searchByName(const QString& name) const;
 
+	//! Return the matching satellite if exists or Q_NULLPTR.
+	//! @param id The satellite id (NORAD)
 	virtual StelObjectP searchByID(const QString &id) const;
 	
 	//! Return the satellite with the given catalog number.
@@ -368,8 +374,6 @@ public:
 	bool getFlagLabels() const;
 	bool getFlagRealisticMode() const;
 	bool getFlagHideInvisibleSatellites() const;
-	//! Get the current status of the orbit line rendering flag.
-	bool getOrbitLinesFlag() const;
 	bool isAutoAddEnabled() const { return autoAddEnabled; }
 	bool isAutoRemoveEnabled() const { return autoRemoveEnabled; }	
 
@@ -381,6 +385,7 @@ public:
 signals:
 	void hintsVisibleChanged(bool b);
 	void labelsVisibleChanged(bool b);
+	void flagOrbitLinesChanged(bool b);
 
 	//! Emitted when some of the plugin settings have been changed.
 	//! Used to communicate with the configuration window.
@@ -458,7 +463,9 @@ public slots:
 	//! as well, but this can be used to turn on/off all those satellites which elect to
 	//! have orbit lines all in one go.
 	//! @param b - true to turn on orbit lines, false to turn off
-	void setOrbitLinesFlag(bool b);
+	void setFlagOrbitLines(bool b);
+	//! Get the current status of the orbit line rendering flag.
+	bool getFlagOrbitLines() const;
 
 	void recalculateOrbitLines(void);
 
@@ -623,7 +630,7 @@ private slots:
 	//! re-use them later when adding manually satellites, parseTleFile()
 	//! can be modified to read directly form QNetworkReply-s. --BM
 	void saveDownloadedUpdate(QNetworkReply* reply);
-	void updateObserverLocation(StelLocation loc);
+	void updateObserverLocation(const StelLocation &loc);
 };
 
 
