@@ -43,7 +43,6 @@
 #include "sgp4unit.h"
 #include "sgp4ext.h"
 
-
 //! @class gSatTEME
 //! @brief Sat position and velocity predictions over TEME reference system.
 //! @details
@@ -54,7 +53,6 @@
 class gSatTEME
 {
 public:
-
 	// Operation: gSatTEME(const char *pstrName, char *pstrTleLine1, char *pstrTleLine2)
 	//! @brief Default class gSatTEME constructor
 	//! @param[in] 	pstrName Pointer to a null end string with the Sat. Name
@@ -107,9 +105,6 @@ public:
 		return m_Vel;
 	}
 
-
-
-
 	// Operation:  getSubPoint
 	//! @brief Get the Geographic satellite subpoint Vector calculated by the method compute SubPoint
 	//! @details To implement this operation, next references has been used:
@@ -129,6 +124,16 @@ public:
 		return satrec.error;
 	}
 
+	double getPeriod() const
+	{
+		// Get orbital period from mean motion (rad/min)
+		double mm = satrec.no;
+		if (mm > 0.0)
+			return 2*M_PI/mm;
+
+		return 0.0;
+	}
+
 private:
 	// Operation:  computeSubPoint
 	//! @brief Compute the Geographic satellite subpoint Vector
@@ -143,7 +148,6 @@ private:
 	//!	   Altitude:  Coord[2]  measured in Km.\n
 	Vec3d computeSubPoint(gTime ai_time);
 
-
 	// sgp4 proceses variables
 	double tumin, mu, radiusearthkm, xke, j2, j3, j4, j3oj2;
 	elsetrec satrec;
