@@ -160,9 +160,9 @@ bool SceneInfo::loadByID(const QString &id,SceneInfo& info)
 		}
 
 		if(ini.contains("latitude"))
-			info.location->latitude = StelUtils::getDecAngle(ini.value("latitude").toString())*180./M_PI;
+			info.location->latitude = StelUtils::getDecAngle(ini.value("latitude").toString())*M_180_PI;
 		if (ini.contains("longitude"))
-			info.location->longitude = StelUtils::getDecAngle(ini.value("longitude").toString())*180./M_PI;
+			info.location->longitude = StelUtils::getDecAngle(ini.value("longitude").toString())*M_180_PI;
 		if (ini.contains("country"))
 			info.location->country = ini.value("country").toString();
 		if (ini.contains("state"))
@@ -189,18 +189,18 @@ bool SceneInfo::loadByID(const QString &id,SceneInfo& info)
 	{ // compute rot_z from grid_meridian and location. Check their existence!
 		if (ini.contains("grid_meridian"))
 		{
-			double gridCentralMeridian=StelUtils::getDecAngle(ini.value("grid_meridian").toString())*180./M_PI;
+			double gridCentralMeridian=StelUtils::getDecAngle(ini.value("grid_meridian").toString())*M_180_PI;
 			if (!info.location.isNull())
 			{
 				// Formula from: http://en.wikipedia.org/wiki/Transverse_Mercator_projection, Convergence
 				//rot_z=std::atan(std::tan((lng-gridCentralMeridian)*M_PI/180.)*std::sin(lat*M_PI/180.));
 				// or from http://de.wikipedia.org/wiki/Meridiankonvergenz
-				rot_z=(info.location->longitude - gridCentralMeridian)*M_PI/180.*std::sin(info.location->latitude*M_PI/180.);
+				rot_z=(info.location->longitude - gridCentralMeridian)*M_PI_180*std::sin(info.location->latitude*M_PI_180);
 
 				qCDebug(sceneInfo) << "With Longitude " << info.location->longitude
 					 << ", Latitude " << info.location->latitude << " and CM="
 					 << gridCentralMeridian << ", ";
-				qCDebug(sceneInfo) << "setting meridian convergence to " << rot_z*180./M_PI << "degrees";
+				qCDebug(sceneInfo) << "setting meridian convergence to " << rot_z*M_180_PI << "degrees";
 			}
 			else
 			{
@@ -214,14 +214,14 @@ bool SceneInfo::loadByID(const QString &id,SceneInfo& info)
 	}
 	else
 	{
-		rot_z = convAngle.toDouble() * M_PI / 180.0;
+		rot_z = convAngle.toDouble() * M_PI_180;
 	}
 	// We must apply also a 90 degree rotation, plus convergence(rot_z)
 
 	// Meridian Convergence is negative in north-west quadrant.
 	// positive MC means True north is "left" of grid north, and model must be rotated clockwise. E.g. Sterngarten (east of UTM CM +15deg) has +0.93, we must rotate clockwise!
 	// A zRotate rotates counterclockwise, so we must reverse rot_z.
-	info.zRotateMatrix = Mat4d::zrotation(M_PI/2.0 - rot_z);
+	info.zRotateMatrix = Mat4d::zrotation(M_PI_2 - rot_z);
 
 	// At last, find start points.
 	if(ini.contains("start_E") && ini.contains("start_N"))
