@@ -558,9 +558,9 @@ SsoElements SolarSystemEditor::readMpcOneLineCometElements(QString oneLineElemen
 	int year	= mpcParser.cap(4).toInt();
 	int month	= mpcParser.cap(5).toInt();
 	double dayFraction	= mpcParser.cap(6).toDouble(&ok);
-	int day = (int) dayFraction;
+	int day = static_cast<int>(dayFraction);
 	QDate datePerihelionPassage(year, month, day);
-	int fraction = (int) ((dayFraction - day) * 24 * 60 * 60);
+	int fraction = static_cast<int>((dayFraction - day) * 24 * 60 * 60);
 	int seconds = fraction % 60; fraction /= 60;
 	int minutes = fraction % 60; fraction /= 60;
 	int hours = fraction % 24;
@@ -592,7 +592,7 @@ SsoElements SolarSystemEditor::readMpcOneLineCometElements(QString oneLineElemen
 		const double a=perihelionDistance/(1.-eccentricity); // semimajor axis.
 		const double meanMotion=0.01720209895/std::sqrt(a*a*a); // radians/day (0.01720209895 is Gaussian gravitational constant (symbol k))
 		double period=M_PI*2.0 / meanMotion; // period, days
-		result.insert("orbit_good", qMin(1000, (int) floor(0.5*period))); // validity for elliptical osculating elements, days. Goes from aphel to next aphel or max 1000 days.
+		result.insert("orbit_good", qMin(1000, static_cast<int>(floor(0.5*period)))); // validity for elliptical osculating elements, days. Goes from aphel to next aphel or max 1000 days.
 		result.insert("orbit_visualization_period", period); // add period for visualization of orbit
 	}
 	else
@@ -831,7 +831,7 @@ SsoElements SolarSystemEditor::readMpcOneLineMinorPlanetElements(QString oneLine
 		result.insert("orbit_visualization_period", StelUtils::calculateSiderealPeriod(semiMajorAxis));
 
 	// 2:3 resonance to Neptune [https://en.wikipedia.org/wiki/Plutino]
-	if ((int)semiMajorAxis == 39)
+	if (static_cast<int>(semiMajorAxis) == 39)
 		objectType = "plutino";
 
 	// Classical Kuiper belt objects [https://en.wikipedia.org/wiki/Classical_Kuiper_belt_object]
@@ -839,7 +839,7 @@ SsoElements SolarSystemEditor::readMpcOneLineMinorPlanetElements(QString oneLine
 		objectType = "cubewano";
 
 	// Calculate perihelion
-	float r = (1 - eccentricity)*semiMajorAxis;
+	double r = (1 - eccentricity)*semiMajorAxis;
 
 	// Scattered disc objects
 	if (r > 35)
@@ -860,263 +860,6 @@ SsoElements SolarSystemEditor::readMpcOneLineMinorPlanetElements(QString oneLine
 
 	return result;
 }
-/* DEAD CODE. MAYBE REACTIVATE FOR SCRIPTING ACCESS
-SsoElements SolarSystemEditor::readXEphemOneLineElements(QString oneLineElements)
-{
-	SsoElements result;
-
-	enum OrbitType {Elliptic, Hyperbolic, Parabolic} orbitType;
-
-	QStringList fields = oneLineElements.split(',');
-	if (fields.isEmpty() || fields.count() < 10 || fields.count() > 14)
-		return result;
-	//qDebug() << fields;
-
-	QString name = fields.at(0).trimmed();
-	if (name.isEmpty() || fields.at(1).isEmpty())
-		return result;
-
-	QChar orbitTypeFlag = fields.at(1).trimmed().at(0);
-	if (orbitTypeFlag == 'e')
-		orbitType = Elliptic;
-	else if(orbitTypeFlag == 'h')
-		orbitType = Hyperbolic;
-	else if (orbitTypeFlag == 'p')
-		orbitType = Parabolic;
-	else
-	{
-		qDebug() << "Unrecognised orbit type:" << orbitTypeFlag;
-		return result;
-	}
-
-	//"comet_orbit" is used for all cases:
-	//"ell_orbit" interprets distances as kilometers, not AUs
-	result.insert("coord_func", "comet_orbit");
-
-	//Type detection and name parsing
-	QString objectType;
-	int minorPlanetNumber = 0;
-	QRegExp cometProvisionalDesignationStart("^[PCDX]/");
-	QRegExp cometDesignationStart("^(\\d)+[PCDX]/");
-	if (cometDesignationStart.indexIn(name) == 0 ||
-		cometProvisionalDesignationStart.indexIn(name) == 0)
-	{
-		objectType = "comet";
-	}
-	else
-	{
-		objectType = "asteroid";
-		QRegExp asteroidProvisionalDesignation("(\\d{4}\\s[A-Z]{2})(\\d*)$");
-		int pdIndex = asteroidProvisionalDesignation.indexIn(name);
-		if (pdIndex != 0)
-		{
-			int spaceIndex = name.indexOf(' ');
-			if (spaceIndex > 0)
-			{
-				QString numberString = name.left(spaceIndex);
-				//qDebug() << numberString;
-				minorPlanetNumber = numberString.toInt();
-				if (minorPlanetNumber)
-					name = name.right(name.length() - spaceIndex - 1);
-				//qDebug() << name;
-			}
-		}
-	}
-	if (name.isEmpty())
-	{
-		return SsoElements();
-	}
-	result.insert("name", name);	
-	if (minorPlanetNumber)
-		result.insert("minor_planet_number", minorPlanetNumber);
-
-	//Section name
-	QString sectionName = convertToGroupName(name, minorPlanetNumber);
-	if (sectionName.isEmpty())
-	{
-		return SsoElements();
-	}
-	result.insert("section_name", sectionName);
-
-	//After a name has been determined, insert the essential keys
-	result.insert("parent", "Sun");
-
-	result.insert("lighting", false);
-	result.insert("color", "1.0, 1.0, 1.0");
-	result.insert("tex_map", "nomap.png");
-
-	//Orbital elements
-	bool ok;
-	QString field;
-
-	if (orbitType == Elliptic)
-		field = fields.at(2);//Field 3
-	else
-		field = fields.at(3);//Field 4
-	double inclination = field.trimmed().toDouble(&ok);
-	if (!ok)
-		return SsoElements();
-	result.insert("orbit_Inclination", inclination);
-
-	if (orbitType == Elliptic)
-		field = fields.at(3);//Field 4
-	else if (orbitType == Hyperbolic)
-		field = fields.at(4);//Field 5
-	else
-		field = fields.at(6);//Field 7
-	double longitudeOfTheAscendingNode = field.toDouble(&ok);//J2000.0, degrees
-	if (!ok)
-		return SsoElements();
-	result.insert("orbit_AscendingNode", longitudeOfTheAscendingNode);
-
-	if (orbitType == Hyperbolic)
-		field = fields.at(5);//Field 6
-	else
-		field = fields.at(4);//Field 5
-	double argumentOfPerihelion = field.toDouble(&ok);//J2000.0, degrees
-	if (!ok)
-		return SsoElements();
-	result.insert("orbit_ArgOfPericenter", argumentOfPerihelion);
-
-	double semiMajorAxis = -1.;
-	if (orbitType == Elliptic)
-	{
-		field = fields.at(5);//Field 6
-		semiMajorAxis = field.toDouble(&ok);
-		if (!ok)
-			return SsoElements();
-		result.insert("orbit_SemiMajorAxis", semiMajorAxis);
-
-		field = fields.at(6);//Field 7
-		double meanDailyMotion = field.toDouble(&ok);//degrees per day
-		if (!ok)
-			return SsoElements();
-		result.insert("orbit_MeanMotion", meanDailyMotion);
-	}
-
-	double eccentricity;
-	if (orbitType == Elliptic)
-		eccentricity = fields.at(7).toDouble(&ok);//Field 8
-	else if (orbitType == Hyperbolic)
-		eccentricity = fields.at(6).toDouble(&ok);//Field 7
-	else
-	{
-		//Parabolic orbit
-		eccentricity = 1.0;
-		ok = true;
-	}
-	if (!ok)
-		return SsoElements();
-	result.insert("orbit_Eccentricity", eccentricity);
-
-	if (orbitType == Elliptic)
-	{
-		double meanAnomalyAtEpoch = fields.at(8).toDouble(&ok);//degrees
-		if (!ok)
-			return SsoElements();
-		result.insert("orbit_MeanAnomaly", meanAnomalyAtEpoch);
-	}
-
-	if (orbitType == Elliptic)
-		field = fields.at(9);//Field 10
-	else
-		field = fields.at(2);//Field 3
-	QStringList dateStrings = field.trimmed().split('/');
-	//TODO: Validation
-	int year	= dateStrings.at(2).toInt();
-	int month	= dateStrings.at(0).toInt();
-	double dayFraction	= dateStrings.at(1).toDouble(&ok);
-	int day = (int) dayFraction;
-	QDate date(year, month, day);
-	int fraction = (int) ((dayFraction - day) * 24 * 60 * 60);
-	int seconds = fraction % 60; fraction /= 60;
-	int minutes = fraction % 60; fraction /= 60;
-	int hours = fraction % 24;
-	//qDebug() << hours << minutes << seconds << fraction;
-	QTime time(hours, minutes, seconds, 0);
-	QDateTime dt(date, time, Qt::UTC);
-	double jd = StelUtils::qDateTimeToJd(dt);
-	if (orbitType == Elliptic)
-		result.insert("orbit_Epoch", jd);
-	else
-		result.insert("orbit_TimeAtPericenter", jd);
-
-	if (orbitType != Elliptic)
-	{
-		if (orbitType == Hyperbolic)
-			field = fields.at(7);//Field 8
-		else
-			field = fields.at(5);//Field 6
-		double perihelionDistance = field.toDouble(&ok);//AU
-		if (!ok)
-			return SsoElements();
-		result.insert("orbit_PericenterDistance", perihelionDistance);
-	}
-
-	//Magnitude
-	if (orbitType == Elliptic)
-		field = fields.at(11);//Field 12
-	else if (orbitType == Hyperbolic)
-		field = fields.at(9);//Field 10
-	else
-		field = fields.at(8);//Field 9
-	QRegExp magnitudePrefix("^([Hg]\\s*)?(\\d.+)");
-	if (magnitudePrefix.indexIn(field) != 0)
-		return SsoElements();
-	field = magnitudePrefix.cap(2);
-	double absoluteMagnitude = field.toDouble(&ok);
-	if (!ok)
-		return SsoElements();
-	result.insert("absolute_magnitude", absoluteMagnitude);
-
-	if (orbitType == Elliptic)
-		field = fields.at(12);//Field 13
-	else if (orbitType == Hyperbolic)
-		field = fields.at(10);//Field 11
-	else
-		field = fields.at(9);//Field 10
-	double slopeParameter = field.toDouble(&ok);
-	if (!ok)
-		return SsoElements();
-	result.insert("slope_parameter", slopeParameter);
-
-	//Radius and albedo
-	double albedo = 0.04;
-	double radius = 5.0;
-	if (objectType == "asteroid")
-	{
-		//Assume albedo of 0.15 and calculate a radius based on the absolute magnitude
-		//http://www.physics.sfasu.edu/astro/asteroids/sizemagnitude.html
-		albedo = 0.15;
-		radius = std::ceil((1329 / std::sqrt(albedo)) * std::pow(10, -0.2 * absoluteMagnitude));
-
-		// 2:3 resonanse to Neptune
-		if ((int)semiMajorAxis == 39)
-			objectType = "plutino";
-
-		// Classical Kuiper belt objects
-		if (semiMajorAxis>=40 && semiMajorAxis<=50)
-			objectType = "cubewano";
-
-		// Calculate perihelion
-		float r = (1 - eccentricity)*semiMajorAxis;
-
-		// Scattered disc objects
-		if (r > 35)
-			objectType = "scattered disc object";
-
-		// Sednoids
-		if (r > 50 && semiMajorAxis > 150)
-			objectType = "sednoid";
-
-	}
-	result.insert("albedo", albedo);
-	result.insert("radius", radius);
-	result.insert("type", objectType);
-
-	return result;
-}
-*/
 
 QList<SsoElements> SolarSystemEditor::readMpcOneLineCometElementsFromFile(QString filePath) const
 {
@@ -1168,8 +911,6 @@ QList<SsoElements> SolarSystemEditor::readMpcOneLineCometElementsFromFile(QStrin
 		qDebug() << "File error:" << mpcElementsFile.errorString();
 		return objectList;
 	}
-
-	return objectList;
 }
 
 QList<SsoElements> SolarSystemEditor::readMpcOneLineMinorPlanetElementsFromFile(QString filePath) const
@@ -1222,71 +963,8 @@ QList<SsoElements> SolarSystemEditor::readMpcOneLineMinorPlanetElementsFromFile(
 		qDebug() << "File error:" << mpcElementsFile.errorString();
 		return objectList;
 	}
-
-	return objectList;
 }
 
-/*
- * // UNUSED FUNCTON as of 0.16pre. Maybe reactivate as public slot for scripting.
-QList<SsoElements> SolarSystemEditor::readXEphemOneLineElementsFromFile(QString filePath)
-{
-	QList<SsoElements> objectList;
-
-	if (!QFile::exists(filePath))
-	{
-		qDebug() << "Can't find" << QDir::toNativeSeparators(filePath);
-		return objectList;
-	}
-
-	QFile xEphemElementsFile(filePath);
-	if (xEphemElementsFile.open(QFile::ReadOnly | QFile::Text ))
-	{
-		int candidatesCount = 0;
-		int lineCount = 0;
-
-		while(!xEphemElementsFile.atEnd())
-		{
-			QString oneLineElements = QString(xEphemElementsFile.readLine());
-			if(oneLineElements.endsWith('\n'))
-			{
-				oneLineElements.chop(1);
-			}
-			if (oneLineElements.isEmpty())
-			{
-				qDebug() << "Empty line skipped.";
-				continue;
-			}
-			if (oneLineElements.startsWith('#'))
-			{
-				qDebug() << "Comment skipped.";
-				continue;
-			}
-			lineCount++;
-
-			SsoElements ssObject = readXEphemOneLineElements(oneLineElements);
-			if(!ssObject.isEmpty() && !ssObject.value("section_name").toString().isEmpty())
-			{
-				objectList << ssObject;
-				candidatesCount++;
-			}
-		}
-		xEphemElementsFile.close();
-		qDebug() << "Done reading minor planet orbital elements."
-				 << "Recognized" << candidatesCount << "candidate objects"
-				 << "out of" << lineCount << "lines.";
-
-		return objectList;
-	}
-	else
-	{
-		qDebug() << "Unable to open for reading" << QDir::toNativeSeparators(filePath);
-		qDebug() << "File error:" << xEphemElementsFile.errorString();
-		return objectList;
-	}
-
-	return objectList;
-}
-*/
 bool SolarSystemEditor::appendToSolarSystemConfigurationFile(QList<SsoElements> objectList)
 {
 	qDebug() << "appendToSolarSystemConfigurationFile begin ... ";
@@ -1422,26 +1100,26 @@ bool SolarSystemEditor::updateSolarSystemConfigurationFile(QList<SsoElements> ob
 	// This list of elements gets temporarily deleted.
 	// GZ: Note that the original implementation assumed that the coord_func could ever change. This is not possible at least in 0.13 and later:
 	// ell_orbit is used for moons (distances in km) while comet_orbit is used for minor bodies around the sun.
-	QStringList orbitalElementsKeys;
-	orbitalElementsKeys << "coord_func"
-			<< "orbit_ArgOfPericenter"
-			<< "orbit_AscendingNode"
-			<< "orbit_Eccentricity"
-			<< "orbit_Epoch"
+	static const QStringList orbitalElementsKeys = {
+		"coord_func",
+		"orbit_ArgOfPericenter",
+		"orbit_AscendingNode",
+		"orbit_Eccentricity",
+		"orbit_Epoch",
 // GZ It seems to have been an error to include these.  They might simply be updated without prior deletion.
-//			<< "orbit_good"
-//			<< "dust_lengthfactor"
-//			<< "dust_brightnessfactor"
-//			<< "dust_widthfactor"
-			<< "orbit_Inclination"
-			<< "orbit_LongOfPericenter"
-			<< "orbit_MeanAnomaly"
-			<< "orbit_MeanLongitude"
-			<< "orbit_MeanMotion"
-			<< "orbit_PericenterDistance"
-			<< "orbit_Period"
-			<< "orbit_SemiMajorAxis"
-			<< "orbit_TimeAtPericenter";
+//		"orbit_good",
+//		"dust_lengthfactor",
+//		"dust_brightnessfactor",
+//		"dust_widthfactor",
+		"orbit_Inclination",
+		"orbit_LongOfPericenter",
+		"orbit_MeanAnomaly",
+		"orbit_MeanLongitude",
+		"orbit_MeanMotion",
+		"orbit_PericenterDistance",
+		"orbit_Period",
+		"orbit_SemiMajorAxis",
+		"orbit_TimeAtPericenter"};
 
 	qDebug() << "Updating objects...";
 	for (auto object : objectList)
