@@ -58,10 +58,11 @@ Supernova::Supernova(const QVariantMap& map)
 
 	designation  = map.value("designation").toString();
 	sntype = map.value("type").toString();
-	maxMagnitude = map.value("maxMagnitude").toFloat();
+	maxMagnitude = map.value("maxMagnitude").toDouble();
 	peakJD = map.value("peakJD").toDouble();
 	snra = StelUtils::getDecAngle(map.value("alpha").toString());
 	snde = StelUtils::getDecAngle(map.value("delta").toString());
+	StelUtils::spheToRect(snra, snde, XYZ);
 	note = map.value("note").toString();
 	distance = map.value("distance").toDouble();
 
@@ -75,15 +76,15 @@ Supernova::~Supernova()
 
 QVariantMap Supernova::getMap(void) const
 {
-	QVariantMap map;
-	map["designation"] = designation;
-	map["sntype"] = sntype;
-	map["maxMagnitude"] = maxMagnitude;
-	map["peakJD"] = peakJD;
-	map["snra"] = snra;
-	map["snde"] = snde;
-	map["note"] = note;
-	map["distance"] = distance;
+	const QVariantMap map = {
+	{"designation", designation},
+	{"sntype", sntype},
+	{"maxMagnitude", maxMagnitude},
+	{"peakJD", peakJD},
+	{"snra", snra},
+	{"snde", snde},
+	{"note", note},
+	{"distance", distance}};
 
 	return map;
 }
@@ -182,14 +183,14 @@ QVariantMap Supernova::getInfoMap(const StelCore *core) const
 
 Vec3f Supernova::getInfoColor(void) const
 {
-	return Vec3f(1.0, 1.0, 1.0);
+	return Vec3f(1.f, 1.f, 1.f);
 }
 
 float Supernova::getVMagnitude(const StelCore* core) const
 {
 	double vmag = 20;
-	double currentJD = core->getJDE(); // GZ JDfix for 0.14. I hope the JD in the list is JDE? (Usually difference should be negligible)
-	double deltaJD = qAbs(peakJD-currentJD);
+	const double currentJD = core->getJDE(); // GZ JDfix for 0.14. I hope the JD in the list is JDE? (Usually difference should be negligible)
+	const double deltaJD = qAbs(peakJD-currentJD);
 
 	// Use supernova light curve model from here - http://www.astronet.ru/db/msg/1188703
 
@@ -239,7 +240,7 @@ float Supernova::getVMagnitude(const StelCore* core) const
 	if (vmag<maxMagnitude)
 		vmag = maxMagnitude;
 
-	return vmag;
+	return static_cast<float>(vmag);
 }
 
 double Supernova::getAngularSize(const StelCore*) const
@@ -249,31 +250,26 @@ double Supernova::getAngularSize(const StelCore*) const
 
 void Supernova::update(double deltaTime)
 {
-	labelsFader.update((int)(deltaTime*1000));
+	labelsFader.update(static_cast<int>(deltaTime*1000));
 }
 
 void Supernova::draw(StelCore* core, StelPainter& painter)
 {
 	StelSkyDrawer* sd = core->getSkyDrawer();
-	StarMgr* smgr = GETSTELMODULE(StarMgr); // It's need for checking displaying of labels for stars
-
-	Vec3f color = Vec3f(1.f,1.f,1.f);
-	RCMag rcMag;
-	float size, shift;
-	double mag;
-
-	StelUtils::spheToRect(snra, snde, XYZ);
-	mag = getVMagnitudeWithExtinction(core);
-	sd->preDrawPointSource(&painter);
-	float mlimit = sd->getLimitMagnitude();
+	const float mlimit = sd->getLimitMagnitude();
+	const float mag = getVMagnitudeWithExtinction(core);
 	
 	if (mag <= mlimit)
 	{
-		sd->computeRCMag(mag, &rcMag);		
-		sd->drawPointSource(&painter, Vec3f(XYZ[0],XYZ[1],XYZ[2]), rcMag, color, false);
-		painter.setColor(color[0], color[1], color[2], 1.f);
-		size = getAngularSize(Q_NULLPTR)*M_PI/180.*painter.getProjector()->getPixelPerRadAtCenter();
-		shift = 6.f + size/1.8f;
+		const Vec3f color(1.f);
+		RCMag rcMag;
+		sd->computeRCMag(mag, &rcMag);
+		sd->preDrawPointSource(&painter);
+		sd->drawPointSource(&painter, XYZ.toVec3f(), rcMag, color, false);
+		painter.setColor(color, 1.f);
+		float size = static_cast<float>(getAngularSize(Q_NULLPTR))*M_PI_180f*painter.getProjector()->getPixelPerRadAtCenter();
+		float shift = 6.f + size/1.8f;
+		StarMgr* smgr = GETSTELMODULE(StarMgr); // It's need for checking displaying of labels for stars
 		if (labelsFader.getInterstate()<=0.f && (mag+5.f)<mlimit && smgr->getFlagLabels())
 		{
 			painter.drawText(XYZ, designation, 0, shift, shift, false);
