@@ -70,7 +70,7 @@ StelPluginInfo SupernovaeStelPluginInterface::getPluginInfo() const
 	info.id = "Supernovae";
 	info.displayedName = N_("Historical Supernovae");
 	info.authors = "Alexander Wolf";
-	info.contact = "alex.v.wolf@gmail.com";
+	info.contact = "https://github.com/Stellarium/stellarium";
 	info.description = N_("This plugin allows you to see some bright historical supernovae.");
 	info.version = SUPERNOVAE_PLUGIN_VERSION;
 	info.license = SUPERNOVAE_PLUGIN_LICENSE;
@@ -140,7 +140,7 @@ void Supernovae::init()
 		// populate settings from main config file.
 		readSettingsFromConfig();
 
-		sneJsonPath = StelFileMgr::findFile("modules/Supernovae", (StelFileMgr::Flags)(StelFileMgr::Directory|StelFileMgr::Writable)) + "/supernovae.json";
+		sneJsonPath = StelFileMgr::findFile("modules/Supernovae", static_cast<StelFileMgr::Flags>(StelFileMgr::Directory|StelFileMgr::Writable)) + "/supernovae.json";
 		if (sneJsonPath.isEmpty())
 			return;
 
@@ -204,7 +204,6 @@ void Supernovae::draw(StelCore* core)
 
 	if (GETSTELMODULE(StelObjectMgr)->getFlagSelectedObjectPointer())
 		drawPointer(core, painter);
-
 }
 
 void Supernovae::drawPointer(StelCore* core, StelPainter& painter)
@@ -224,7 +223,7 @@ void Supernovae::drawPointer(StelCore* core, StelPainter& painter)
 		painter.setColor(c[0],c[1],c[2]);
 		texPointer->bind();
 		painter.setBlending(true);
-		painter.drawSprite2dMode(screenpos[0], screenpos[1], 13.f, StelApp::getInstance().getTotalRunTime()*40.);
+		painter.drawSprite2dMode(static_cast<float>(screenpos[0]), static_cast<float>(screenpos[1]), 13.f, static_cast<float>(StelApp::getInstance().getTotalRunTime())*40.f);
 	}
 }
 
@@ -234,7 +233,7 @@ QList<StelObjectP> Supernovae::searchAround(const Vec3d& av, double limitFov, co
 
 	Vec3d v(av);
 	v.normalize();
-	double cosLimFov = cos(limitFov * M_PI/180.);
+	const double cosLimFov = cos(limitFov * M_PI/180.);
 	Vec3d equPos;
 
 	for (const auto& sn : snstar)
@@ -243,7 +242,7 @@ QList<StelObjectP> Supernovae::searchAround(const Vec3d& av, double limitFov, co
 		{
 			equPos = sn->XYZ;
 			equPos.normalize();
-			if (equPos[0]*v[0] + equPos[1]*v[1] + equPos[2]*v[2]>=cosLimFov)
+			if (equPos.dot(v) >= cosLimFov)
 			{
 				result.append(qSharedPointerCast<StelObject>(sn));
 			}
@@ -416,7 +415,6 @@ void Supernovae::setSNeMap(const QVariantMap& map)
 		SupernovaP sn(new Supernova(sneData));
 		if (sn->initialized)
 			snstar.append(sn);
-
 	}
 }
 
@@ -567,7 +565,7 @@ void Supernovae::saveSettingsToConfig(void)
 int Supernovae::getSecondsToUpdate(void)
 {
 	QDateTime nextUpdate = lastUpdate.addSecs(updateFrequencyDays * 3600 * 24);
-	return QDateTime::currentDateTime().secsTo(nextUpdate);
+	return static_cast<int>(QDateTime::currentDateTime().secsTo(nextUpdate));
 }
 
 void Supernovae::checkForUpdate(void)
@@ -632,23 +630,23 @@ void Supernovae::updateDownloadProgress(qint64 bytesReceived, qint64 bytesTotal)
 	if (progressBar == Q_NULLPTR)
 		return;
 
-	int currentValue = 0;
-	int endValue = 0;
+	qint64 currentValue = 0;
+	qint64 endValue = 0;
 
 	if (bytesTotal > -1 && bytesReceived <= bytesTotal)
 	{
 		//Round to the greatest possible derived unit
 		while (bytesTotal > 1024)
 		{
-			bytesReceived = std::floor(bytesReceived / 1024.);
-			bytesTotal    = std::floor(bytesTotal / 1024.);
+			bytesReceived = qRound(std::floor(bytesReceived / 1024.));
+			bytesTotal    = qRound(std::floor(bytesTotal / 1024.));
 		}
 		currentValue = bytesReceived;
 		endValue = bytesTotal;
 	}
 
-	progressBar->setValue(currentValue);
-	progressBar->setRange(0, endValue);
+	progressBar->setValue(static_cast<int>(currentValue));
+	progressBar->setRange(0, static_cast<int>(endValue));
 }
 
 void Supernovae::downloadComplete(QNetworkReply *reply)
@@ -729,15 +727,14 @@ void Supernovae::displayMessage(const QString& message, const QString hexColor)
 
 QString Supernovae::getSupernovaeList() const
 {
-	QString smonth[] = {q_("January"), q_("February"), q_("March"), q_("April"), q_("May"), q_("June"), q_("July"), q_("August"), q_("September"), q_("October"), q_("November"), q_("December")};
 	QStringList out;
 	int year, month, day;
 	QList<double> vals = snlist.values();
-	qSort(vals);
+	std::sort(vals.begin(), vals.end());
 	for (auto val : vals)
 	{
 		StelUtils::getDateFromJulianDay(val, &year, &month, &day);
-		out << QString("%1 (%2 %3)").arg(snlist.key(val)).arg(day).arg(smonth[month-1]);
+		out << QString("%1 (%2 %3)").arg(snlist.key(val)).arg(day).arg(StelLocaleMgr::longGenitiveMonthName(month));
 	}
 
 	return out.join(", ");
