@@ -100,7 +100,7 @@ TelescopeClientDirectLx200::TelescopeClientDirectLx200 (const QString &name, con
 //! queues a GOTO command
 void TelescopeClientDirectLx200::telescopeGoto(const Vec3d &j2000Pos, StelObjectP selectObject)
 {
-	Q_UNUSED(selectObject);
+	Q_UNUSED(selectObject)
 
 	if (!isConnected())
 		return;
@@ -112,24 +112,38 @@ void TelescopeClientDirectLx200::telescopeGoto(const Vec3d &j2000Pos, StelObject
 		position = core->j2000ToEquinoxEqu(j2000Pos, StelCore::RefractionOff);
 	}
 
-	//if (writeBufferEnd - writeBuffer + 20 < (int)sizeof(writeBuffer))
-	//TODO: See the else clause, think how to do the same thing
-	{
-		const double ra_signed = atan2(position[1], position[0]);
-		//Workaround for the discrepancy in precision between Windows/Linux/PPC Macs and Intel Macs:
-		const double ra = (ra_signed >= 0) ? ra_signed : (ra_signed + 2.0 * M_PI);
-		const double dec = atan2(position[2], std::sqrt(position[0]*position[0]+position[1]*position[1]));
-		unsigned int ra_int = (unsigned int)floor(0.5 + ra*(((unsigned int)0x80000000)/M_PI));
-		int dec_int = (int)floor(0.5 + dec*(((unsigned int)0x80000000)/M_PI));
+	const double ra_signed = atan2(position[1], position[0]);
+	//Workaround for the discrepancy in precision between Windows/Linux/PPC Macs and Intel Macs:
+	const double ra = (ra_signed >= 0) ? ra_signed : (ra_signed + 2.0 * M_PI);
+	const double dec = atan2(position[2], std::sqrt(position[0]*position[0]+position[1]*position[1]));
+	unsigned int ra_int = static_cast<unsigned int>(floor(0.5 + ra*(static_cast<unsigned int>(0x80000000)/M_PI)));
+	int dec_int = static_cast<int>(floor(0.5 + dec*(static_cast<unsigned int>(0x80000000)/M_PI)));
 
-		gotoReceived(ra_int, dec_int);
+	gotoReceived(ra_int, dec_int);
+}
+
+void TelescopeClientDirectLx200::telescopeSync(const Vec3d &j2000Pos, StelObjectP selectObject)
+{
+	Q_UNUSED(selectObject)
+
+	if (!isConnected())
+		return;
+
+	Vec3d position = j2000Pos;
+	if (equinox == EquinoxJNow)
+	{
+		const StelCore* core = StelApp::getInstance().getCore();
+		position = core->j2000ToEquinoxEqu(j2000Pos, StelCore::RefractionOff);
 	}
-	/*
-		else
-		{
-			qDebug() << "TelescopeTCP(" << name << ")::telescopeGoto: "<< "communication is too slow, I will ignore this command";
-		}
-	*/
+
+	const double ra_signed = atan2(position[1], position[0]);
+	//Workaround for the discrepancy in precision between Windows/Linux/PPC Macs and Intel Macs:
+	const double ra = (ra_signed >= 0) ? ra_signed : (ra_signed + 2.0 * M_PI);
+	const double dec = atan2(position[2], std::sqrt(position[0]*position[0]+position[1]*position[1]));
+	unsigned int ra_int = static_cast<unsigned int>(floor(0.5 + ra*(static_cast<unsigned int>(0x80000000)/M_PI)));
+	int dec_int = static_cast<int>(floor(0.5 + dec*(static_cast<unsigned int>(0x80000000)/M_PI)));
+
+	syncReceived(ra_int, dec_int);
 }
 
 void TelescopeClientDirectLx200::gotoReceived(unsigned int ra_int, int dec_int)
@@ -137,6 +151,12 @@ void TelescopeClientDirectLx200::gotoReceived(unsigned int ra_int, int dec_int)
 	lx200->sendGoto(ra_int, dec_int);
 }
 
+void TelescopeClientDirectLx200::syncReceived(unsigned int ra_int, int dec_int)
+{
+	lx200->sendSync(ra_int, dec_int);
+}
+
+
 //! estimates where the telescope is by interpolation in the stored
 //! telescope positions:
 Vec3d TelescopeClientDirectLx200::getJ2000EquatorialPos(const StelCore*) const
@@ -203,7 +223,7 @@ void TelescopeClientDirectLx200::decReceived(unsigned int dec_int)
 	*log_file << Now() << "TelescopeClientDirectLx200::decReceived: " << dec_int << endl;
 #endif
 	const int lx200_status = 0;
-	sendPosition(last_ra, dec_int, lx200_status);
+	sendPosition(last_ra, static_cast<int>(dec_int), lx200_status);
 	queue_get_position = true;
 }
 
@@ -234,9 +254,9 @@ bool TelescopeClientDirectLx200::isInitialized(void) const
 void TelescopeClientDirectLx200::sendPosition(unsigned int ra_int, int dec_int, int status)
 {
 	//Server time is "now", because this class is the server
-	const qint64 server_micros = (qint64) getNow();
-	const double ra  =  ra_int * (M_PI/(unsigned int)0x80000000);
-	const double dec = dec_int * (M_PI/(unsigned int)0x80000000);
+	const qint64 server_micros = static_cast<qint64>(getNow());
+	const double ra  =  ra_int * (M_PI/0x80000000u);
+	const double dec = dec_int * (M_PI/0x80000000u);
 	const double cdec = cos(dec);
 	Vec3d position(cos(ra)*cdec, sin(ra)*cdec, sin(dec));
 	Vec3d j2000Position = position;
