@@ -71,6 +71,7 @@ void SlewDialog::createDialogContent()
 	connect(ui->radioButtonDecimal, SIGNAL(toggled(bool)), this, SLOT(setFormatDecimal(bool)));
 
 	connect(ui->pushButtonSlew, SIGNAL(clicked()), this, SLOT(slew()));
+	connect(ui->pushButtonSync, SIGNAL(clicked()), this, SLOT(sync()));
 	connect(ui->pushButtonConfigure, SIGNAL(clicked()), this, SLOT(showConfiguration()));
 
 	connect(telescopeManager, SIGNAL(clientConnected(int, QString)), this, SLOT(addTelescope(int, QString)));
@@ -219,10 +220,26 @@ void SlewDialog::slew()
 	if (!telescope)
 		return;
 
-	StelObjectP selectObject = nullptr;
+	StelObjectP selectObject = Q_NULLPTR;
 	telescope->telescopeGoto(targetPosition, selectObject);
 }
 
+void SlewDialog::sync()
+{
+	double radiansRA  = ui->spinBoxRA->valueRadians();
+	double radiansDec = ui->spinBoxDec->valueRadians();
+
+	Vec3d targetPosition;
+	StelUtils::spheToRect(radiansRA, radiansDec, targetPosition);
+
+	auto telescope = currentTelescope();
+	if (!telescope)
+		return;
+
+	StelObjectP selectObject = Q_NULLPTR;
+	telescope->telescopeSync(targetPosition, selectObject);
+}
+
 void SlewDialog::getCurrentObjectInfo()
 {
 	const QList<StelObjectP>& selected = GETSTELMODULE(StelObjectMgr)->getSelectedObject();
@@ -240,7 +257,7 @@ void SlewDialog::getCenterInfo()
 	StelCore *core = StelApp::getInstance().getCore();
 	const StelProjectorP projector = core->getProjection(StelCore::FrameEquinoxEqu);
 	Vec3d centerPosition;
-	Vec2f center = projector->getViewportCenter();
+	Vector2<qreal> center = projector->getViewportCenter();
 	projector->unProject(center[0], center[1], centerPosition);
 	double dec_j2000 = 0;
 	double ra_j2000 = 0;
@@ -251,7 +268,6 @@ void SlewDialog::getCenterInfo()
 
 void SlewDialog::editStoredPoints()
 {
-
 	storedPointsDialog->setVisible(true);
 	QVariantList qvl;
 	for (int i = 1;i< ui->comboBoxStoredPoints->count(); i++)
@@ -326,7 +342,7 @@ void SlewDialog::onCurrentTelescopeChanged()
 {
 	// remove previous controlWidget
 	QLayoutItem* child;
-	while ((child = ui->controlWidgetLayout->takeAt(0)) != 0)
+	while ((child = ui->controlWidgetLayout->takeAt(0)) != Q_NULLPTR)
 	{
 		delete child->widget();
 		delete child;
@@ -346,7 +362,7 @@ void SlewDialog::onCurrentTelescopeChanged()
 void SlewDialog::savePointsToFile()
 {
 	//Open/create the JSON file
-	QString pointsJsonPath = StelFileMgr::findFile("modules/TelescopeControl", (StelFileMgr::Flags)(StelFileMgr::Directory|StelFileMgr::Writable)) + "/points.json";
+	QString pointsJsonPath = StelFileMgr::findFile("modules/TelescopeControl", static_cast<StelFileMgr::Flags>(StelFileMgr::Directory|StelFileMgr::Writable)) + "/points.json";
 	if (pointsJsonPath.isEmpty())
 	{
 		qWarning() << "SlewDialog: Error saving points";
@@ -385,7 +401,7 @@ void SlewDialog::savePointsToFile()
 void SlewDialog::loadPointsFromFile()
 {
 	QVariantMap result;
-	QString pointsJsonPath = StelFileMgr::findFile("modules/TelescopeControl", (StelFileMgr::Flags)(StelFileMgr::Directory|StelFileMgr::Writable)) + "/points.json";
+	QString pointsJsonPath = StelFileMgr::findFile("modules/TelescopeControl", static_cast<StelFileMgr::Flags>(StelFileMgr::Directory|StelFileMgr::Writable)) + "/points.json";
 
 	if (pointsJsonPath.isEmpty())
 	{
