@@ -36,8 +36,9 @@ QMap<QString, QString> StelLocaleMgr::countryCodeToStringMap;
 StelLocaleMgr::StelLocaleMgr()
 	: skyTranslator(Q_NULLPTR)
 	, planetaryFeaturesTranslator(Q_NULLPTR)
+	, scriptsTranslator(Q_NULLPTR)
 	, timeFormat()
-	, dateFormat()	
+	, dateFormat()
 {
 	core = StelApp::getInstance().getCore();
 
@@ -57,6 +58,7 @@ StelLocaleMgr::StelLocaleMgr()
 		in >> countryCodeToStringMap;
 		file.close();
 	}
+	createNameLists();
 }
 
 
@@ -66,6 +68,8 @@ StelLocaleMgr::~StelLocaleMgr()
 	skyTranslator = Q_NULLPTR;
 	delete planetaryFeaturesTranslator;
 	planetaryFeaturesTranslator = Q_NULLPTR;
+	delete scriptsTranslator;
+	scriptsTranslator = Q_NULLPTR;
 }
 
 // Mehtod which generates and save the map between 2 letters country code and english country names
@@ -134,16 +138,23 @@ void StelLocaleMgr::setAppLanguage(const QString& newAppLanguageName, bool refre
 	delete StelTranslator::globalTranslator;
 	StelTranslator::globalTranslator = new StelTranslator("stellarium", newAppLanguageName);
 	qDebug() << "Application language is " << StelTranslator::globalTranslator->getTrueLocaleName();
+
+	delete scriptsTranslator;
+	// Update the translator with new locale name
+	scriptsTranslator = new StelTranslator("stellarium-scripts", newAppLanguageName);
+	qDebug() << "Scripts language is " << scriptsTranslator->getTrueLocaleName();
+
+	createNameLists();
 	if (refreshAll)
+	{
+
 		StelApp::getInstance().updateI18n();
+	}
 }
 
 bool StelLocaleMgr::isAppRTL() const
 {
-	bool rtl = false;
-	if (QString("ar fa ckb ug ur he yi").contains(getAppLanguage()))
-		rtl = true;
-	return rtl;
+	return QString("ar fa ckb ug ur he yi").contains(getAppLanguage());
 }
 
 /*************************************************************************
@@ -175,10 +186,7 @@ QString StelLocaleMgr::getSkyLanguage() const
 
 bool StelLocaleMgr::isSkyRTL() const
 {
-	bool rtl = false;
-	if (QString("ar fa ckb ug ur he yi").contains(getSkyLanguage()))
-		rtl = true;
-	return rtl;
+	return QString("ar fa ckb ug ur he yi").contains(getSkyLanguage());
 }
 
 // Get the StelTranslator currently used for sky objects.
@@ -197,6 +205,10 @@ const StelTranslator &StelLocaleMgr::getAppStelTranslator() const
 	return *StelTranslator::globalTranslator;
 }
 
+const StelTranslator& StelLocaleMgr::getScriptsTranslator() const
+{
+	return *scriptsTranslator;
+}
 
 // Return the time in ISO 8601 format that is : %Y-%m-%d %H:%M:%S
 QString StelLocaleMgr::getISO8601TimeLocal(double JD) const
@@ -214,7 +226,7 @@ double StelLocaleMgr::getJdFromISO8601TimeLocal(const QString& t, bool* ok) cons
 		qWarning() << "StelLocaleMgr::getJdFromISO8601TimeLocal: invalid ISO8601 date. Returning JD=0";
 		return 0.0;
 	}
-	
+
 	jd -= core->getUTCOffset(jd)*0.041666666666;
 	return jd;
 }
@@ -224,9 +236,9 @@ double StelLocaleMgr::getJdFromISO8601TimeLocal(const QString& t, bool* ok) cons
 QString StelLocaleMgr::getPrintableDateLocal(double JD) const
 {
 	int year, month, day, dayOfWeek;
-	double shift = core->getUTCOffset(JD)*0.041666666666;
+	const double shift = core->getUTCOffset(JD)*0.041666666666;
 	StelUtils::getDateFromJulianDay(JD+shift, &year, &month, &day);
-	dayOfWeek = (int)floor(fmod(JD, 7));
+	dayOfWeek = StelUtils::getDayOfWeek(year, month, day);
 	QString str;
 	switch (dateFormat)
 	{
@@ -239,6 +251,15 @@ QString StelLocaleMgr::getPrintableDateLocal(double JD) const
 		case SDateYYYYMMDD:
 			str = QString("%1-%2-%3").arg(year,4,10).arg(month,2,10,QLatin1Char('0')).arg(day,2,10,QLatin1Char('0'));
 			break;
+		case SDateWWMMDDYYYY:
+			str = QString("%1, %2-%3-%4").arg(shortDayName(dayOfWeek)).arg(month,2,10,QLatin1Char('0')).arg(day,2,10,QLatin1Char('0')).arg(year,4,10);
+			break;
+		case SDateWWDDMMYYYY:
+			str = QString("%1, %2-%3-%4").arg(shortDayName(dayOfWeek)).arg(day,2,10,QLatin1Char('0')).arg(month,2,10,QLatin1Char('0')).arg(year,4,10);
+			break;
+		case SDateWWYYYYMMDD:
+			str = QString("%1, %2-%3-%4").arg(shortDayName(dayOfWeek)).arg(year,4,10).arg(month,2,10,QLatin1Char('0')).arg(day,2,10,QLatin1Char('0'));
+			break;
 		case SDateSystemDefault:
 			str = StelUtils::localeDateString(year, month, day, dayOfWeek);
 			break;
@@ -253,13 +274,10 @@ QString StelLocaleMgr::getPrintableDateLocal(double JD) const
 // according to the timeFormat variable
 QString StelLocaleMgr::getPrintableTimeLocal(double JD) const
 {
-	int hour, minute, second;
-	double shift = core->getUTCOffset(JD)*0.041666666666;
-
-	StelUtils::getTimeFromJulianDay(JD+shift, &hour, &minute, &second);
-
-	QTime t(hour, minute, second);
-
+	int hour, minute, second, millsec;
+	const double shift = core->getUTCOffset(JD)*0.041666666666;
+	StelUtils::getTimeFromJulianDay(JD+shift, &hour, &minute, &second, &millsec);
+	QTime t(hour, minute, second, millsec);
 	switch (timeFormat)
 	{
 		case STimeSystemDefault:
@@ -270,17 +288,17 @@ QString StelLocaleMgr::getPrintableTimeLocal(double JD) const
 			return t.toString("hh:mm:ss AP");
 		default:
 			qWarning() << "WARNING: unknown time format, fallback to system default";
-			return t.toString(Qt::LocaleDate);
+			return t.toString(Qt::DefaultLocaleShortDate);
 	}
 }
 
 QString StelLocaleMgr::getPrintableTimeZoneLocal(double JD) const
 {
+	QString timeZone = "";
+	QString timeZoneST = "";
 	if (core->getCurrentLocation().planetName=="Earth")
 	{
-		QString timeZone = "";
 		QString currTZ = core->getCurrentTimeZone();
-		QString timeZoneST = "";
 
 		if (JD<=StelCore::TZ_ERA_BEGINNING || currTZ.contains("auto") || currTZ.contains("LMST"))
 		{
@@ -294,82 +312,90 @@ QString StelLocaleMgr::getPrintableTimeZoneLocal(double JD) const
 			timeZoneST = qc_("LTST", "solar time");
 		}
 
-		float shift = core->getUTCOffset(JD);		
-		QTime tz = QTime(0, 0, 0).addSecs(3600*qAbs(shift));
-		if(shift<0.0f)
+		const double shift = core->getUTCOffset(JD);
+		QTime tz = QTime(0, 0, 0).addSecs(static_cast<int>(3600*qAbs(shift)));
+		if(shift<0.0)
 			timeZone = QString("UTC-%1").arg(tz.toString("hh:mm"));
 		else
 			timeZone = QString("UTC+%1").arg(tz.toString("hh:mm"));
 
 		if (!timeZoneST.isEmpty() && !core->getUseCustomTimeZone())
 			timeZone = QString("%1 (%2)").arg(timeZone, timeZoneST);
-
-		return timeZone;
 	}
 	else
-		return QString();
+	{
+		// TODO: Make sure LMST/LTST would make sense on other planet, or inhibit it?
+		const double shift = core->getUTCOffset(JD);
+		QTime tz = QTime(0, 0, 0).addSecs(static_cast<int>(3600*qAbs(shift)));
+		if(shift<0.0)
+			timeZone = QString("UTC-%1").arg(tz.toString("hh:mm"));
+		else
+			timeZone = QString("UTC+%1").arg(tz.toString("hh:mm"));
+
+		//if (!timeZoneST.isEmpty() && !core->getUseCustomTimeZone())
+		//	timeZone = QString("%1 (%2)").arg(timeZone, timeZoneST);
+	}
+	return timeZone;
 }
 
 // Convert the time format enum to its associated string and reverse
-StelLocaleMgr::STimeFormat StelLocaleMgr::stringToSTimeFormat(const QString& tf) const
+StelLocaleMgr::STimeFormat StelLocaleMgr::stringToSTimeFormat(const QString& tf)
 {
-	if (tf == "system_default") return STimeSystemDefault;
-	if (tf == "24h") return STime24h;
-	if (tf == "12h") return STime12h;
-	qWarning() << "WARNING: unrecognized time_display_format : " << tf << " system_default used.";
-	return STimeSystemDefault;
+	static const QMap<QString, StelLocaleMgr::STimeFormat> map = {
+		{"system_default", STimeSystemDefault},
+		{"24h", STime24h},
+		{"12h", STime12h}};
+	if (!map.contains(tf))
+		qWarning() << "WARNING: unrecognized time_display_format : " << tf << " system_default used.";
+	return map.value(tf, STimeSystemDefault);
 }
 
-QString StelLocaleMgr::sTimeFormatToString(STimeFormat tf) const
+QString StelLocaleMgr::sTimeFormatToString(STimeFormat tf)
 {
-	if (tf == STimeSystemDefault) return "system_default";
-	if (tf == STime24h) return "24h";
-	if (tf == STime12h) return "12h";
-	qWarning() << "WARNING: unrecognized time_display_format value : " << (int)tf << " system_default used.";
-	return "system_default";
+	static const QStringList tfmt={"system_default", "24h", "12h"};
+	return tfmt[tf];
 }
 
 // Convert the date format enum to its associated string and reverse
-StelLocaleMgr::SDateFormat StelLocaleMgr::stringToSDateFormat(const QString& df) const
+StelLocaleMgr::SDateFormat StelLocaleMgr::stringToSDateFormat(const QString& df)
 {
-	if (df == "system_default") return SDateSystemDefault;
-	if (df == "mmddyyyy") return SDateMMDDYYYY;
-	if (df == "ddmmyyyy") return SDateDDMMYYYY;
-	if (df == "yyyymmdd") return SDateYYYYMMDD;  // iso8601
-	qWarning() << "WARNING: unrecognized date_display_format : " << df << " system_default used.";
-	return SDateSystemDefault;
+	static const QMap<QString, StelLocaleMgr::SDateFormat> map = {
+		{"system_default", SDateSystemDefault},
+		{"mmddyyyy",       SDateMMDDYYYY},
+		{"ddmmyyyy",       SDateDDMMYYYY},
+		{"yyyymmdd",       SDateYYYYMMDD}, // iso8601
+		{"wwmmddyyyy",     SDateWWMMDDYYYY},
+		{"wwddmmyyyy",     SDateWWDDMMYYYY},
+		{"wwyyyymmdd",     SDateWWYYYYMMDD}};
+	if (!map.contains(df))
+		qWarning() << "WARNING: unrecognized date_display_format : " << df << " system_default used.";
+	return map.value(df, SDateSystemDefault);
 }
 
-QString StelLocaleMgr::sDateFormatToString(SDateFormat df) const
+QString StelLocaleMgr::sDateFormatToString(SDateFormat df)
 {
-	if (df == SDateSystemDefault) return "system_default";
-	if (df == SDateMMDDYYYY) return "mmddyyyy";
-	if (df == SDateDDMMYYYY) return "ddmmyyyy";
-	if (df == SDateYYYYMMDD) return "yyyymmdd";
-	qWarning() << "WARNING: unrecognized date_display_format value : " << (int)df << " system_default used.";
-	return "system_default";
+	QStringList dfmt = {
+		"system_default",
+		"mmddyyyy",
+		"ddmmyyyy",
+		"yyyymmdd",
+		"wwddmmyyyy",
+		"wwddmmyyyy",
+		"wwyyyymmdd"};
+	return dfmt[df];
 }
 
 QString StelLocaleMgr::getQtDateFormatStr() const
 {
-	QString dfmt;
-	switch (dateFormat) {
-		case SDateDDMMYYYY:
-			dfmt = "dd.MM.yyyy";
-			break;
-		case SDateMMDDYYYY:
-			dfmt = "MM.dd.yyyy";
-			break;
-		case SDateYYYYMMDD:
-		case SDateSystemDefault:
-			dfmt = "yyyy.MM.dd";
-			break;
-		default:
-			qWarning() << "WARNING: unknown date format, fallback to system default";
-			dfmt = "yyyy.MM.dd";
-			break;
-	}
-	return dfmt;
+	QStringList dfmt = {
+		"yyyy.MM.dd",
+		"MM.dd.yyyy",
+		"dd.MM.yyyy",
+		"yyyy.MM.dd",
+		"ddd, MM.dd.yyyy",
+		"ddd, dd.MM.yyyy",
+		"ddd, yyyy.MM.dd"};
+	return dfmt[dateFormat];
 }
 
 // Convert a 2 letter country code to string
@@ -390,9 +416,124 @@ QString StelLocaleMgr::countryNameToCode(const QString& countryName)
 QStringList StelLocaleMgr::getAllCountryNames()
 {
 	QStringList res;
-	for (QMap<QString, QString>::ConstIterator i = countryCodeToStringMap.constBegin();i!=countryCodeToStringMap.constEnd();++i)
-		res.append(i.value());
+	//for (QMap<QString, QString>::ConstIterator i = countryCodeToStringMap.constBegin();i!=countryCodeToStringMap.constEnd();++i)
+	//	res.append(i.value());
+	res=countryCodeToStringMap.values();
 	res.sort();
 	return res;
 }
 
+QString StelLocaleMgr::shortDayName(int weekday)
+{
+	Q_ASSERT(weekday>=0);
+	Q_ASSERT(shortWeekDays.length()==7);
+	return shortWeekDays[weekday % 7];
+}
+
+QString StelLocaleMgr::longDayName(int weekday)
+{
+	Q_ASSERT(weekday>=0);
+	Q_ASSERT(longWeekDays.length()==7);
+	return longWeekDays[weekday % 7];
+}
+
+QString StelLocaleMgr::shortMonthName(int month)
+{
+	Q_ASSERT(month >= 0);
+	Q_ASSERT(shortMonthNames.length()==12);
+	return shortMonthNames[month % 12];
+}
+
+QString StelLocaleMgr::longMonthName(int month)
+{
+	Q_ASSERT(month >= 0);
+	Q_ASSERT(longMonthNames.length()==12);
+	return longMonthNames[month % 12];
+}
+
+QString StelLocaleMgr::longGenitiveMonthName(int month)
+{
+	Q_ASSERT(month >= 0);
+	Q_ASSERT(longGenitiveMonthNames.length()==12);
+	return longGenitiveMonthNames[month % 12];
+}
+
+QString StelLocaleMgr::romanMonthName(int month)
+{
+	Q_ASSERT(month >= 0);
+	static const QStringList romanMonths = { "XII", "I", "II", "III", "IV", "V", "VI", "VII", "VIII", "IX", "X", "XI"};
+	return romanMonths[month % 12];
+}
+
+
+void StelLocaleMgr::createNameLists()
+{
+	shortWeekDays.clear();
+	shortWeekDays
+		<< qc_("Sun", "short day name")
+		<< qc_("Mon", "short day name")
+		<< qc_("Tue", "short day name")
+		<< qc_("Wed", "short day name")
+		<< qc_("Thu", "short day name")
+		<< qc_("Fri", "short day name")
+		<< qc_("Sat", "short day name");
+	longWeekDays.clear();
+	longWeekDays
+		<< qc_("Sunday",    "long day name")
+		<< qc_("Monday",    "long day name")
+		<< qc_("Tuesday",   "long day name")
+		<< qc_("Wednesday", "long day name")
+		<< qc_("Thursday",  "long day name")
+		<< qc_("Friday",    "long day name")
+		<< qc_("Saturday",  "long day name");
+
+	shortMonthNames.clear();
+	shortMonthNames
+		<< qc_("Dec", "short month name")
+		<< qc_("Jan", "short month name")
+		<< qc_("Feb", "short month name")
+		<< qc_("Mar", "short month name")
+		<< qc_("Apr", "short month name")
+		<< qc_("May", "short month name")
+		<< qc_("Jun", "short month name")
+		<< qc_("Jul", "short month name")
+		<< qc_("Aug", "short month name")
+		<< qc_("Sep", "short month name")
+		<< qc_("Oct", "short month name")
+		<< qc_("Nov", "short month name");
+
+	longMonthNames.clear();
+	longMonthNames
+		<< qc_("December",  "long month name")
+		<< qc_("January",   "long month name")
+		<< qc_("February",  "long month name")
+		<< qc_("March",     "long month name")
+		<< qc_("April",     "long month name")
+		<< qc_("May",       "long month name")
+		<< qc_("June",      "long month name")
+		<< qc_("July",      "long month name")
+		<< qc_("August",    "long month name")
+		<< qc_("September", "long month name")
+		<< qc_("October",   "long month name")
+		<< qc_("November",  "long month name");
+	longGenitiveMonthNames.clear();
+	longGenitiveMonthNames
+		<< qc_("December",  "genitive")
+		<< qc_("January",   "genitive")
+		<< qc_("February",  "genitive")
+		<< qc_("March",     "genitive")
+		<< qc_("April",     "genitive")
+		<< qc_("May",       "genitive")
+		<< qc_("June",      "genitive")
+		<< qc_("July",      "genitive")
+		<< qc_("August",    "genitive")
+		<< qc_("September", "genitive")
+		<< qc_("October",   "genitive")
+		<< qc_("November",  "genitive");
+}
+
+QStringList StelLocaleMgr::shortWeekDays;
+QStringList StelLocaleMgr::longWeekDays;
+QStringList StelLocaleMgr::shortMonthNames;
+QStringList StelLocaleMgr::longMonthNames;
+QStringList StelLocaleMgr::longGenitiveMonthNames;
