@@ -74,6 +74,9 @@ public:
 	//! Get a reference to the StelTranslator object currently used for planetary features.
 	const StelTranslator &getPlanetaryFeaturesTranslator() const;
 
+	//! Get a reference to the StelTranslator object currently used for scripts.
+	const StelTranslator &getScriptsTranslator() const;
+
 	//! Get the type (RTL or LTR) of language currently used for sky objects
 	bool isSkyRTL() const;
 	
@@ -108,18 +111,21 @@ public:
 	//! @enum STimeFormat
 	//! The time display format.
 	enum STimeFormat {
+		STimeSystemDefault,	//!< use the system default format.
 		STime24h,		//!< 24 hour clock, e.g. "18:22:00"
-		STime12h,		//!< 12 hour clock, e.g. "06:22:00 pm"
-  		STimeSystemDefault	//!< use the system default format.
+		STime12h		//!< 12 hour clock, e.g. "06:22:00 pm"
 	};
 	
 	//! @enum SDateFormat
 	//! The date display format.
 	enum SDateFormat {
+		SDateSystemDefault,	//!< Use the system default date format
 		SDateMMDDYYYY,		//!< e.g. "07-05-1998" for July 5th 1998
 		SDateDDMMYYYY,		//!< e.g. "05-07-1998" for July 5th 1998
-		SDateSystemDefault,	//!< Use the system default date format
-		SDateYYYYMMDD		//!< e.g. "1998-07-05" for July 5th 1998
+		SDateYYYYMMDD,		//!< e.g. "1998-07-05" for July 5th 1998
+		SDateWWMMDDYYYY,	//!< e.g. "Sun, 07-05-1998" for Sunday, July 5th 1998
+		SDateWWDDMMYYYY,	//!< e.g. "Sun, 05-07-1998" for Sunday, July 5th 1998
+		SDateWWYYYYMMDD		//!< e.g. "Sun, 1998-07-05" for Sunday, July 5th 1998
 	};
 	
 	//! Get a localized, formatted string representation of the date component of a Julian date.
@@ -149,11 +155,33 @@ public:
 
 	//! Return an alphabetically ordered list of all the known country names
 	static QStringList getAllCountryNames();
+
+	//! Returns the short name of the \a weekday [0=Sunday, 1=Monday..6]; weekday mod 7)
+	static QString shortDayName(int weekday);
+
+	//! Returns the long name of the \a weekday ([0..6]; weekday mod 7)
+	static QString longDayName(int weekday);
+
+	//! Returns the short name of the \a month [1..12]
+	static QString shortMonthName(int month);
+
+	//! Returns the long name of the \a month [1..12]
+	static QString longMonthName(int month);
+
+	//! Returns the genitive long name of the \a month [1..12]
+	static QString longGenitiveMonthName(int month);
+
+	//! Returns the Roman name (a number) of the \a month [1..12]
+	static QString romanMonthName(int month);
 	
 private:
+	//! fill the class-inherent lists with translated names for weekdays, month names etc. in the current language.
+	//! Call this at program start and then after each language change.
+	static void createNameLists();
 	// The translator used for astronomical object naming
 	StelTranslator* skyTranslator;
 	StelTranslator* planetaryFeaturesTranslator;
+	StelTranslator* scriptsTranslator;
 	StelCore* core;
 	
 	// Date and time variables
@@ -161,15 +189,22 @@ private:
 	SDateFormat dateFormat;
 
 	// Convert the time format enum to its associated string and reverse
-	STimeFormat stringToSTimeFormat(const QString&) const;
-	QString sTimeFormatToString(STimeFormat) const;
+	static STimeFormat stringToSTimeFormat(const QString&);
+	static QString sTimeFormatToString(STimeFormat);
 	
 	// Convert the date format enum to its associated string and reverse
-	SDateFormat stringToSDateFormat(const QString& df) const;
-	QString sDateFormatToString(SDateFormat df) const;
+	static SDateFormat stringToSDateFormat(const QString& df);
+	static QString sDateFormatToString(SDateFormat df);
 	
 	static QMap<QString, QString> countryCodeToStringMap;
 	
+	// Lists for rapid access. These must be recreated on language change by createNameLists().
+	static QStringList shortWeekDays;
+	static QStringList longWeekDays;
+	static QStringList shortMonthNames;
+	static QStringList longMonthNames;
+	static QStringList longGenitiveMonthNames;
+
 	static void generateCountryList();
 };
 
