@@ -63,7 +63,7 @@ QString StelLocation::getID() const
 		return name;
 }
 
-// GZ TODO: These operators may require the sanitizing for timezone names!
+// GZ TODO: These operators may require sanitizing for timezone names!
 QDataStream& operator<<(QDataStream& out, const StelLocation& loc)
 {
 	out << loc.name << loc.state << loc.country << loc.role << loc.population << loc.latitude << loc.longitude << loc.altitude << loc.bortleScaleIndex << loc.ianaTimeZone << loc.planetName << loc.landscapeKey << loc.isUserLocation;
@@ -90,7 +90,7 @@ StelLocation StelLocation::createFromLine(const QString& rawline)
 	loc.role    = splitline.at(3).at(0).toUpper();
 	if (loc.role.isNull())
 		loc.role = QChar(0x0058); // char 'X'
-	loc.population = (int) (splitline.at(4).toFloat()*1000);
+	loc.population = static_cast<int> (splitline.at(4).toFloat()*1000);
 
 	const QString& latstring = splitline.at(5).trimmed();
 	loc.latitude = latstring.left(latstring.size() - 1).toFloat();
@@ -102,7 +102,7 @@ StelLocation StelLocation::createFromLine(const QString& rawline)
 	if (lngstring.endsWith('W'))
 		loc.longitude=-loc.longitude;
 
-	loc.altitude = (int)splitline.at(7).toFloat();
+	loc.altitude = static_cast<int>(splitline.at(7).toFloat());
 
 	if (splitline.size()>8)
 	{
@@ -150,7 +150,7 @@ StelLocation StelLocation::createFromLine(const QString& rawline)
 // Compute great-circle distance between two locations
 float StelLocation::distanceDegrees(const float long1, const float lat1, const float long2, const float lat2)
 {
-	const float DEGREES=M_PI/180.0f;
+	const float DEGREES=M_PIf/180.0f;
 	return std::acos( std::sin(lat1*DEGREES)*std::sin(lat2*DEGREES) +
 			  std::cos(lat1*DEGREES)*std::cos(lat2*DEGREES) *
 			  std::cos((long1-long2)*DEGREES) ) / DEGREES;
