@@ -36,7 +36,7 @@
 #include <QDebug>
 #include <QStringList>
 
-StelObjectMgr::StelObjectMgr() : objectPointerVisibility(true), searchRadiusPixel(25.f), distanceWeight(1.f)
+StelObjectMgr::StelObjectMgr() : objectPointerVisibility(true), searchRadiusPixel(25.), distanceWeight(1.f)
 {
 	setObjectName("StelObjectMgr");
 }
@@ -55,6 +55,9 @@ void StelObjectMgr::init()
 	actionsMgr->addAction("actionNext_Transit", timeGroup, N_("Next transit of the selected object"), this, "nextTransit()");
 	actionsMgr->addAction("actionNext_Rising", timeGroup, N_("Next rising of the selected object"), this, "nextRising()");
 	actionsMgr->addAction("actionNext_Setting", timeGroup, N_("Next setting of the selected object"), this, "nextSetting()");
+	actionsMgr->addAction("actionToday_Transit", timeGroup, N_("Today's transit of the selected object"), this, "todayTransit()");
+	actionsMgr->addAction("actionToday_Rising", timeGroup, N_("Today's rising of the selected object"), this, "todayRising()");
+	actionsMgr->addAction("actionToday_Setting", timeGroup, N_("Today's setting of the selected object"), this, "todaySetting()");
 	actionsMgr->addAction("actionPrevious_Transit", timeGroup, N_("Previous transit of the selected object"), this, "previousTransit()");
 	actionsMgr->addAction("actionPrevious_Rising", timeGroup, N_("Previous rising of the selected object"), this, "previousRising()");
 	actionsMgr->addAction("actionPrevious_Setting", timeGroup, N_("Previous setting of the selected object"), this, "previousSetting()");
@@ -62,20 +65,20 @@ void StelObjectMgr::init()
 
 void StelObjectMgr::nextTransit()
 {
-	const QList<StelObjectP> selected = GETSTELMODULE(StelObjectMgr)->getSelectedObject();
+	const QList<StelObjectP> selected = getSelectedObject();
 	if (!selected.isEmpty() && selected[0]->getType()!="Satellite")
 	{
 		StelCore* core = StelApp::getInstance().getCore();
 		core->addSolarDays(1.0);
 		double JD = core->getJD();
 		Vec3f rts = selected[0]->getRTSTime(core);
-		core->setJD(static_cast<int>(JD) + rts[1]/24. - core->getUTCOffset(JD) / 24. + 0.5);
+		core->setJD(static_cast<int>(JD) + static_cast<double>(rts[1]/24.f - core->getUTCOffset(JD) / 24.f + 0.5f));
 	}
 }
 
 void StelObjectMgr::nextRising()
 {
-	const QList<StelObjectP> selected = GETSTELMODULE(StelObjectMgr)->getSelectedObject();
+	const QList<StelObjectP> selected = getSelectedObject();
 	if (!selected.isEmpty() && selected[0]->getType()!="Satellite")
 	{
 		StelCore* core = StelApp::getInstance().getCore();
@@ -83,13 +86,13 @@ void StelObjectMgr::nextRising()
 		double JD = core->getJD();
 		Vec3f rts = selected[0]->getRTSTime(core);
 		if (rts[0]>-99.f && rts[0]<100.f)
-			core->setJD(static_cast<int>(JD) + rts[0]/24. - core->getUTCOffset(JD) / 24. + 0.5);
+			core->setJD(static_cast<int>(JD) + static_cast<double>(rts[0]/24.f - core->getUTCOffset(JD) / 24.f + 0.5f));
 	}
 }
 
 void StelObjectMgr::nextSetting()
 {
-	const QList<StelObjectP> selected = GETSTELMODULE(StelObjectMgr)->getSelectedObject();
+	const QList<StelObjectP> selected = getSelectedObject();
 	if (!selected.isEmpty() && selected[0]->getType()!="Satellite")
 	{
 		StelCore* core = StelApp::getInstance().getCore();
@@ -97,26 +100,26 @@ void StelObjectMgr::nextSetting()
 		double JD = core->getJD();
 		Vec3f rts = selected[0]->getRTSTime(core);
 		if (rts[2]>-99.f && rts[2]<100.f)
-			core->setJD(static_cast<int>(JD) + rts[2]/24. - core->getUTCOffset(JD) / 24. + 0.5);
+			core->setJD(static_cast<int>(JD) + static_cast<double>(rts[2]/24.f - core->getUTCOffset(JD) / 24.f + 0.5f));
 	}
 }
 
 void StelObjectMgr::previousTransit()
 {
-	const QList<StelObjectP> selected = GETSTELMODULE(StelObjectMgr)->getSelectedObject();
+	const QList<StelObjectP> selected = getSelectedObject();
 	if (!selected.isEmpty() && selected[0]->getType()!="Satellite")
 	{
 		StelCore* core = StelApp::getInstance().getCore();
 		core->addSolarDays(-1.0);
 		double JD = core->getJD();
 		Vec3f rts = selected[0]->getRTSTime(core);
-		core->setJD(static_cast<int>(JD) + rts[1]/24. - core->getUTCOffset(JD) / 24. + 0.5);
+		core->setJD(static_cast<int>(JD) + static_cast<double>(rts[1]/24.f - core->getUTCOffset(JD) / 24.f + 0.5f));
 	}
 }
 
 void StelObjectMgr::previousRising()
 {
-	const QList<StelObjectP> selected = GETSTELMODULE(StelObjectMgr)->getSelectedObject();
+	const QList<StelObjectP> selected = getSelectedObject();
 	if (!selected.isEmpty() && selected[0]->getType()!="Satellite")
 	{
 		StelCore* core = StelApp::getInstance().getCore();
@@ -124,13 +127,13 @@ void StelObjectMgr::previousRising()
 		double JD = core->getJD();
 		Vec3f rts = selected[0]->getRTSTime(core);
 		if (rts[0]>-99.f && rts[0]<100.f)
-			core->setJD(static_cast<int>(JD) + rts[0]/24. - core->getUTCOffset(JD) / 24. + 0.5);
+			core->setJD(static_cast<int>(JD) + static_cast<double>(rts[0]/24.f - core->getUTCOffset(JD) / 24.f + 0.5f));
 	}
 }
 
 void StelObjectMgr::previousSetting()
 {
-	const QList<StelObjectP> selected = GETSTELMODULE(StelObjectMgr)->getSelectedObject();
+	const QList<StelObjectP> selected = getSelectedObject();
 	if (!selected.isEmpty() && selected[0]->getType()!="Satellite")
 	{
 		StelCore* core = StelApp::getInstance().getCore();
@@ -138,7 +141,45 @@ void StelObjectMgr::previousSetting()
 		double JD = core->getJD();
 		Vec3f rts = selected[0]->getRTSTime(core);
 		if (rts[2]>-99.f && rts[2]<100.f)
-			core->setJD(static_cast<int>(JD) + rts[2]/24. - core->getUTCOffset(JD) / 24. + 0.5);
+			core->setJD(static_cast<int>(JD) + static_cast<double>(rts[2]/24.f - core->getUTCOffset(JD) / 24.f + 0.5f));
+	}
+}
+
+void StelObjectMgr::todayTransit()
+{
+	const QList<StelObjectP> selected = getSelectedObject();
+	if (!selected.isEmpty() && selected[0]->getType()!="Satellite")
+	{
+		StelCore* core = StelApp::getInstance().getCore();
+		double JD = core->getJD();
+		Vec3f rts = selected[0]->getRTSTime(core);
+		core->setJD(static_cast<int>(JD) + static_cast<double>(rts[1]/24.f - core->getUTCOffset(JD) / 24.f + 0.5f));
+	}
+}
+
+void StelObjectMgr::todayRising()
+{
+	const QList<StelObjectP> selected = getSelectedObject();
+	if (!selected.isEmpty() && selected[0]->getType()!="Satellite")
+	{
+		StelCore* core = StelApp::getInstance().getCore();
+		double JD = core->getJD();
+		Vec3f rts = selected[0]->getRTSTime(core);
+		if (rts[0]>-99.f && rts[0]<100.f)
+			core->setJD(static_cast<int>(JD) + static_cast<double>(rts[0]/24.f - core->getUTCOffset(JD) / 24.f + 0.5f));
+	}
+}
+
+void StelObjectMgr::todaySetting()
+{
+	const QList<StelObjectP> selected = getSelectedObject();
+	if (!selected.isEmpty() && selected[0]->getType()!="Satellite")
+	{
+		StelCore* core = StelApp::getInstance().getCore();
+		double JD = core->getJD();
+		Vec3f rts = selected[0]->getRTSTime(core);
+		if (rts[2]>-99.f && rts[2]<100.f)
+			core->setJD(static_cast<int>(JD) + static_cast<double>(rts[2]/24.f - core->getUTCOffset(JD) / 24.f + 0.5f));
 	}
 }
 
@@ -147,7 +188,7 @@ void StelObjectMgr::previousSetting()
 *************************************************************************/
 void StelObjectMgr::registerStelObjectMgr(StelObjectModule* m)
 {
-	objectsModule.push_back(m);
+	objectsModules.push_back(m);
 	typeToModuleMap.insert(m->getStelObjectType(),m);
 
 	objModulesMap.insert(m->objectName(), m->getName());
@@ -231,6 +272,8 @@ void StelObjectMgr::registerStelObjectMgr(StelObjectModule* m)
 		objModulesMap["NebulaMgr:121"] = "Hickson Compact Group";
 		objModulesMap["NebulaMgr:122"] = "Abell Catalog of Planetary Nebulae";
 		objModulesMap["NebulaMgr:123"] = "ESO/Uppsala Survey of the ESO(B) Atlas";
+		objModulesMap["NebulaMgr:124"] = "Catalogue of southern stars embedded in nebulosity";
+		objModulesMap["NebulaMgr:125"] = "Catalogue and distances of optically visible H II regions";
 		objModulesMap["NebulaMgr:150"] = "Dwarf galaxies";
 		objModulesMap["NebulaMgr:151"] = "Herschel 400 Catalogue";
 		objModulesMap["NebulaMgr:152"] = "Jack Bennett's deep sky catalogue";
@@ -354,7 +397,7 @@ void StelObjectMgr::registerStelObjectMgr(StelObjectModule* m)
 StelObjectP StelObjectMgr::searchByNameI18n(const QString &name) const
 {
 	StelObjectP rval;
-	for (const auto* m : objectsModule)
+	for (const auto* m : objectsModules)
 	{
 		rval = m->searchByNameI18n(name);
 		if (rval)
@@ -367,7 +410,7 @@ StelObjectP StelObjectMgr::searchByNameI18n(const QString &name) const
 StelObjectP StelObjectMgr::searchByName(const QString &name) const
 {
 	StelObjectP rval;
-	for (const auto* m : objectsModule)
+	for (const auto* m : objectsModules)
 	{
 		rval = m->searchByName(name);
 		if (rval)
@@ -429,16 +472,14 @@ bool StelObjectMgr::findAndSelect(const StelCore* core, int x, int y, StelModule
 // Find an object in a "clever" way, v in J2000 frame
 StelObjectP StelObjectMgr::cleverFind(const StelCore* core, const Vec3d& v) const
 {
-	StelObjectP sobj;
-	QList<StelObjectP> candidates;
-
 	const StelProjectorP prj = core->getProjection(StelCore::FrameJ2000);
 
 	// Field of view for a searchRadiusPixel pixel diameter circle on screen
-	float fov_around = core->getMovementMgr()->getCurrentFov()/qMin(prj->getViewportWidth(), prj->getViewportHeight()) * searchRadiusPixel;
+	const double fov_around = core->getMovementMgr()->getCurrentFov()/qMin(prj->getViewportWidth(), prj->getViewportHeight()) * searchRadiusPixel;
 
 	// Collect the objects inside the range
-	for (const auto* m : objectsModule)
+	QList<StelObjectP> candidates;
+	for (const auto* m : objectsModules)
 		candidates += m->searchAround(v, fov_around, core);
 
 	// GZ 2014-08-17: This should be exactly the sky's limit magnitude (or even more, but not less!), else visible stars cannot be clicked.
@@ -449,21 +490,20 @@ StelObjectP StelObjectMgr::cleverFind(const StelCore* core, const Vec3d& v) cons
 		if (obj->getSelectPriority(core)<=limitMag)
 			tmp.append(obj);
 	}
-	
 	candidates = tmp;
 	
 	// Now select the object minimizing the function y = distance(in pixel) + magnitude
 	Vec3d winpos;
 	prj->project(v, winpos);
-	float xpos = winpos[0];
-	float ypos = winpos[1];
+	const double xpos = winpos[0];
+	const double ypos = winpos[1];
 
-	float best_object_value;
-	best_object_value = 100000.f;
+	StelObjectP sobj;
+	float best_object_value = 100000.f;
 	for (const auto& obj : candidates)
 	{
 		prj->project(obj->getJ2000EquatorialPos(core), winpos);
-		float distance = std::sqrt((xpos-winpos[0])*(xpos-winpos[0]) + (ypos-winpos[1])*(ypos-winpos[1]))*distanceWeight;
+		float distance = static_cast<float>(std::sqrt((xpos-winpos[0])*(xpos-winpos[0]) + (ypos-winpos[1])*(ypos-winpos[1])))*distanceWeight;
 		float priority =  obj->getSelectPriority(core);
 		// qDebug() << (*iter).getShortInfoString(core) << ": " << priority << " " << distance;
 		if (distance + priority < best_object_value)
@@ -488,8 +528,8 @@ StelObjectP StelObjectMgr::cleverFind(const StelCore* core, int x, int y) const
 		// Nick Fedoseev patch: improve click match for refracted coordinates
 		Vec3d win;
 		prj->project(v,win);
-		float dx = x - win.v[0];
-		float dy = y - win.v[1];
+		const double dx = x - win.v[0];
+		const double dy = y - win.v[1];
 		prj->unProject(x+dx, y+dy, v);
 
 		return cleverFind(core, v);
@@ -557,7 +597,7 @@ QList<StelObjectP> StelObjectMgr::getSelectedObject(const QString& type) const
 /*****************************************************************************************
  Find and return the list of at most maxNbItem objects auto-completing passed object name
 *******************************************************************************************/
-QStringList StelObjectMgr::listMatchingObjects(const QString& objPrefix, unsigned int maxNbItem, bool useStartOfWords, bool inEnglish) const
+QStringList StelObjectMgr::listMatchingObjects(const QString& objPrefix, int maxNbItem, bool useStartOfWords, bool inEnglish) const
 {
 	QStringList result;
 	if (maxNbItem <= 0)
@@ -566,7 +606,7 @@ QStringList StelObjectMgr::listMatchingObjects(const QString& objPrefix, unsigne
 	}
 
 	// For all StelObjectmodules..
-	for (const auto* m : objectsModule)
+	for (const auto* m : objectsModules)
 	{
 		// Get matching object for this module
 		QStringList matchingObj = m->listMatchingObjects(objPrefix, maxNbItem, useStartOfWords, inEnglish);
@@ -594,7 +634,7 @@ QStringList StelObjectMgr::listAllModuleObjects(const QString &moduleId, bool in
 	}
 	else
 		objModule = moduleId;
-	for (auto* m : objectsModule)
+	for (auto* m : objectsModules)
 	{
 		if (m->objectName() == objModule)
 		{
