@@ -93,7 +93,6 @@ StelOpenGLArray::StelOpenGLArray()
 	  m_types(),
 	  m_strides()
 {
-
 }
 
 StelOpenGLArray::~StelOpenGLArray()
@@ -159,8 +158,8 @@ bool StelOpenGLArray::load(const StelOBJ* obj, bool useTangents)
 		if(useTangents)
 		{
 			//we can simply upload the whole vertex data in a single call
-			m_vertexBuffer.allocate(vertices.constData(), sizeof(StelOBJ::Vertex) * vertices.size());
-			m_memoryUsage+=sizeof(StelOBJ::Vertex) * vertices.size();
+			m_vertexBuffer.allocate(vertices.constData(), static_cast<int>(sizeof(StelOBJ::Vertex)) * vertices.size());
+			m_memoryUsage+=sizeof(StelOBJ::Vertex) * static_cast<size_t>(vertices.size());
 
 			//setup vtx format
 			for (int i = 0;i<=ATTLOC_BITANGENT;++i)
@@ -187,7 +186,7 @@ bool StelOpenGLArray::load(const StelOBJ* obj, bool useTangents)
 			const int vtxSize = sizeof(GLfloat) * 8;
 			//alloc data but dont upload
 			m_vertexBuffer.allocate(vertices.size() * vtxSize);
-			m_memoryUsage+=vertices.size() * vtxSize;
+			m_memoryUsage+=static_cast<size_t>(vertices.size() * vtxSize);
 			for(int i =0;i<vertices.size();++i)
 			{
 				//copy the first 8 floats from each vertex
@@ -225,7 +224,7 @@ bool StelOpenGLArray::load(const StelOBJ* obj, bool useTangents)
 			m_indexBufferType = GL_UNSIGNED_SHORT;
 			m_indexBufferTypeSize = sizeof(GLushort);
 			const StelOBJ::ShortIndexList idxList = obj->getShortIndexList();
-			m_indexBuffer.allocate(idxList.constData(),static_cast<int>(m_indexBufferTypeSize * idxList.size()));
+			m_indexBuffer.allocate(idxList.constData(),static_cast<int>(m_indexBufferTypeSize) * idxList.size());
 		}
 		else
 		{
@@ -241,10 +240,10 @@ bool StelOpenGLArray::load(const StelOBJ* obj, bool useTangents)
 			m_indexBufferTypeSize = sizeof(GLuint);
 
 			const StelOBJ::IndexList& idxList = obj->getIndexList();
-			m_indexBuffer.allocate(idxList.constData(),static_cast<int>(m_indexBufferTypeSize * idxList.size()));
+			m_indexBuffer.allocate(idxList.constData(),static_cast<int>(m_indexBufferTypeSize) * idxList.size());
 		}
 		m_indexCount = obj->getIndexList().size();
-		m_memoryUsage+= m_indexCount * m_indexBufferTypeSize;
+		m_memoryUsage+= static_cast<size_t>(m_indexCount) * m_indexBufferTypeSize;
 		m_indexBuffer.release();
 	}
 	else
