@@ -148,7 +148,7 @@ public:
 	//! Convert quantized B-V index to float B-V
 	static inline float indexToBV(unsigned char bV)
 	{
-		return (float)bV*(4.f/127.f)-0.5f;
+		return static_cast<float>(bV)*(4.f/127.f)-0.5f;
 	}
 
 	//! Convert quantized B-V index to RGB colors
@@ -159,17 +159,17 @@ public:
 
 public slots:
 	//! Set the way brighter stars will look bigger as the fainter ones
-	void setRelativeStarScale(double b=1.0) {if(b!=starRelativeScale){ starRelativeScale=b; emit relativeStarScaleChanged(b);}}
+	void setRelativeStarScale(double b=1.0) { starRelativeScale=b; emit relativeStarScaleChanged(b);}
 	//! Get the way brighter stars will look bigger as the fainter ones
 	double getRelativeStarScale() const {return starRelativeScale;}
 
 	//! Set the absolute star brightness scale
-	void setAbsoluteStarScale(double b=1.0) {if(b!=starAbsoluteScaleF){ starAbsoluteScaleF=b; emit absoluteStarScaleChanged(b);}}
+	void setAbsoluteStarScale(double b=1.0) { starAbsoluteScaleF=b; emit absoluteStarScaleChanged(b);}
 	//! Get the absolute star brightness scale
 	double getAbsoluteStarScale() const {return starAbsoluteScaleF;}
 
 	//! Set source twinkle amount.
-	void setTwinkleAmount(double b) {if(b!=twinkleAmount){ twinkleAmount=b; emit twinkleAmountChanged(b);}}
+	void setTwinkleAmount(double b) { twinkleAmount=b; emit twinkleAmountChanged(b);}
 	//! Get source twinkle amount.
 	double getTwinkleAmount() const {return twinkleAmount;}
 
@@ -192,8 +192,29 @@ public slots:
 	//! Get the current Bortle scale index
 	//! @see https://en.wikipedia.org/wiki/Bortle_scale
 	int getBortleScaleIndex() const {return bortleScaleIndex;}
-	//! Get the average NELM for current Bortle scale index
+	//! Get the average NELM for current Bortle scale index:
+	//! Class 1 = NELM 7.6-8.0; average NELM is 7.8
+	//! Class 2 = NELM 7.1-7.5; average NELM is 7.3
+	//! Class 3 = NELM 6.6-7.0; average NELM is 6.8
+	//! Class 4 = NELM 6.1-6.5; average NELM is 6.3
+	//! Class 5 = NELM 5.6-6.0; average NELM is 5.8
+	//! Class 6 = NELM 5.1-5.5; average NELM is 5.3
+	//! Class 7 = NELM 4.6-5.0; average NELM is 4.8
+	//! Class 8 = NELM 4.1-4.5; average NELM is 4.3
+	//! Class 9 = NELM 4.0
 	float getNELMFromBortleScale() const;
+	//! Get the average NELM for given Bortle scale index [1..9]
+	//! Class 1 = NELM 7.6-8.0; average NELM is 7.8
+	//! Class 2 = NELM 7.1-7.5; average NELM is 7.3
+	//! Class 3 = NELM 6.6-7.0; average NELM is 6.8
+	//! Class 4 = NELM 6.1-6.5; average NELM is 6.3
+	//! Class 5 = NELM 5.6-6.0; average NELM is 5.8
+	//! Class 6 = NELM 5.1-5.5; average NELM is 5.3
+	//! Class 7 = NELM 4.6-5.0; average NELM is 4.8
+	//! Class 8 = NELM 4.1-4.5; average NELM is 4.3
+	//! Class 9 = NELM 4.0
+	//! @arg idx Bortle Scale Index (valid: 1..9, will be forced to valid range)
+	static float getNELMFromBortleScale(int idx);
 
 	//! Set flag for drawing a halo around bright stars.
 	void setFlagDrawBigStarHalo(bool b) {if(b!=flagDrawBigStarHalo){ flagDrawBigStarHalo=b; emit flagDrawBigStarHaloChanged(b);}}
@@ -228,17 +249,17 @@ public slots:
 	double getCustomStarMagnitudeLimit() const {return customStarMagLimit;}
 	//! Sets a lower limit for star magnitudes (anything fainter is ignored).
 	//! In force only if flagStarMagnitudeLimit is set.
-	void setCustomStarMagnitudeLimit(double limit) {if(limit!=customStarMagLimit){ customStarMagLimit=limit; emit customStarMagLimitChanged(limit);}}
+	void setCustomStarMagnitudeLimit(double limit) { customStarMagLimit=limit; emit customStarMagLimitChanged(limit);}
 	//! Get the value used for forced nebula magnitude limiting.
 	double getCustomNebulaMagnitudeLimit() const {return customNebulaMagLimit;}
 	//! Sets a lower limit for nebula magnitudes (anything fainter is ignored).
 	//! In force only if flagNebulaMagnitudeLimit is set.
-	void setCustomNebulaMagnitudeLimit(double limit) {if(limit!=customNebulaMagLimit){ customNebulaMagLimit=limit; emit customNebulaMagLimitChanged(limit);}}
+	void setCustomNebulaMagnitudeLimit(double limit) { customNebulaMagLimit=limit; emit customNebulaMagLimitChanged(limit);}
 	//! Get the value used for forced solar system object magnitude limiting.
 	double getCustomPlanetMagnitudeLimit() const {return customPlanetMagLimit;}
 	//! Sets a lower limit for solar system object magnitudes (anything fainter is ignored).
 	//! In force only if flagPlanetMagnitudeLimit is set.
-	void setCustomPlanetMagnitudeLimit(double limit) {if(limit!=customPlanetMagLimit){ customPlanetMagLimit=limit; emit customPlanetMagLimitChanged(limit);}}
+	void setCustomPlanetMagnitudeLimit(double limit) { customPlanetMagLimit=limit; emit customPlanetMagLimitChanged(limit);}
 
 	//! Get the luminance of the faintest visible object (e.g. RGB<0.05)
 	//! It depends on the zoom level, on the eye adapation and on the point source rendering parameters
@@ -251,7 +272,7 @@ public slots:
 	bool getFlagLuminanceAdaptation() const {return flagLuminanceAdaptation;}
 
 	//! Set the label brightness threshold
-	void setDaylightLabelThreshold(double t) {if(t!=daylightLabelThreshold){ daylightLabelThreshold=t; emit daylightLabelThresholdChanged(t);}}
+	void setDaylightLabelThreshold(double t) { daylightLabelThreshold=t; emit daylightLabelThresholdChanged(t);}
 	//! Get the current label brightness threshold
 	double getDaylightLabelThreshold() const {return daylightLabelThreshold;}
 	//! Return a brightness value based on objects in view (sky, sun, moon, ...)
@@ -264,17 +285,17 @@ public slots:
 	bool getFlagHasAtmosphere() const {return flagHasAtmosphere;}
 
 	//! Set extinction coefficient, mag/airmass (for extinction).
-	void setExtinctionCoefficient(double extCoeff) {if(extCoeff!=extinction.getExtinctionCoefficient()){ extinction.setExtinctionCoefficient(extCoeff); emit extinctionCoefficientChanged(extinction.getExtinctionCoefficient());}}
+	void setExtinctionCoefficient(double extCoeff) { extinction.setExtinctionCoefficient(static_cast<float>(extCoeff)); emit extinctionCoefficientChanged(static_cast<double>(extinction.getExtinctionCoefficient()));}
 	//! Get extinction coefficient, mag/airmass (for extinction).
-	double getExtinctionCoefficient() const {return extinction.getExtinctionCoefficient();}
+	double getExtinctionCoefficient() const {return static_cast<double>(extinction.getExtinctionCoefficient());}
 	//! Set atmospheric (ground) temperature in deg celsius (for refraction).
-	void setAtmosphereTemperature(double celsius) {if(celsius!=refraction.getTemperature()){refraction.setTemperature(celsius); emit atmosphereTemperatureChanged(refraction.getTemperature());}}
+	void setAtmosphereTemperature(double celsius) {refraction.setTemperature(static_cast<float>(celsius)); emit atmosphereTemperatureChanged(static_cast<double>(refraction.getTemperature()));}
 	//! Get atmospheric (ground) temperature in deg celsius (for refraction).
-	double getAtmosphereTemperature() const {return refraction.getTemperature();}
+	double getAtmosphereTemperature() const {return static_cast<double>(refraction.getTemperature());}
 	//! Set atmospheric (ground) pressure in mbar (for refraction).
-	void setAtmospherePressure(double mbar) {if(mbar!=refraction.getPressure()){ refraction.setPressure(mbar); emit atmospherePressureChanged(refraction.getPressure());}}
+	void setAtmospherePressure(double mbar) { refraction.setPressure(static_cast<float>(mbar)); emit atmospherePressureChanged(static_cast<double>(refraction.getPressure()));}
 	//! Get atmospheric (ground) pressure in mbar (for refraction).
-	double getAtmospherePressure() const {return refraction.getPressure();}
+	double getAtmospherePressure() const {return static_cast<double>(refraction.getPressure());}
 
 	//! Get the current valid extinction computation object.
 	const Extinction& getExtinction() const {return extinction;}
