@@ -313,87 +313,6 @@ bool StelSkyLayerMgr::loadSkyImage(const QString& id, const QString& filename,
 	}
 }
 
-// DEPRECATED, REMOVE FOR 0.19+?
-bool StelSkyLayerMgr::loadSkyImageAltAz(const QString& id, const QString& filename,
-								   double alt0, double azi0,
-								   double alt1, double azi1,
-								   double alt2, double azi2,
-								   double alt3, double azi3,
-								   double minRes, double maxBright, bool visible)
-{
-	Q_UNUSED(id) Q_UNUSED(filename)
-	Q_UNUSED(alt0) Q_UNUSED(azi0) Q_UNUSED(alt1) Q_UNUSED(azi1)
-	Q_UNUSED(alt2) Q_UNUSED(azi2) Q_UNUSED(alt3) Q_UNUSED(azi3)
-	Q_UNUSED(minRes) Q_UNUSED(maxBright) Q_UNUSED(visible)
-
-	qWarning() << "StelSkyLayerMgr::loadSkyImageAltAz() has been deprecated before version 0.16 and is no longer available! Please use loadSkyImage() with AzAlt frame argument.";
-	//return loadSkyImage( id, filename, azi0, alt0, azi1, alt1, azi2, alt2, azi3, alt3, minRes, maxBright, visible, StelCore::FrameAltAz);
-	return false;
-
-	// NOTE: This old version may have inverted series of coordinates. Else, the only difference against the original loadSkyImage (setting J2000 coords) is the frame.
-/*
-	if (allSkyLayers.contains(id))
-	{
-		qWarning() << "Image ID" << id << "already exists, removing old image before loading";
-		removeSkyLayer(id);
-	}
-
-	QString path = StelFileMgr::findFile(filename);
-	if (path.isEmpty())
-	{
-		qWarning() << "Could not find image" << QDir::toNativeSeparators(filename);
-		return false;
-	}
-
-	QVariantMap vm;
-	//QVariantList l;
-	QVariantList cl; // coordinates list for adding worldCoords and textureCoords
-	QVariantList c;  // a list for a pair of coordinates
-	QVariantList ol; // outer list - we want a structure 3 levels deep...
-	vm["imageUrl"] = QVariant(path);
-	vm["maxBrightness"] = QVariant(maxBright);
-	vm["minResolution"] = QVariant(minRes);
-	vm["shortName"] = QVariant(id);
-
-	// textureCoords (define the ordering of worldCoords)
-	cl.clear();
-	ol.clear();
-	c.clear(); c.append(0); c.append(0); cl.append(QVariant(c));
-	c.clear(); c.append(1); c.append(0); cl.append(QVariant(c));
-	c.clear(); c.append(1); c.append(1); cl.append(QVariant(c));
-	c.clear(); c.append(0); c.append(1); cl.append(QVariant(c));
-	ol.append(QVariant(cl));
-	vm["textureCoords"] = ol;
-
-	// world coordinates
-	cl.clear();
-	ol.clear();
-	c.clear(); c.append(alt0); c.append(azi0); cl.append(QVariant(c));
-	c.clear(); c.append(alt1); c.append(azi1); cl.append(QVariant(c));
-	c.clear(); c.append(alt2); c.append(azi2); cl.append(QVariant(c));
-	c.clear(); c.append(alt3); c.append(azi3); cl.append(QVariant(c)); 
-	ol.append(QVariant(cl));
-	vm["worldCoords"] = ol;
-
-	StelSkyLayerP tile = StelSkyLayerP(new StelSkyImageTile(vm, 0));
-	tile->setFrameType(StelCore::FrameAltAz);
-	
-	try
-	{
-		QString key = insertSkyLayer(tile, filename, visible);
-		if (key == id)
-			return true;
-		else
-			return false;
-	}
-	catch (std::runtime_error& e)
-	{
-		qWarning() << e.what();
-		return false;
-	}
-	*/
-}
-
 void StelSkyLayerMgr::showLayer(const QString& id, bool b)
 {
 	if (allSkyLayers.contains(id))
