@@ -34,9 +34,9 @@
 #include <QDebug>
 #include <QFontMetrics>
 
-Vec3f Asterism::lineColor = Vec3f(0.4,0.4,0.8);
-Vec3f Asterism::rayHelperColor = Vec3f(1.0,1.0,0.0);
-Vec3f Asterism::labelColor = Vec3f(0.4,0.4,0.8);
+Vec3f Asterism::lineColor = Vec3f(0.4f,0.4f,0.8f);
+Vec3f Asterism::rayHelperColor = Vec3f(1.0f,1.0f,0.0f);
+Vec3f Asterism::labelColor = Vec3f(0.4f,0.4f,0.8f);
 const QString Asterism::ASTERISM_TYPE = QStringLiteral("Asterism");
 
 Asterism::Asterism()
@@ -88,15 +88,12 @@ bool Asterism::read(const QString& record, StarMgr *starMgr)
 					// delete[] asterism;
 					return false;
 				}
-
-				asterism[i]=starMgr->searchHP(HP);
-
+				asterism[i]=starMgr->searchHP(static_cast<int>(HP));
 				if (!asterism[i])
 				{
 					qWarning() << "Error in Asterism " << abbreviation << ": can't find star HIP" << HP;
 					return false;
 				}
-
 				break;
 			}
 			case 2: // A small asterism with lines by J2000.0 coordinates
@@ -107,26 +104,23 @@ bool Asterism::read(const QString& record, StarMgr *starMgr)
 				istr >> RA >> DE;				
 				StelUtils::spheToRect(RA*M_PI/12., DE*M_PI/180., coords);
 				QList<StelObjectP> stars = starMgr->searchAround(coords, 0.1, core);
-				StelObjectP s = NULL;
-				float d = 10.f;
+				StelObjectP s = Q_NULLPTR;
+				double d = 10.;
 				for (const auto& p : stars)
 				{
-					float a = coords.angle(p->getJ2000EquatorialPos(core));
+					double a = coords.angle(p->getJ2000EquatorialPos(core));
 					if (a<d)
 					{
 						d = a;
 						s = p;
 					}
 				}
-
 				asterism[i] = s;
-
 				if (!asterism[i])
 				{
 					qWarning() << "Error in Asterism " << abbreviation << ": can't find star with coordinates" << RA << "/" << DE;
 					return false;
 				}
-
 				break;
 			}
 		}
@@ -135,10 +129,8 @@ bool Asterism::read(const QString& record, StarMgr *starMgr)
 	if (typeOfAsterism>0)
 	{
 		XYZname.set(0.,0.,0.);
-		for(unsigned int ii=0;ii<numberOfSegments*2;++ii)
-		{
-			XYZname+= asterism[ii]->getJ2000EquatorialPos(StelApp::getInstance().getCore());
-		}
+		for(unsigned int j=0;j<numberOfSegments*2;++j)
+			XYZname+= asterism[j]->getJ2000EquatorialPos(core);
 		XYZname.normalize();
 	}
 	else
@@ -178,7 +170,7 @@ void Asterism::drawOptim(StelPainter& sPainter, const StelCore* core, const Sphe
 
 void Asterism::drawName(StelPainter& sPainter) const
 {
-	if (!nameFader.getInterstate() || !flagAsterism)
+	if ((nameFader.getInterstate()==0.0f) || !flagAsterism)
 		return;
 
 	if (typeOfAsterism==2 && sPainter.getProjector()->getFov()>60.f)
@@ -186,7 +178,7 @@ void Asterism::drawName(StelPainter& sPainter) const
 
 	QString name = getNameI18n();
 	sPainter.setColor(labelColor[0], labelColor[1], labelColor[2], nameFader.getInterstate());
-	sPainter.drawText(XYname[0], XYname[1], name, 0., -sPainter.getFontMetrics().width(name)/2, 0, false);
+	sPainter.drawText(static_cast<float>(XYname[0]), static_cast<float>(XYname[1]), name, 0., -sPainter.getFontMetrics().boundingRect(name).width()/2, 0, false);
 }
 
 const Asterism* Asterism::isStarIn(const StelObject* s) const
