@@ -40,7 +40,7 @@ class Comet : public Planet
 public:
 	friend class SolarSystem;               // Solar System initializes static constants.
 	Comet(const QString& englishName,
-	      double radius,
+	      double equatorialRadius,
 	      double oblateness,
 	      Vec3f halocolor,
 	      float albedo,
@@ -134,7 +134,7 @@ private:
 	//! @param colorArr vertex colors (if not textured) r0, g0, b0, r1, g1, b1, ...
 	//! @param indices into the former arrays (zero-starting), triplets forming triangles: t0,0, t0,1, t0,2, t1,0, t1,1, t1,2, ...
 	//! @param xOffset for the dust tail, this may introduce a bend. Units are x per sqrt(z).
-	void computeParabola(const float parameter, const float topradius, const float zshift, QVector<Vec3d>& vertexArr, QVector<float>& texCoordArr, QVector<unsigned short>& indices, const float xOffset=0.0f);
+	void computeParabola(const float parameter, const float topradius, const float zshift, QVector<Vec3d>& vertexArr, QVector<Vec2f>& texCoordArr, QVector<unsigned short>& indices, const float xOffset=0.0f);
 
 	float slopeParameter;
 	double semiMajorAxis;
@@ -152,8 +152,8 @@ private:
 	float dustTailWidthFactor;      //!< empirical individual broadening of the dust tail end, compared to the gas tail end. Actually, dust tail width=2*comaWidth*dustTailWidthFactor. Default 1.5
 	float dustTailLengthFactor;     //!< empirical individual length of dust tail relative to gas tail. Taken from ssystem.ini, typical value 0.3..0.5, default 0.4
 	float dustTailBrightnessFactor; //!< empirical individual brightness of dust tail relative to gas tail. Taken from ssystem.ini, default 1.5
-	QVector<double> comaVertexArr;
-	QVector<float> comaTexCoordArr; //  --> 2014-08: could also be declared static, but it is filled by StelPainter...
+	QVector<Vec3d> comaVertexArr;
+	QVector<Vec2f> comaTexCoordArr; //  --> 2014-08: could also be declared static, but it is filled by StelPainter...
 
 	float intensityFovScale; // like for constellations: reduce brightness when zooming in.
 	float intensityMinFov;
@@ -168,7 +168,7 @@ private:
 	QVector<Vec3d> dusttailVertexArr; // computed frequently, describes parabolic shape (along z axis) of dust tail.
 	QVector<Vec3f> gastailColorArr;    // NEW computed for every 5 mins, modulates gas tail brightness for extinction
 	QVector<Vec3f> dusttailColorArr;   // NEW computed for every 5 mins, modulates dust tail brightness for extinction
-	static QVector<float> tailTexCoordArr; // computed only once for all comets!
+	static QVector<Vec2f> tailTexCoordArr; // computed only once for all comets!
 	static QVector<unsigned short> tailIndices; // computed only once for all comets!
 	static StelTextureSP comaTexture;
 	static StelTextureSP tailTexture;      // it seems not really necessary to have different textures. gas tail is just painted blue.
