@@ -38,9 +38,9 @@
 
 const QString Constellation::CONSTELLATION_TYPE = QStringLiteral("Constellation");
 
-Vec3f Constellation::lineColor = Vec3f(0.4,0.4,0.8);
-Vec3f Constellation::labelColor = Vec3f(0.4,0.4,0.8);
-Vec3f Constellation::boundaryColor = Vec3f(0.8,0.3,0.3);
+Vec3f Constellation::lineColor = Vec3f(0.4f,0.4f,0.8f);
+Vec3f Constellation::labelColor = Vec3f(0.4f,0.4f,0.8f);
+Vec3f Constellation::boundaryColor = Vec3f(0.8f,0.3f,0.3f);
 bool Constellation::singleSelected = false;
 bool Constellation::seasonalRuleEnabled = false;
 float Constellation::artIntensityFovScale = 1.0f;
@@ -90,10 +90,10 @@ bool Constellation::read(const QString& record, StarMgr *starMgr)
 			return false;
 		}
 
-		constellation[i]=starMgr->searchHP(HP);
+		constellation[i]=starMgr->searchHP(static_cast<int>(HP));
 		if (!constellation[i])
 		{
-			qWarning() << "Error in Constellation " << abbreviation << " asterism : can't find star HP= " << HP;
+			qWarning() << "Error in Constellation " << abbreviation << ": can't find star HIP" << HP;
 			// TODO: why is this delete commented?
 			// delete[] constellation;
 			return false;
@@ -134,7 +134,7 @@ void Constellation::drawOptim(StelPainter& sPainter, const StelCore* core, const
 
 void Constellation::drawName(StelPainter& sPainter, ConstellationMgr::ConstellationDisplayStyle style) const
 {
-	if (!nameFader.getInterstate())
+	if (nameFader.getInterstate()==0.0f)
 		return;
 
 	if (checkVisibility())
@@ -157,7 +157,7 @@ void Constellation::drawName(StelPainter& sPainter, ConstellationMgr::Constellat
 		}
 
 		sPainter.setColor(labelColor[0], labelColor[1], labelColor[2], nameFader.getInterstate());
-		sPainter.drawText(XYname[0], XYname[1], name, 0., -sPainter.getFontMetrics().width(name)/2, 0, false);
+		sPainter.drawText(static_cast<float>(XYname[0]), static_cast<float>(XYname[1]), name, 0., -sPainter.getFontMetrics().boundingRect(name).width()/2, 0, false);
 	}
 }
 
@@ -193,7 +193,6 @@ const Constellation* Constellation::isStarIn(const StelObject* s) const
 {
 	for(unsigned int i=0;i<numberOfSegments*2;++i)
 	{
-
 		// constellation[i]==s test was not working
 		if (constellation[i]->getEnglishName()==s->getEnglishName())
 		{
@@ -214,7 +213,7 @@ void Constellation::update(int deltaTime)
 
 void Constellation::drawBoundaryOptim(StelPainter& sPainter) const
 {
-	if (!boundaryFader.getInterstate())
+	if (boundaryFader.getInterstate()==0.0f)
 		return;
 
 	sPainter.setBlending(true);
@@ -262,7 +261,6 @@ bool Constellation::checkVisibility() const
 		// ...oops, it's a "inverted" season rule
 		if (((month>=1) && (month<=endSeason)) || ((month>=beginSeason) && (month<=12)))
 			visible = true;
-
 	}
 	return visible;
 }
@@ -297,9 +295,9 @@ StelObjectP Constellation::getBrightestStarInConstellation(void) const
 	StelObjectP brightest;
 	// maybe the brightest star has always odd index,
 	// so check all segment endpoints:
-	for (int i=2*numberOfSegments-1;i>=0;i--)
+	for (int i=2*static_cast<int>(numberOfSegments)-1;i>=0;i--)
 	{
-		const float Mag = constellation[i]->getVMagnitude(0);
+		const float Mag = constellation[i]->getVMagnitude(Q_NULLPTR);
 		if (Mag < maxMag)
 		{
 			brightest = constellation[i];
