@@ -62,6 +62,7 @@ ConstellationMgr::ConstellationMgr(StarMgr *_hip_stars)
 	  boundariesDisplayed(0),
 	  linesDisplayed(0),
 	  namesDisplayed(0),
+	  checkLoadingData(false),
 	  constellationLineThickness(1),
 	  constellationBoundariesThickness(1)
 {
@@ -99,30 +100,21 @@ void ConstellationMgr::init()
 	setFlagConstellationPick(conf->value("viewing/flag_constellation_pick", false).toBool());
 	setConstellationLineThickness(conf->value("viewing/constellation_line_thickness", 1).toInt());
 	setConstellationLineThickness(conf->value("viewing/constellation_boundaries_thickness", 1).toInt());
+	// The setting for developers
+	setFlagCheckLoadingData(conf->value("devel/check_loading_constellation_data","false").toBool());
 
 	QString starloreDisplayStyle=conf->value("viewing/constellation_name_style", "translated").toString();
-	if (starloreDisplayStyle=="translated")
-	{
-		setConstellationDisplayStyle(constellationsTranslated);
-	}
-	else if (starloreDisplayStyle=="native")
-	{
-		setConstellationDisplayStyle(constellationsNative);
-	}
-	else if (starloreDisplayStyle=="abbreviated")
-	{
-		setConstellationDisplayStyle(constellationsAbbreviated);
-	}
-	else if (starloreDisplayStyle=="english")
-	{
-		setConstellationDisplayStyle(constellationsEnglish);
-	}
-	else
+	static const QMap<QString, ConstellationDisplayStyle>map={
+		{ "translated",  constellationsTranslated},
+		{ "native",      constellationsNative},
+		{ "abbreviated", constellationsAbbreviated},
+		{ "english",     constellationsEnglish}};
+	if (!map.contains(starloreDisplayStyle))
 	{
 		qDebug() << "Warning: viewing/constellation_name_style (" << starloreDisplayStyle << ") invalid. Using translated style.";
 		conf->setValue("viewing/constellation_name_style", "translated");
-		setConstellationDisplayStyle(constellationsTranslated);
 	}
+	setConstellationDisplayStyle(map.value(starloreDisplayStyle, constellationsTranslated));
 
 	// Load colors from config file
 	QString defaultColor = conf->value("color/default_color").toString();
@@ -227,6 +219,16 @@ void ConstellationMgr::updateSkyCulture(const QString& skyCultureDir)
 	}
 
 	lastLoadedSkyCulture = skyCultureDir;
+
+	if (getFlagCheckLoadingData())
+	{
+		int i = 1;
+		for (auto* constellation : constellations)
+		{
+			qWarning() << "[Constellation] #" << i << " abbr:" << constellation->abbreviation << " name:" << constellation->getEnglishName() << " segments:" << constellation->numberOfSegments;
+			i++;
+		}
+	}
 }
 
 void ConstellationMgr::selectedObjectChange(StelModule::StelModuleSelectAction action)
@@ -248,12 +250,12 @@ void ConstellationMgr::selectedObjectChange(StelModule::StelModuleSelectAction a
 		// If removing this selection
 		if(action == StelModule::RemoveFromSelection)
 		{
-			unsetSelectedConst((Constellation *)newSelectedConst[0].data());
+			unsetSelectedConst(static_cast<Constellation *>(newSelectedConst[0].data()));
 		}
 		else
 		{
 			// Add constellation to selected list (do not select a star, just the constellation)
-			setSelectedConst((Constellation *)newSelectedConst[0].data());
+			setSelectedConst(static_cast<Constellation *>(newSelectedConst[0].data()));
 		}
 	}
 	else
@@ -370,9 +372,9 @@ Vec3f ConstellationMgr::getLabelsColor() const
 
 void ConstellationMgr::setFontSize(const float newFontSize)
 {
-	if (asterFont.pixelSize() != newFontSize)
+	if (asterFont.pixelSize() - newFontSize != 0.0f)
 	{
-		asterFont.setPixelSize(newFontSize);
+		asterFont.setPixelSize(static_cast<int>(newFontSize));
 		emit fontSizeChanged(newFontSize);
 	}
 }
@@ -471,7 +473,7 @@ void ConstellationMgr::loadLinesAndArt(const QString &fileName, const QString &a
 		if(cons->read(record, hipStarMgr))
 		{
 			cons->artOpacity = artIntensity;
-			cons->artFader.setDuration((int) (artFadeDuration * 1000.f));
+			cons->artFader.setDuration(static_cast<int>(artFadeDuration * 1000.f));
 			cons->setFlagArt(artDisplayed);
 			cons->setFlagBoundaries(boundariesDisplayed);
 			cons->setFlagLines(linesDisplayed);
@@ -573,9 +575,9 @@ void ConstellationMgr::loadLinesAndArt(const QString &fileName, const QString &a
 			}
 
 			StelCore* core = StelApp::getInstance().getCore();
-			Vec3d s1 = hipStarMgr->searchHP(hp1)->getJ2000EquatorialPos(core);
-			Vec3d s2 = hipStarMgr->searchHP(hp2)->getJ2000EquatorialPos(core);
-			Vec3d s3 = hipStarMgr->searchHP(hp3)->getJ2000EquatorialPos(core);
+			Vec3d s1 = hipStarMgr->searchHP(static_cast<int>(hp1))->getJ2000EquatorialPos(core);
+			Vec3d s2 = hipStarMgr->searchHP(static_cast<int>(hp2))->getJ2000EquatorialPos(core);
+			Vec3d s3 = hipStarMgr->searchHP(static_cast<int>(hp3))->getJ2000EquatorialPos(core);
 
 			// To transform from texture coordinate to 2d coordinate we need to find X with XA = B
 			// A formed of 4 points in texture coordinate, B formed with 4 points in 3d coordinate
@@ -583,7 +585,7 @@ void ConstellationMgr::loadLinesAndArt(const QString &fileName, const QString &a
 			// X = B inv(A)
 			Vec3d s4 = s1 + ((s2 - s1) ^ (s3 - s1));
 			Mat4d B(s1[0], s1[1], s1[2], 1, s2[0], s2[1], s2[2], 1, s3[0], s3[1], s3[2], 1, s4[0], s4[1], s4[2], 1);
-			Mat4d A(x1, texSizeY - y1, 0.f, 1.f, x2, texSizeY - y2, 0.f, 1.f, x3, texSizeY - y3, 0.f, 1.f, x1, texSizeY - y1, texSizeX, 1.f);
+			Mat4d A(x1, texSizeY - static_cast<int>(y1), 0., 1., x2, texSizeY - static_cast<int>(y2), 0., 1., x3, texSizeY - static_cast<int>(y3), 0., 1., x1, texSizeY - static_cast<int>(y1), texSizeX, 1.);
 			Mat4d X = B * A.inverse();
 
 			// Tesselate on the plan assuming a tangential projection for the image
@@ -594,19 +596,19 @@ void ConstellationMgr::loadLinesAndArt(const QString &fileName, const QString &a
 			{
 				for (int i=0;i<nbPoints;++i)
 				{
-					texCoords << Vec2f(((float)i)/nbPoints, ((float)j)/nbPoints);
-					texCoords << Vec2f(((float)i+1.f)/nbPoints, ((float)j)/nbPoints);
-					texCoords << Vec2f(((float)i)/nbPoints, ((float)j+1.f)/nbPoints);
-					texCoords << Vec2f(((float)i+1.f)/nbPoints, ((float)j)/nbPoints);
-					texCoords << Vec2f(((float)i+1.f)/nbPoints, ((float)j+1.f)/nbPoints);
-					texCoords << Vec2f(((float)i)/nbPoints, ((float)j+1.f)/nbPoints);
+					texCoords << Vec2f((static_cast<float>(i))/nbPoints, (static_cast<float>(j))/nbPoints);
+					texCoords << Vec2f((static_cast<float>(i)+1.f)/nbPoints, (static_cast<float>(j))/nbPoints);
+					texCoords << Vec2f((static_cast<float>(i))/nbPoints, (static_cast<float>(j)+1.f)/nbPoints);
+					texCoords << Vec2f((static_cast<float>(i)+1.f)/nbPoints, (static_cast<float>(j))/nbPoints);
+					texCoords << Vec2f((static_cast<float>(i)+1.f)/nbPoints, (static_cast<float>(j)+1.f)/nbPoints);
+					texCoords << Vec2f((static_cast<float>(i))/nbPoints, (static_cast<float>(j)+1.f)/nbPoints);
 				}
 			}
 
 			QVector<Vec3d> contour;
 			contour.reserve(texCoords.size());
 			for (const auto& v : texCoords)
-				contour << X * Vec3d((double)v[0] * texSizeX, (double)v[1] * texSizeY, 0.);
+				contour << X * Vec3d(static_cast<double>(v[0]) * texSizeX, static_cast<double>(v[1]) * texSizeY, 0.);
 
 			cons->artPolygon.vertex=contour;
 			cons->artPolygon.texCoords=texCoords;
@@ -748,7 +750,7 @@ void ConstellationMgr::loadNames(const QString& namesFile)
 	// lines which look like records - we use the RE to extract the fields
 	// which will be available in recRx.capturedTexts()
 	// abbreviation is allowed to start with a dot to mark as "hidden".
-	QRegExp recRx("^\\s*(\\.?\\w+)\\s+\"(.*)\"\\s+_[(]\"(.*)\"[)]\\n");
+	QRegExp recRx("^\\s*(\\.?\\w+)\\s+\"(.*)\"\\s+_[(]\"(.*)\"[)]\\s*(\\w*)\\n");
 	QRegExp ctxRx("(.*)\",\\s*\"(.*)");
 
 	// Some more variables to use in the parsing
@@ -824,7 +826,7 @@ void ConstellationMgr::loadSeasonalRules(const QString& rulesFile)
 	if (rulesFile.isEmpty())
 		flag = false;
 
-	// clear previous names
+	// clear previous rules
 	for (auto* constellation : constellations)
 	{
 		constellation->beginSeason = 1;
@@ -912,7 +914,7 @@ void ConstellationMgr::update(double deltaTime)
 	double fov = StelApp::getInstance().getCore()->getMovementMgr()->getCurrentFov();
 	Constellation::artIntensityFovScale = qBound(0.0,(fov - artIntensityMinimumFov) / (artIntensityMaximumFov - artIntensityMinimumFov),1.0);
 
-	const int delta = (int)(deltaTime*1000);
+	const int delta = static_cast<int>(deltaTime*1000);
 	for (auto* constellation : constellations)
 	{
 		constellation->update(delta);
@@ -921,7 +923,7 @@ void ConstellationMgr::update(double deltaTime)
 
 void ConstellationMgr::setArtIntensity(const float intensity)
 {
-	if (artIntensity != intensity)
+	if ((artIntensity - intensity) != 0.0f)
 	{
 		artIntensity = intensity;
 
@@ -930,7 +932,7 @@ void ConstellationMgr::setArtIntensity(const float intensity)
 			constellation->artOpacity = artIntensity;
 		}
 
-		emit artIntensityChanged(intensity);
+		emit artIntensityChanged(static_cast<double>(intensity));
 	}
 }
 
@@ -967,7 +969,7 @@ void ConstellationMgr::setArtFadeDuration(const float duration)
 
 		for (auto* constellation : constellations)
 		{
-			constellation->artFader.setDuration((int)(duration * 1000.f));
+			constellation->artFader.setDuration(static_cast<int>(duration * 1000.f));
 		}
 		emit artFadeDurationChanged(duration);
 	}
