@@ -28,10 +28,12 @@
 #include "StelTranslator.hpp"
 #include "StelModuleMgr.hpp"
 #include "StelProjector.hpp"
+#include "StelUtils.hpp"
 
 const QString CustomObject::CUSTOMOBJECT_TYPE = QStringLiteral("CustomObject");
 Vec3f CustomObject::markerColor = Vec3f(0.1f,1.0f,0.1f);
 float CustomObject::markerSize = 1.f;
+float CustomObject::selectPriority = 0.f;
 
 CustomObject::CustomObject(const QString& codesignation, const Vec3d& coordinates, const bool isVisible)
 	: initialized(false)
@@ -40,8 +42,8 @@ CustomObject::CustomObject(const QString& codesignation, const Vec3d& coordinate
 	, designation(codesignation)
 	, isMarker(isVisible)
 {
-	markerTexture = StelApp::getInstance().getTextureManager().createTexture(StelFileMgr::getInstallationDir()+"/textures/cross.png");
-	initialized = true;	
+	markerTexture = StelApp::getInstance().getTextureManager().createTexture(StelFileMgr::getInstallationDir()+"/textures/cross.png");	
+	initialized = true;
 }
 
 CustomObject::~CustomObject()
@@ -51,7 +53,8 @@ CustomObject::~CustomObject()
 
 float CustomObject::getSelectPriority(const StelCore* core) const
 {
-	return StelObject::getSelectPriority(core)-2.f;
+	Q_UNUSED(core);
+	return selectPriority;
 }
 
 QString CustomObject::getNameI18n() const
@@ -93,7 +96,7 @@ QString CustomObject::getInfoString(const StelCore* core, const InfoStringGroup&
 
 Vec3f CustomObject::getInfoColor(void) const
 {
-	return Vec3f(1.0, 1.0, 1.0);
+	return Vec3f(1.f, 1.f, 1.f);
 }
 
 float CustomObject::getVMagnitude(const StelCore* core) const
@@ -112,7 +115,7 @@ double CustomObject::getAngularSize(const StelCore*) const
 
 void CustomObject::update(double deltaTime)
 {
-	labelsFader.update((int)(deltaTime*1000));
+	labelsFader.update(static_cast<int>(deltaTime*1000));
 }
 
 void CustomObject::draw(StelCore* core, StelPainter *painter)
@@ -129,14 +132,14 @@ void CustomObject::draw(StelCore* core, StelPainter *painter)
 	if (isMarker)
 	{
 		markerTexture->bind();
-		float size = getAngularSize(Q_NULLPTR)*M_PI/180.*painter->getProjector()->getPixelPerRadAtCenter();
-		float shift = markerSize + size/1.6f;
+		const float size = static_cast<float>(getAngularSize(Q_NULLPTR))*M_PI_180f*painter->getProjector()->getPixelPerRadAtCenter();
+		const float shift = markerSize + size/1.6f;
 
-		painter->drawSprite2dMode(pos[0], pos[1], markerSize);
+		painter->drawSprite2dMode(static_cast<float>(pos[0]), static_cast<float>(pos[1]), markerSize);
 
 		if (labelsFader.getInterstate()<=0.f)
 		{
-			painter->drawText(pos[0], pos[1], getNameI18n(), 0, shift, shift, false);
+			painter->drawText(static_cast<float>(pos[0]), static_cast<float>(pos[1]), getNameI18n(), 0, shift, shift, false);
 		}
 	}
 }
