@@ -80,7 +80,7 @@ class LandscapeMgr : public StelModule
 		   READ getFlagLabels
 		   WRITE setFlagLabels
 		   NOTIFY labelsDisplayedChanged)
-	Q_PROPERTY(bool flagUseLightPollutionFromDatabase // was databaseUsage
+	Q_PROPERTY(bool flagUseLightPollutionFromDatabase
 		   READ getFlagUseLightPollutionFromDatabase
 		   WRITE setFlagUseLightPollutionFromDatabase
 		   NOTIFY flagUseLightPollutionFromDatabaseChanged)
@@ -230,7 +230,7 @@ public slots:
 
 	//! Get the current landscape or lightscape brightness (0..1)
 	//! @param light true to retrieve the light layer brightness value.
-	float getCurrentLandscapeBrightness(const bool light=false) const {return (light? landscape->getLightscapeBrightness() : landscape->getBrightness());}
+	float getCurrentLandscapeBrightness(const bool light=false) const {return static_cast<float>(light? landscape->getLightscapeBrightness() : landscape->getBrightness());}
 
 	//! Preload a landscape into cache.
 	//! @param id the ID of a landscape
@@ -247,7 +247,7 @@ public slots:
 	//! A big landscape may well take 150MB or more.
 	//! On a 32bit system, keep this rather small. On 64bit with 16GB RAM and no other tasks, 4GB is no problem.
 	//! Modern GPUs may have 4 or even 8GB of dedicated texture memory. Most of this may be filled with landscape textures.
-	//! Example: a museum installation with 20 large (16384x2048) old_stype landscapes can require up to 3.5GB. Allow 4GB cache,
+	//! Example: a museum installation with 20 large (16384x2048) old_style landscapes can require up to 3.5GB. Allow 4GB cache,
 	//! and the system will never have to load a landscape during the show when all have been preloaded.
 	void setCacheSize(int mb) { landscapeCache.setMaxCost(mb);}
 	//! Retrieve total size of cache (MB).
@@ -281,7 +281,7 @@ public slots:
 	//! Get whether the landscape is currently visible. If true, objects below landscape's limiting altitude limit can be omitted.
 	bool getIsLandscapeFullyVisible() const;
 	//! Get the sine of current landscape's minimal altitude. Useful to construct bounding caps.
-	float getLandscapeSinMinAltitudeLimit() const;
+	double getLandscapeSinMinAltitudeLimit() const;
 	
 	//! Get flag for displaying Fog.
 	bool getFlagFog() const;
@@ -312,7 +312,7 @@ public slots:
 	//! Return the minimal brightness value of the landscape
 	double getDefaultMinimalBrightness() const {return defaultMinimalBrightness;}
 	//! Set the minimal brightness value of the landscape.
-	void setDefaultMinimalBrightness(const double b) {if(b!=defaultMinimalBrightness){ defaultMinimalBrightness=b; emit defaultMinimalBrightnessChanged(b);}}
+	void setDefaultMinimalBrightness(const double b) {if(fabs(b-defaultMinimalBrightness)>0.0){ defaultMinimalBrightness=b; emit defaultMinimalBrightnessChanged(b);}}
 	//! Sets the value of the flag usage light pollution (and bortle index) from locations database.
 	void setFlagUseLightPollutionFromDatabase(const bool usage);
 	//! Return the value of flag usage light pollution (and bortle index) from locations database.
@@ -439,27 +439,17 @@ public slots:
 	//! Set flag for auto-enable atmosphere and landscape for planets with atmospheres in location window
 	void setFlagEnvironmentAutoEnable(bool b);
 
-	//! Get flag for auto-enable of atmospheres for planets.
-	//! @note this function is enabled for backward compatibility
-	//! @deprecated
-	bool getFlagAtmosphereAutoEnable() const { return getFlagEnvironmentAutoEnable(); }
-
-	//! Set flag for auto-enable atmosphere for planets with atmospheres in location window
-	//! @note this function is enabled for backward compatibility
-	//! @deprecated
-	void setFlagAtmosphereAutoEnable(bool b) { setFlagEnvironmentAutoEnable(b); }
-
 	//! Forward opacity query to current landscape.
 	//! @param azalt direction of view line to sample in azaltimuth coordinates.
 	float getLandscapeOpacity(Vec3d azalt) const {return landscape->getOpacity(azalt);}
 	// This variant is required for scripting!
-	float getLandscapeOpacity(Vec3f azalt) const {return landscape->getOpacity(Vec3d(azalt[0], azalt[1], azalt[2]));}
+	float getLandscapeOpacity(Vec3f azalt) const {return landscape->getOpacity(azalt.toVec3d());}
 	//! Forward opacity query to current landscape.
 	//! @param azimuth in degrees
 	//! @param altitude in degrees
 	float getLandscapeOpacity(float azimuth, float altitude) const {
 		Vec3d azalt;
-		StelUtils::spheToRect((180.0f-azimuth)*M_PI/180.0, altitude*M_PI/180.0, azalt);
+		StelUtils::spheToRect((180.0f-azimuth)*M_PI_180f, altitude*M_PI_180f, azalt);
 		return landscape->getOpacity(azalt);
 	}
 
@@ -519,8 +509,8 @@ private slots:
 	void setAtmosphereBortleLightPollution(const int bIndex);
 
 	//! Reacts to StelCore::locationChanged.
-	void onLocationChanged(StelLocation loc);
-	void onTargetLocationChanged(StelLocation loc);
+	void onLocationChanged(const StelLocation &loc);
+	void onTargetLocationChanged(const StelLocation &loc);
 
 	//! Translate labels to new language settings.
 	void updateI18n();
