@@ -63,41 +63,8 @@ bool  Nebula::surfaceBrightnessUsage = false;
 bool  Nebula::designationUsage = false;
 float Nebula::hintsBrightness = 0.f;
 Vec3f Nebula::labelColor = Vec3f(0.4f,0.3f,0.5f);
-Vec3f Nebula::circleColor = Vec3f(0.8f,0.8f,0.1f);
-Vec3f Nebula::galaxyColor = Vec3f(1.0f,0.2f,0.2f);
-Vec3f Nebula::radioGalaxyColor = Vec3f(0.3f,0.3f,0.3f);
-Vec3f Nebula::activeGalaxyColor = Vec3f(0.8f,0.8f,0.1f);
-Vec3f Nebula::interactingGalaxyColor = Vec3f(0.8f,0.8f,0.1f);
-Vec3f Nebula::quasarColor = Vec3f(1.0f,0.2f,0.2f);
-Vec3f Nebula::nebulaColor = Vec3f(0.1f,1.0f,0.1f);
-Vec3f Nebula::planetaryNebulaColor = Vec3f(0.1f,1.0f,0.1f);
-Vec3f Nebula::reflectionNebulaColor = Vec3f(0.1f,1.0f,0.1f);
-Vec3f Nebula::bipolarNebulaColor = Vec3f(0.1f,1.0f,0.1f);
-Vec3f Nebula::emissionNebulaColor = Vec3f(0.1f,1.0f,0.1f);
-Vec3f Nebula::darkNebulaColor = Vec3f(0.3f,0.3f,0.3f);
-Vec3f Nebula::hydrogenRegionColor = Vec3f(0.1f,1.0f,0.1f);
-Vec3f Nebula::supernovaRemnantColor = Vec3f(0.1f,1.0f,0.1f);
-Vec3f Nebula::interstellarMatterColor = Vec3f(0.1f,1.0f,0.1f);
-Vec3f Nebula::clusterWithNebulosityColor = Vec3f(0.1f,1.0f,0.1f);
-Vec3f Nebula::clusterColor = Vec3f(1.0f,1.0f,0.1f);
-Vec3f Nebula::openClusterColor = Vec3f(1.0f,1.0f,0.1f);
-Vec3f Nebula::globularClusterColor = Vec3f(1.0f,1.0f,0.1f);
-Vec3f Nebula::stellarAssociationColor = Vec3f(1.0f,1.0f,0.1f);
-Vec3f Nebula::starCloudColor = Vec3f(1.0f,1.0f,0.1f);
-Vec3f Nebula::emissionObjectColor = Vec3f(1.0f,1.0f,0.1f);
-Vec3f Nebula::blLacObjectColor = Vec3f(1.0f,1.0f,0.1f);
-Vec3f Nebula::blazarColor = Vec3f(1.0f,1.0f,0.1f);
-Vec3f Nebula::molecularCloudColor = Vec3f(1.0f,1.0f,0.1f);
-Vec3f Nebula::youngStellarObjectColor = Vec3f(1.0f,1.0f,0.1f);
-Vec3f Nebula::possibleQuasarColor = Vec3f(1.0f,0.2f,0.2f);
-Vec3f Nebula::possiblePlanetaryNebulaColor = Vec3f(1.0f,1.0f,0.1f);
-Vec3f Nebula::protoplanetaryNebulaColor = Vec3f(1.0f,1.0f,0.1f);
-Vec3f Nebula::starColor = Vec3f(1.0f,1.0f,0.1f);
-Vec3f Nebula::symbioticStarColor = Vec3f(1.0f,1.0f,0.1f);
-Vec3f Nebula::emissionLineStarColor = Vec3f(1.0f,1.0f,0.1f);
-Vec3f Nebula::supernovaCandidateColor = Vec3f(0.1f,1.0f,0.1f);
-Vec3f Nebula::supernovaRemnantCandidateColor = Vec3f(0.1f,1.0f,0.1f);
-Vec3f Nebula::galaxyClusterColor = Vec3f(0.8f,0.8f,0.5f);
+QMap<Nebula::NebulaType, Vec3f>Nebula::hintColorMap;
+QMap<Nebula::NebulaType, QString> Nebula::typeStringMap;
 bool Nebula::flagUseTypeFilters = false;
 Nebula::CatalogGroup Nebula::catalogFilters = Nebula::CatalogGroup(Q_NULLPTR);
 Nebula::TypeGroup Nebula::typeFilters = Nebula::TypeGroup(Nebula::AllTypes);
@@ -110,7 +77,8 @@ double Nebula::minSizeLimit = 1.0;
 double Nebula::maxSizeLimit = 600.0;
 
 Nebula::Nebula()
-	: DSO_nb(0)
+	: StelObject()
+	, DSO_nb(0)
 	, M_nb(0)
 	, NGC_nb(0)
 	, IC_nb(0)
@@ -128,6 +96,7 @@ Nebula::Nebula()
 	, Arp_nb(0)
 	, VV_nb(0)	
 	, Abell_nb(0)
+	, DWB_nb(0)
 	, Ced_nb("")
 	, PK_nb("")
 	, PNG_nb("")
@@ -135,6 +104,7 @@ Nebula::Nebula()
 	, ACO_nb("")
 	, HCG_nb("")
 	, ESO_nb("")
+	, VdBH_nb("")
 	, withoutID(false)
 	, nameI18("")
 	, mTypeString()
@@ -171,7 +141,7 @@ QString Nebula::getMagnitudeInfoString(const StelCore *core, const InfoStringGro
 		if (nType != NebDn && core->getSkyDrawer()->getFlagHasAtmosphere() && (alt_app>-2.0*M_PI/180.0)) // Don't show extincted magnitude much below horizon where model is meaningless.
 		{
 			const Extinction &extinction=core->getSkyDrawer()->getExtinction();
-			float airmass=extinction.airmass(std::cos(M_PI/2.0-alt_app), true);
+			float airmass=extinction.airmass(static_cast<float>(std::cos(M_PI_2-alt_app)), true);
 
 			emag = QString(" (%1 <b>%2</b> %3 <b>%4</b> %5)").arg(q_("reduced to"), QString::number(getVMagnitudeWithExtinction(core), 'f', decimals), q_("by"), QString::number(airmass, 'f', 2), q_("Airmasses"));
 		}
@@ -255,6 +225,10 @@ QString Nebula::getInfoString(const StelCore *core, const InfoStringGroup& flags
 			catIds << QString("Abell %1").arg(Abell_nb);
 		if (!ESO_nb.isEmpty())
 			catIds << QString("ESO %1").arg(ESO_nb);
+		if (!VdBH_nb.isEmpty())
+			catIds << QString("VdBH %1").arg(VdBH_nb);
+		if (DWB_nb > 0)
+			catIds << QString("DWB %1").arg(DWB_nb);
 
 		if (!nameI18.isEmpty() && !catIds.isEmpty() && flags&Name)
 			oss << "<br>";
@@ -322,16 +296,16 @@ QString Nebula::getInfoString(const StelCore *core, const InfoStringGroup& flags
 		QString majorAxS, minorAxS, sizeAx = q_("Size");
 		if (withDecimalDegree)
 		{
-			majorAxS = StelUtils::radToDecDegStr(majorAxisSize*M_PI/180., 5, false, true);
-			minorAxS = StelUtils::radToDecDegStr(minorAxisSize*M_PI/180., 5, false, true);
+			majorAxS = StelUtils::radToDecDegStr(static_cast<double>(majorAxisSize)*M_PI/180., 5, false, true);
+			minorAxS = StelUtils::radToDecDegStr(static_cast<double>(minorAxisSize)*M_PI/180., 5, false, true);
 		}
 		else
 		{
-			majorAxS = StelUtils::radToDmsPStr(majorAxisSize*M_PI/180., 2);
-			minorAxS = StelUtils::radToDmsPStr(minorAxisSize*M_PI/180., 2);
+			majorAxS = StelUtils::radToDmsPStr(static_cast<double>(majorAxisSize)*M_PI/180., 2);
+			minorAxS = StelUtils::radToDmsPStr(static_cast<double>(minorAxisSize)*M_PI/180., 2);
 		}
 
-		if (majorAxisSize==minorAxisSize || minorAxisSize==0.f)
+		if (fuzzyEquals(majorAxisSize, minorAxisSize) || minorAxisSize==0.f)
 			oss << QString("%1: %2").arg(sizeAx, majorAxS) << "<br />";
 		else
 		{
@@ -343,15 +317,16 @@ QString Nebula::getInfoString(const StelCore *core, const InfoStringGroup& flags
 
 	if (flags&Distance)
 	{
-		if (parallax!=0.f)
+		float distance, distanceErr, distanceLY, distanceErrLY;
+		if (qAbs(parallax)>0.f)
 		{
 			QString dx;
 			// distance in light years from parallax
-			float distance = 3.162e-5/(qAbs(parallax)*4.848e-9);
-			float distanceErr = 0.f;
+			distance = 3.162e-5f/(qAbs(parallax)*4.848e-9f);
+			distanceErr = 0.f;
 
 			if (parallaxErr>0.f)
-				distanceErr = 3.162e-5/(qAbs(parallaxErr)*4.848e-9);
+				distanceErr = qAbs(3.162e-5f/(qAbs(parallaxErr + parallax)*4.848e-9f) - distance);
 
 			if (distanceErr>0.f)
 				dx = QString("%1%2%3").arg(QString::number(distance, 'f', 3)).arg(QChar(0x00B1)).arg(QString::number(distanceErr, 'f', 3));
@@ -376,25 +351,36 @@ QString Nebula::getInfoString(const StelCore *core, const InfoStringGroup& flags
 			//TRANSLATORS: Unit of measure for distance - Light Years
 			QString duly = qc_("ly", "distance");
 
-			if (nType==NebAGx || nType==NebGx || nType==NebRGx || nType==NebIGx || nType==NebQSO || nType==NebPossQSO)
+			distance = oDistance;
+			distanceErr = oDistanceErr;
+			distanceLY = oDistance*dc;
+			distanceErrLY= oDistanceErr*dc;
+			if (oDistance>=1000.f)
 			{
-				dc = 3.262f;
-				ms = 3;
+				distance = oDistance/1000.f;
+				distanceErr = oDistanceErr/1000.f;
 				//TRANSLATORS: Unit of measure for distance - Megaparsecs
 				dupc = qc_("Mpc", "distance");
+			}
+
+			if (distanceLY>=1e6f)
+			{
+				distanceLY /= 1e6f;
+				distanceErrLY /= 1e6f;
+				ms = 3;
 				//TRANSLATORS: Unit of measure for distance - Millions of Light Years
 				duly = qc_("M ly", "distance");
 			}
 
 			if (oDistanceErr>0.f)
 			{
-				dx = QString("%1%2%3").arg(QString::number(oDistance, 'f', 3)).arg(QChar(0x00B1)).arg(QString::number(oDistanceErr, 'f', 3));
-				dy = QString("%1%2%3").arg(QString::number((double)oDistance*dc, 'f', ms)).arg(QChar(0x00B1)).arg(QString::number((double)oDistanceErr*dc, 'f', ms));
+				dx = QString("%1%2%3").arg(QString::number(distance, 'f', 3)).arg(QChar(0x00B1)).arg(QString::number(distanceErr, 'f', 3));
+				dy = QString("%1%2%3").arg(QString::number(distanceLY, 'f', ms)).arg(QChar(0x00B1)).arg(QString::number(distanceErrLY, 'f', ms));
 			}
 			else
 			{
-				dx = QString("%1").arg(QString::number(oDistance, 'f', 3));
-				dy = QString("%1").arg(QString::number((double)oDistance*dc, 'f', ms));
+				dx = QString("%1").arg(QString::number(distance, 'f', 3));
+				dy = QString("%1").arg(QString::number(distanceLY, 'f', ms));
 			}
 
 			oss << QString("%1: %2 %3 (%4 %5)").arg(q_("Distance"), dx, dupc, dy, duly) << "<br />";
@@ -413,18 +399,16 @@ QString Nebula::getInfoString(const StelCore *core, const InfoStringGroup& flags
 
 			oss << QString("%1: %2").arg(q_("Redshift"), z) << "<br />";
 		}
-		if (parallax!=0.f)
+		if (qAbs(parallax)>0.f)
 		{
 			QString px;
-
 			if (parallaxErr>0.f)
-				px = QString("%1%2%3").arg(QString::number(qAbs(parallax)*0.001, 'f', 5)).arg(QChar(0x00B1)).arg(QString::number(parallaxErr*0.001, 'f', 5));
+				px = QString("%1%2%3").arg(QString::number(qAbs(parallax), 'f', 3)).arg(QChar(0x00B1)).arg(QString::number(parallaxErr, 'f', 3));
 			else
-				px = QString("%1").arg(QString::number(qAbs(parallax)*0.001, 'f', 5));
+				px = QString("%1").arg(QString::number(qAbs(parallax), 'f', 3));
 
-			oss << QString("%1: %2\"").arg(q_("Parallax"), px) << "<br />";
+			oss << QString("%1: %2 %3").arg(q_("Parallax"), px, qc_("mas", "parallax")) << "<br />";
 		}
-
 		if (!getMorphologicalTypeDescription().isEmpty())
 			oss << QString("%1: %2.").arg(q_("Morphological description"), getMorphologicalTypeDescription()) << "<br />";
 	}
@@ -508,21 +492,21 @@ float Nebula::getVMagnitude(const StelCore* core) const
 double Nebula::getAngularSize(const StelCore *) const
 {
 	float size = majorAxisSize;
-	if (majorAxisSize!=minorAxisSize || minorAxisSize>0)
+	if (!fuzzyEquals(majorAxisSize, minorAxisSize) || minorAxisSize>0)
 		size = (majorAxisSize+minorAxisSize)*0.5f;
-	return size;
+	return static_cast<double>(size);
 }
 
 float Nebula::getSelectPriority(const StelCore* core) const
 {
 	float selectPriority = StelObject::getSelectPriority(core);
-	const NebulaMgr* nebMgr = ((NebulaMgr*)StelApp::getInstance().getModuleMgr().getModule("NebulaMgr"));
+	const NebulaMgr* nebMgr = (static_cast<NebulaMgr*>(StelApp::getInstance().getModuleMgr().getModule("NebulaMgr")));
 	// minimize unwanted selection of the deep-sky objects
 	if (!nebMgr->getFlagHints())
 		return selectPriority+3.f;
 
-	float lim, mag;
-	lim = mag = getVMagnitude(core);
+	float mag = getVMagnitude(core);
+	float lim = mag;
 	float mLim = 15.0f;
 
 	if (!objectInDisplayedCatalog() || !objectInDisplayedType())
@@ -530,7 +514,7 @@ float Nebula::getSelectPriority(const StelCore* core) const
 
 	const StelSkyDrawer* drawer = core->getSkyDrawer();
 
-	if (drawer->getFlagNebulaMagnitudeLimit() && (mag>drawer->getCustomNebulaMagnitudeLimit()))
+	if (drawer->getFlagNebulaMagnitudeLimit() && (mag>static_cast<float>(drawer->getCustomNebulaMagnitudeLimit())))
 		return selectPriority+mLim;
 	
 	const float maxMagHint = nebMgr->computeMaxMagHint(drawer);
@@ -556,35 +540,32 @@ float Nebula::getSelectPriority(const StelCore* core) const
 
 Vec3f Nebula::getInfoColor(void) const
 {
-	return ((NebulaMgr*)StelApp::getInstance().getModuleMgr().getModule("NebulaMgr"))->getLabelsColor();
+	return (static_cast<NebulaMgr*>(StelApp::getInstance().getModuleMgr().getModule("NebulaMgr")))->getLabelsColor();
 }
 
 double Nebula::getCloseViewFov(const StelCore*) const
 {
-	return majorAxisSize>0.f ? majorAxisSize * 4. : 1.;
+	return majorAxisSize>0.f ? static_cast<double>(majorAxisSize) * 4. : 1.;
 }
 
 float Nebula::getSurfaceBrightness(const StelCore* core, bool arcsec) const
 {
+	const float sq = (arcsec ? 3600.f*3600.f : 3600.f); // arcsec^2 or arcmin^2
 	float mag = getVMagnitude(core);
-	float sq = 3600.f; // arcmin^2
-	if (arcsec)
-		sq = 12.96e6; // 3600.f*3600.f, i.e. arcsec^2
 	if (bMag < 90.f && mag > 90.f)
 		mag = bMag;
 	if (mag<99.f && majorAxisSize>0.f && nType!=NebDn)
-		return mag + 2.5f*log10((double)getSurfaceArea()*sq);
+		return mag + 2.5f*log10f(getSurfaceArea()*sq);
 	else
 		return 99.f;
 }
 
 float Nebula::getSurfaceBrightnessWithExtinction(const StelCore* core, bool arcsec) const
 {
-	float sq = 3600.f; // arcmin^2
-	if (arcsec)
-		sq = 12.96e6; // 3600.f*3600.f, i.e. arcsec^2
-	if (getVMagnitudeWithExtinction(core)<99.f && majorAxisSize>0.f && nType!=NebDn)
-		return getVMagnitudeWithExtinction(core) + 2.5f*log10((double)getSurfaceArea()*sq);
+	const float sq = (arcsec ? 3600.f*3600.f : 3600.f); // arcsec^2 or arcmin^2
+	const float mag=getVMagnitudeWithExtinction(core);
+	if (mag<99.f && majorAxisSize>0.f && nType!=NebDn)
+		return mag + 2.5f*log10f(getSurfaceArea()*sq);
 	else
 		return 99.f;
 }
@@ -596,130 +577,24 @@ float Nebula::getContrastIndex(const StelCore* core) const
 	// Sky brightness
 	// Source: Schaefer, B.E. Feb. 1990. Telescopic Limiting Magnitude. PASP 102:212-229
 	// URL: http://adsbit.harvard.edu/cgi-bin/nph-iarticle_query?bibcode=1990PASP..102..212S [1990PASP..102..212S]
-	float B_mpsas = 21.58 - 5*log10(std::pow(10, 1.586 - core->getSkyDrawer()->getNELMFromBortleScale()/5)-1);
+	const float B_mpsas = 21.58f - 5*log10(std::pow(10.f, 1.586f - static_cast<float>(core->getSkyDrawer()->getNELMFromBortleScale())*0.2f)-1);
 	// Compute an extended object's contrast index
 	// Source: Clark, R.N., 1990. Appendix E in Visual Astronomy of the Deep Sky, Cambridge University Press and Sky Publishing.
 	// URL: http://www.clarkvision.com/visastro/appendix-e.html
-	return -0.4 * (getSurfaceBrightnessWithExtinction(core, true) - B_mpsas);
+	return -0.4f * (getSurfaceBrightnessWithExtinction(core, true) - B_mpsas);
 }
 
 float Nebula::getSurfaceArea(void) const
 {
-	if (majorAxisSize==minorAxisSize || minorAxisSize==0.f)
-		return M_PI*(majorAxisSize/2.f)*(majorAxisSize/2.f); // S = pi*R^2 = pi*(D/2)^2
+	if (minorAxisSize==0.f)
+		return M_PIf*(majorAxisSize/2.f)*(majorAxisSize/2.f); // S = pi*R^2 = pi*(D/2)^2
 	else
-		return M_PI*(majorAxisSize/2.f)*(minorAxisSize/2.f); // S = pi*a*b
+		return M_PIf*(majorAxisSize/2.f)*(minorAxisSize/2.f); // S = pi*a*b
 }
 
-Vec3f Nebula::getHintColor(void) const
+Vec3f Nebula::getHintColor(Nebula::NebulaType nType)
 {
-	Vec3f color=circleColor;
-	switch (nType)
-	{
-		case NebGx:
-			color=galaxyColor;
-			break;
-		case NebIGx:
-			color=interactingGalaxyColor;
-			break;
-		case NebAGx:
-			color=activeGalaxyColor;
-			break;
-		case NebQSO:
-			color=quasarColor;
-			break;
-		case NebPossQSO:
-			color=possibleQuasarColor;
-			break;
-		case NebBLL:
-			color=blLacObjectColor;
-			break;
-		case NebBLA:
-			color=blazarColor;
-			break;
-		case NebRGx:
-			color=radioGalaxyColor;
-			break;
-		case NebOc:
-			color=openClusterColor;
-			break;
-		case NebSA:
-			color=stellarAssociationColor;
-			break;
-		case NebSC:
-			color=starCloudColor;
-			break;
-		case NebCl:
-			color=clusterColor;
-			break;
-		case NebGc:
-			color=globularClusterColor;
-			break;
-		case NebN:
-			color=nebulaColor;
-			break;
-		case NebHII:
-			color=hydrogenRegionColor;
-			break;
-		case NebMolCld:
-			color=molecularCloudColor;
-			break;
-		case NebYSO:
-			color=youngStellarObjectColor;
-			break;
-		case NebRn:
-			color=reflectionNebulaColor;
-			break;
-		case NebSNR:
-			color=supernovaRemnantColor;
-			break;
-		case NebBn:
-			color=bipolarNebulaColor;
-			break;
-		case NebEn:
-			color=emissionNebulaColor;
-			break;
-		case NebPn:
-			color=planetaryNebulaColor;
-			break;
-		case NebPossPN:
-			color=possiblePlanetaryNebulaColor;
-			break;
-		case NebPPN:
-			color=protoplanetaryNebulaColor;
-			break;
-		case NebDn:
-			color=darkNebulaColor;
-			break;
-		case NebCn:
-			color=clusterWithNebulosityColor;
-			break;
-		case NebEMO:
-			color=emissionObjectColor;
-			break;
-		case NebStar:
-			color=starColor;
-			break;
-		case NebSymbioticStar:
-			color=symbioticStarColor;
-			break;
-		case NebEmissionLineStar:
-			color=emissionLineStarColor;
-			break;
-		case NebSNC:
-			color=supernovaCandidateColor;
-			break;
-		case NebSNRC:
-			color=supernovaRemnantCandidateColor;
-			break;
-		case NebGxCl:
-			color=galaxyClusterColor;
-			break;
-		default:
-			color=circleColor;
-	}
-
-	return color;
+	return hintColorMap.value(nType, hintColorMap.value(NebUnknown));
 }
 
 float Nebula::getVisibilityLevelByMagnitude(void) const
@@ -748,10 +623,8 @@ float Nebula::getVisibilityLevelByMagnitude(void) const
 			// The qMin() maximized the visibility gain for large objects.
 			if (majorAxisSize>0.f && mag<90.f)
 				lim = mLim - mag - 2.0f*qMin(majorAxisSize, 1.5f);
-			else if (B_nb>0)
-				lim = 9.0f;
 			else
-				lim= 12.0f; // GZ I assume LDN objects are rather elusive.
+				lim = (B_nb>0 ? 9.0f : 12.0f); // GZ I assume LDN objects are rather elusive.
 		}
 		else if (nType==NebHII) // NebHII={Sharpless, LBN, RCW}
 		{ // artificially increase visibility of (most) Sharpless objects? No magnitude recorded:-(
@@ -765,16 +638,16 @@ float Nebula::getVisibilityLevelByMagnitude(void) const
 void Nebula::drawOutlines(StelPainter &sPainter, float maxMagHints) const
 {
 	size_t segments = outlineSegments.size();
-	Vec3f color = getHintColor();
+	Vec3f color = getHintColor(nType);
 
 	// tune limits for outlines
 	float oLim = getVisibilityLevelByMagnitude() - 3.f;
 
 	float lum = 1.f;
-	Vec3f col(color[0]*lum*hintsBrightness, color[1]*lum*hintsBrightness, color[2]*lum*hintsBrightness);
+	Vec3f col(color*lum*hintsBrightness);
 	if (!objectInDisplayedType())
-		col = Vec3f(0.f,0.f,0.f);
-	sPainter.setColor(col[0], col[1], col[2], 1);
+		col.set(0.f,0.f,0.f);
+	sPainter.setColor(col, 1);
 
 	// Show outlines
 	if (segments>0 && flagUseOutlines && oLim<=maxMagHints)
@@ -812,13 +685,13 @@ void Nebula::drawHints(StelPainter& sPainter, float maxMagHints) const
 	if (getVisibilityLevelByMagnitude()>maxMagHints)
 		return;
 
-	Vec3f color = getHintColor();
+	Vec3f color = getHintColor(nType);
 
 	const float size = 6.0f;
 	float scaledSize = 0.0f;
 	if (drawHintProportional)
 	{
-		scaledSize = getAngularSize(Q_NULLPTR) *M_PI/180.*sPainter.getProjector()->getPixelPerRadAtCenter();
+		scaledSize = static_cast<float>(getAngularSize(Q_NULLPTR)) *M_PI_180f*static_cast<float>(sPainter.getProjector()->getPixelPerRadAtCenter());
 	}
 	const float finalSize=qMax(size, scaledSize);
 
@@ -901,11 +774,11 @@ void Nebula::drawHints(StelPainter& sPainter, float maxMagHints) const
 	}
 
 	float lum = 1.f;
-	Vec3f col(color[0]*lum*hintsBrightness, color[1]*lum*hintsBrightness, color[2]*lum*hintsBrightness);
+	Vec3f col(color*lum*hintsBrightness);
 	if (!objectInDisplayedType())
-		col = Vec3f(0.f,0.f,0.f);
+		col.set(0.f,0.f,0.f);
 
-	sPainter.setColor(col[0], col[1], col[2], 1);
+	sPainter.setColor(col, 1);
 	sPainter.setBlending(true, GL_ONE, GL_ONE);
 
 	// Rotation looks good only for galaxies.
@@ -917,11 +790,11 @@ void Nebula::drawHints(StelPainter& sPainter, float maxMagHints) const
 		XYZrel[2]*=0.99;
 		Vec3d XYrel;
 		sPainter.getProjector()->project(XYZrel, XYrel);
-		float screenAngle = atan2(XYrel[1]-XY[1], XYrel[0]-XY[0]);
-		sPainter.drawSprite2dMode(XY[0], XY[1], finalSize, screenAngle*180./M_PI + orientationAngle);
+		float screenAngle = static_cast<float>(atan2(XYrel[1]-XY[1], XYrel[0]-XY[0]));
+		sPainter.drawSprite2dMode(static_cast<float>(XY[0]), static_cast<float>(XY[1]), finalSize, screenAngle*M_180_PIf + orientationAngle);
 	}
 	else	// no galaxy
-		sPainter.drawSprite2dMode(XY[0], XY[1], finalSize);
+		sPainter.drawSprite2dMode(static_cast<float>(XY[0]), static_cast<float>(XY[1]), finalSize);
 }
 
 void Nebula::drawLabel(StelPainter& sPainter, float maxMagLabel) const
@@ -934,20 +807,16 @@ void Nebula::drawLabel(StelPainter& sPainter, float maxMagLabel) const
 	if (getVisibilityLevelByMagnitude()>maxMagLabel)
 		return;
 
-	Vec3f col(labelColor[0], labelColor[1], labelColor[2]);
-	if (objectInDisplayedType())
-		sPainter.setColor(col[0], col[1], col[2], hintsBrightness);
-	else
-		sPainter.setColor(col[0], col[1], col[2], 0.f);
+	sPainter.setColor(labelColor, objectInDisplayedType() ? hintsBrightness : 0.f);
 
-	float size = getAngularSize(Q_NULLPTR)*M_PI/180.*sPainter.getProjector()->getPixelPerRadAtCenter();
-	float shift = 5.f + (drawHintProportional ? size*0.9f : 0.f);
+	const float size = static_cast<float>(getAngularSize(Q_NULLPTR))*M_PI_180f*sPainter.getProjector()->getPixelPerRadAtCenter();
+	const float shift = 5.f + (drawHintProportional ? size*0.9f : 0.f);
 
 	QString str = getNameI18n();
 	if (str.isEmpty() || designationUsage)
 		str = getDSODesignation();
 
-	sPainter.drawText(XY[0]+shift, XY[1]+shift, str, 0, 0, 0, false);
+	sPainter.drawText(static_cast<float>(XY[0])+shift, static_cast<float>(XY[1])+shift, str, 0, 0, 0, false);
 }
 
 QString Nebula::getDSODesignation() const
@@ -1002,6 +871,10 @@ QString Nebula::getDSODesignation() const
 		str = QString("Abell %1").arg(Abell_nb);
 	else if (catalogFilters&CatESO && !ESO_nb.isEmpty())
 		str = QString("ESO %1").arg(ESO_nb);
+	else if (catalogFilters&CatVdBH && !VdBH_nb.isEmpty())
+		str = QString("VdBH %1").arg(VdBH_nb);
+	else if (catalogFilters&CatDWB && DWB_nb > 0)
+		str = QString("DWB %1").arg(DWB_nb);
 
 	return str;
 }
@@ -1015,15 +888,15 @@ void Nebula::readDSO(QDataStream &in)
 		>> orientationAngle >> redshift >> redshiftErr >> parallax >> parallaxErr >> oDistance >> oDistanceErr
 		>> NGC_nb >> IC_nb >> M_nb >> C_nb >> B_nb >> Sh2_nb >> VdB_nb >> RCW_nb >> LDN_nb >> LBN_nb >> Cr_nb
 		>> Mel_nb >> PGC_nb >> UGC_nb >> Ced_nb >> Arp_nb >> VV_nb >> PK_nb >> PNG_nb >> SNRG_nb >> ACO_nb
-		>> HCG_nb >> Abell_nb >> ESO_nb;
+		>> HCG_nb >> Abell_nb >> ESO_nb >> VdBH_nb >> DWB_nb;
 
-	int f = NGC_nb + IC_nb + M_nb + C_nb + B_nb + Sh2_nb + VdB_nb + RCW_nb + LDN_nb + LBN_nb + Cr_nb + Mel_nb + PGC_nb + UGC_nb + Arp_nb + VV_nb + Abell_nb;
-	if (f==0 && Ced_nb.isEmpty() && PK_nb.isEmpty() && PNG_nb.isEmpty() && SNRG_nb.isEmpty() && ACO_nb.isEmpty() && HCG_nb.isEmpty() && ESO_nb.isEmpty())
+	const unsigned int f = NGC_nb + IC_nb + M_nb + C_nb + B_nb + Sh2_nb + VdB_nb + RCW_nb + LDN_nb + LBN_nb + Cr_nb + Mel_nb + PGC_nb + UGC_nb + Arp_nb + VV_nb + Abell_nb + DWB_nb;
+	if (f==0 && Ced_nb.isEmpty() && PK_nb.isEmpty() && PNG_nb.isEmpty() && SNRG_nb.isEmpty() && ACO_nb.isEmpty() && HCG_nb.isEmpty() && ESO_nb.isEmpty() && VdBH_nb.isEmpty())
 		withoutID = true;
 
 	StelUtils::spheToRect(ra,dec,XYZ);
 	Q_ASSERT(fabs(XYZ.lengthSquared()-1.)<1e-9);
-	nType = (Nebula::NebulaType)oType;
+	nType = static_cast<Nebula::NebulaType>(oType);
 	pointRegion = SphericalRegionP(new SphericalPoint(getJ2000EquatorialPos(Q_NULLPTR)));
 }
 
@@ -1032,7 +905,6 @@ bool Nebula::objectInDisplayedType() const
 	if (!flagUseTypeFilters)
 		return true;
 
-	bool r = false;
 	int cntype = -1;
 	switch (nType)
 	{
@@ -1050,12 +922,11 @@ bool Nebula::objectInDisplayedType() const
 		case NebIGx:
 			cntype = 2; // Interacting Galaxies
 			break;
-		case NebOc:
-		case NebGc:
+		case NebOc:		
 		case NebCl:
 		case NebSA:
 		case NebSC:
-			cntype = 3; // Star Clusters
+			cntype = 3; // Open Star Clusters
 			break;
 		case NebHII:
 		case NebISM:
@@ -1088,93 +959,61 @@ bool Nebula::objectInDisplayedType() const
 		case NebGxCl:
 			cntype = 10;
 			break;
-		default:
+		case NebGc:
 			cntype = 11;
 			break;
+		default:
+			cntype = 12;
+			break;
 	}
-	if (typeFilters&TypeGalaxies && cntype==0)
-		r = true;
-	else if (typeFilters&TypeActiveGalaxies && cntype==1)
-		r = true;
-	else if (typeFilters&TypeInteractingGalaxies && cntype==2)
-		r = true;
-	else if (typeFilters&TypeStarClusters && cntype==3)
-		r = true;
-	else if (typeFilters&TypeHydrogenRegions && cntype==4)
-		r = true;
-	else if (typeFilters&TypeBrightNebulae && cntype==5)
-		r = true;
-	else if (typeFilters&TypeDarkNebulae && cntype==6)
-		r = true;
-	else if (typeFilters&TypePlanetaryNebulae && cntype==7)
-		r = true;
-	else if (typeFilters&TypeSupernovaRemnants && cntype==8)
-		r = true;
-	else if (typeFilters&TypeStarClusters && (typeFilters&TypeBrightNebulae || typeFilters&TypeHydrogenRegions) && cntype==9)
-		r = true;
-	else if (typeFilters&TypeGalaxyClusters && cntype==10)
-		r = true;
-	else if (typeFilters&TypeOther && cntype==11)
-		r = true;
+	bool r = ( (typeFilters&TypeGalaxies             && cntype==0)
+		|| (typeFilters&TypeActiveGalaxies       && cntype==1)
+		|| (typeFilters&TypeInteractingGalaxies  && cntype==2)
+		|| (typeFilters&TypeOpenStarClusters     && cntype==3)
+		|| (typeFilters&TypeGlobularStarClusters && cntype==11)
+		|| (typeFilters&TypeHydrogenRegions      && cntype==4)
+		|| (typeFilters&TypeBrightNebulae        && cntype==5)
+		|| (typeFilters&TypeDarkNebulae          && cntype==6)
+		|| (typeFilters&TypePlanetaryNebulae     && cntype==7)
+		|| (typeFilters&TypeSupernovaRemnants    && cntype==8)
+		|| (typeFilters&TypeOpenStarClusters     && (typeFilters&TypeBrightNebulae || typeFilters&TypeHydrogenRegions) && cntype==9)
+		|| (typeFilters&TypeGalaxyClusters       && cntype==10)
+		|| (typeFilters&TypeOther                && cntype==12));
 
 	return r;
 }
 
 bool Nebula::objectInDisplayedCatalog() const
 {
-	bool r = false;
-	if ((catalogFilters&CatM) && (M_nb>0))
-		r = true;
-	else if ((catalogFilters&CatC) && (C_nb>0))
-		r = true;
-	else if ((catalogFilters&CatNGC) && (NGC_nb>0))
-		r = true;
-	else if ((catalogFilters&CatIC) && (IC_nb>0))
-		r = true;
-	else if ((catalogFilters&CatB) && (B_nb>0))
-		r = true;
-	else if ((catalogFilters&CatSh2) && (Sh2_nb>0))
-		r = true;
-	else if ((catalogFilters&CatVdB) && (VdB_nb>0))
-		r = true;
-	else if ((catalogFilters&CatRCW) && (RCW_nb>0))
-		r = true;
-	else if ((catalogFilters&CatLDN) && (LDN_nb>0))
-		r = true;
-	else if ((catalogFilters&CatLBN) && (LBN_nb>0))
-		r = true;
-	else if ((catalogFilters&CatCr) && (Cr_nb>0))
-		r = true;
-	else if ((catalogFilters&CatMel) && (Mel_nb>0))
-		r = true;
-	else if ((catalogFilters&CatPGC) && (PGC_nb>0))
-		r = true;
-	else if ((catalogFilters&CatUGC) && (UGC_nb>0))
-		r = true;
-	else if ((catalogFilters&CatCed) && !(Ced_nb.isEmpty()))
-		r = true;
-	else if ((catalogFilters&CatArp) && (Arp_nb>0))
-		r = true;
-	else if ((catalogFilters&CatVV) && (VV_nb>0))
-		r = true;
-	else if ((catalogFilters&CatPK) && !(PK_nb.isEmpty()))
-		r = true;
-	else if ((catalogFilters&CatPNG) && !(PNG_nb.isEmpty()))
-		r = true;
-	else if ((catalogFilters&CatSNRG) && !(SNRG_nb.isEmpty()))
-		r = true;
-	else if ((catalogFilters&CatACO) && (!ACO_nb.isEmpty()))
-		r = true;
-	else if ((catalogFilters&CatHCG) && (!HCG_nb.isEmpty()))
-		r = true;
-	else if ((catalogFilters&CatAbell) && (Abell_nb>0))
-		r = true;
-	else if ((catalogFilters&CatESO) && (!ESO_nb.isEmpty()))
-		r = true;
+	bool r = ( ((catalogFilters&CatM)     && (M_nb>0))
+		|| ((catalogFilters&CatC)     && (C_nb>0))
+		|| ((catalogFilters&CatNGC)   && (NGC_nb>0))
+		|| ((catalogFilters&CatIC)    && (IC_nb>0))
+		|| ((catalogFilters&CatB)     && (B_nb>0))
+		|| ((catalogFilters&CatSh2)   && (Sh2_nb>0))
+		|| ((catalogFilters&CatVdB)   && (VdB_nb>0))
+		|| ((catalogFilters&CatRCW)   && (RCW_nb>0))
+		|| ((catalogFilters&CatLDN)   && (LDN_nb>0))
+		|| ((catalogFilters&CatLBN)   && (LBN_nb>0))
+		|| ((catalogFilters&CatCr)    && (Cr_nb>0))
+		|| ((catalogFilters&CatMel)   && (Mel_nb>0))
+		|| ((catalogFilters&CatPGC)   && (PGC_nb>0))
+		|| ((catalogFilters&CatUGC)   && (UGC_nb>0))
+		|| ((catalogFilters&CatCed)   && !(Ced_nb.isEmpty()))
+		|| ((catalogFilters&CatArp)   && (Arp_nb>0))
+		|| ((catalogFilters&CatVV)    && (VV_nb>0))
+		|| ((catalogFilters&CatPK)    && !(PK_nb.isEmpty()))
+		|| ((catalogFilters&CatPNG)   && !(PNG_nb.isEmpty()))
+		|| ((catalogFilters&CatSNRG)  && !(SNRG_nb.isEmpty()))
+		|| ((catalogFilters&CatACO)   && (!ACO_nb.isEmpty()))
+		|| ((catalogFilters&CatHCG)   && (!HCG_nb.isEmpty()))
+		|| ((catalogFilters&CatAbell) && (Abell_nb>0))
+		|| ((catalogFilters&CatESO)   && (!ESO_nb.isEmpty()))
+		|| ((catalogFilters&CatVdBH)  && (!VdBH_nb.isEmpty()))
+		|| ((catalogFilters&CatDWB)   && (DWB_nb>0)))
 
-	// Special case: objects without ID from current catalogs
-	if (withoutID)
-		r = true;
+		// Special case: objects without ID from current catalogs
+		|| (withoutID);
 
 	return r;
 }
@@ -1184,11 +1023,8 @@ bool Nebula::objectInAllowedSizeRangeLimits(void) const
 	bool r = true;
 	if (flagUseSizeLimits)
 	{
-		float size = 60.f * qMax(majorAxisSize, minorAxisSize);
-		if (size>=minSizeLimit && size<=maxSizeLimit)
-			r = true;
-		else
-			r = false;
+		const double size = 60. * static_cast<double>(qMax(majorAxisSize, minorAxisSize));
+		r = (size>=minSizeLimit && size<=maxSizeLimit);
 	}
 	return r;
 }
@@ -1214,8 +1050,7 @@ QString Nebula::getMorphologicalTypeDescription(void) const
 	else
 		m = mTypeString;
 
-	QStringList glclass;
-	glclass << "I" << "II" << "III" << "IV" << "V" << "VI" << "VII" << "VIII" << "IX" << "X" << "XI" << "XII";
+	static const QStringList glclass = {"I", "II", "III", "IV", "V", "VI", "VII", "VIII", "IX", "X", "XI", "XII"};
 
 	if (GlClRx.exactMatch(m)) // Globular Clusters
 	{
@@ -1268,9 +1103,9 @@ QString Nebula::getMorphologicalTypeDescription(void) const
 
 	if (OClRx.exactMatch(m)) // Open Clusters
 	{
-		QStringList occlass, ocrich, rtxt;
-		occlass << "I" << "II" << "III" << "IV";
-		ocrich << "p" << "m" << "r";
+		QStringList rtxt;
+		static const QStringList occlass = { "I", "II", "III", "IV"};
+		static const QStringList ocrich = { "p", "m", "r"};
 		switch(occlass.indexOf(OClRx.capturedTexts().at(1).trimmed()))
 		{
 			case 0:
@@ -1334,9 +1169,9 @@ QString Nebula::getMorphologicalTypeDescription(void) const
 
 	if (VdBRx.exactMatch(m)) // Reflection Nebulae
 	{
-		QStringList rnclass, rnbrightness, rtx;
-		rnclass << "I" << "II" << "I-II" << "II P" << "P";
-		rnbrightness << "VBR" << "VB" << "BR" << "M" << "F" << "VF" << ":";
+		QStringList rtx;
+		static const QStringList rnclass = { "I", "II", "I-II", "II P", "P"};
+		static const QStringList rnbrightness = { "VBR", "VB", "BR", "M", "F", "VF", ":"};
 		switch(rnbrightness.indexOf(VdBRx.capturedTexts().at(2).trimmed()))
 		{
 			case 0:
@@ -1402,55 +1237,27 @@ QString Nebula::getMorphologicalTypeDescription(void) const
 
 	if (HIIRx.exactMatch(m)) // HII regions
 	{
-		int form	= HIIRx.capturedTexts().at(1).toInt();
-		int structure	= HIIRx.capturedTexts().at(2).toInt();
-		int brightness	= HIIRx.capturedTexts().at(3).toInt();
+		const int form	= HIIRx.capturedTexts().at(1).toInt();
+		const int structure	= HIIRx.capturedTexts().at(2).toInt();
+		const int brightness	= HIIRx.capturedTexts().at(3).toInt();
+		const QStringList formList={
+			q_("circular form"),
+			q_("elliptical form"),
+			q_("irregular form")};
+		const QStringList structureList={
+			q_("amorphous structure"),
+			q_("conventional structure"),
+			q_("filamentary structure")};
+		const QStringList brightnessList={
+			qc_("faintest", "HII region brightness"),
+			qc_("moderate brightness", "HII region brightness"),
+			qc_("brightest", "HII region brightness")};
+
 		QStringList morph;
-		switch(form)
-		{
-			case 1:
-				morph << q_("circular form");
-				break;
-			case 2:
-				morph << q_("elliptical form");
-				break;
-			case 3:
-				morph << q_("irregular form");
-				break;
-			default:
-				morph << q_("undocumented form");
-				break;
-		}
-		switch(structure)
-		{
-			case 1:
-				morph << q_("amorphous structure");
-				break;
-			case 2:
-				morph << q_("conventional structure");
-				break;
-			case 3:
-				morph << q_("filamentary structure");
-				break;
-			default:
-				morph << q_("undocumented structure");
-				break;
-		}
-		switch(brightness)
-		{
-			case 1:
-				morph << qc_("faintest", "HII region brightness");
-				break;
-			case 2:
-				morph << qc_("moderate brightness", "HII region brightness");
-				break;
-			case 3:
-				morph << qc_("brightest", "HII region brightness");
-				break;
-			default:
-				morph << q_("undocumented brightness");
-				break;
-		}
+		morph << formList.value(form-1, q_("undocumented form"));
+		morph << structureList.value(structure-1, q_("undocumented structure"));
+		morph << brightnessList.value(brightness-1, q_("undocumented brightness"));
+
 		r = morph.join(",<br />");
 	}
 
@@ -1482,120 +1289,47 @@ QString Nebula::getMorphologicalTypeDescription(void) const
 	return r;
 }
 
-QString Nebula::getTypeString(void) const
+QString Nebula::getTypeString(Nebula::NebulaType nType)
 {
-	QString wsType;
+	return typeStringMap.value(nType, q_("undocumented type"));
+}
 
-	switch(nType)
-	{
-		case NebGx:
-			wsType = q_("galaxy");
-			break;
-		case NebAGx:
-			wsType = q_("active galaxy");
-			break;
-		case NebRGx:
-			wsType = q_("radio galaxy");
-			break;
-		case NebIGx:
-			wsType = q_("interacting galaxy");
-			break;
-		case NebQSO:
-			wsType = q_("quasar");
-			break;
-		case NebCl:
-			wsType = q_("star cluster");
-			break;
-		case NebOc:
-			wsType = q_("open star cluster");
-			break;
-		case NebGc:
-			wsType = q_("globular star cluster");
-			break;
-		case NebN:
-			wsType = q_("nebula");
-			break;
-		case NebPn:
-			wsType = q_("planetary nebula");
-			break;
-		case NebDn:
-			wsType = q_("dark nebula");
-			break;
-		case NebCn:
-			wsType = q_("cluster associated with nebulosity");
-			break;
-		case NebBn:
-			wsType = q_("bipolar nebula");
-			break;
-		case NebEn:
-			wsType = q_("emission nebula");
-			break;
-		case NebHII:
-			wsType = q_("HII region");
-			break;
-		case NebRn:
-			wsType = q_("reflection nebula");
-			break;		
-		case NebSNR:
-			wsType = q_("supernova remnant");
-			break;
-		case NebSNC:
-			wsType = q_("supernova candidate");
-			break;
-		case NebSNRC:
-			wsType = q_("supernova remnant candidate");
-			break;
-		case NebSA:
-			wsType = q_("stellar association");
-			break;
-		case NebSC:
-			wsType = q_("star cloud");
-			break;
-		case NebISM:
-			wsType = q_("interstellar matter");
-			break;
-		case NebEMO:
-			wsType = q_("emission object");
-			break;
-		case NebBLL:
-			wsType = q_("BL Lac object");
-			break;
-		case NebBLA:
-			wsType = q_("blazar");
-			break;
-		case NebMolCld:
-			wsType = q_("molecular cloud");
-			break;
-		case NebYSO:
-			wsType = q_("young stellar object");
-			break;
-		case NebPossQSO:
-			wsType = q_("possible quasar");
-			break;
-		case NebPossPN:
-			wsType = q_("possible planetary nebula");
-			break;
-		case NebPPN:
-			wsType = q_("protoplanetary nebula");
-			break;
-		case NebStar:
-			wsType = q_("star");
-			break;
-		case NebSymbioticStar:
-			wsType = q_("symbiotic star");
-			break;
-		case NebEmissionLineStar:
-			wsType = q_("emission-line star");
-			break;
-		case NebGxCl:
-			wsType = q_("cluster of galaxies");
-			break;
-		case NebUnknown:
-			wsType = q_("object of unknown nature");
-			break;
-		default:
-			wsType = q_("undocumented type");
-			break;
-	}
-	return wsType;
+void Nebula::buildTypeStringMap()
+{
+	Nebula::typeStringMap.clear();
+	Nebula::typeStringMap.insert( NebGx     , q_("galaxy") );
+	Nebula::typeStringMap.insert( NebAGx    , q_("active galaxy") );
+	Nebula::typeStringMap.insert( NebRGx    , q_("radio galaxy") );
+	Nebula::typeStringMap.insert( NebIGx    , q_("interacting galaxy") );
+	Nebula::typeStringMap.insert( NebQSO    , q_("quasar") );
+	Nebula::typeStringMap.insert( NebCl     , q_("star cluster") );
+	Nebula::typeStringMap.insert( NebOc     , q_("open star cluster") );
+	Nebula::typeStringMap.insert( NebGc     , q_("globular star cluster") );
+	Nebula::typeStringMap.insert( NebSA     , q_("stellar association") );
+	Nebula::typeStringMap.insert( NebSC     , q_("star cloud") );
+	Nebula::typeStringMap.insert( NebN      , q_("nebula") );
+	Nebula::typeStringMap.insert( NebPn     , q_("planetary nebula") );
+	Nebula::typeStringMap.insert( NebDn     , q_("dark nebula") );
+	Nebula::typeStringMap.insert( NebRn     , q_("reflection nebula") );
+	Nebula::typeStringMap.insert( NebBn     , q_("bipolar nebula") );
+	Nebula::typeStringMap.insert( NebEn     , q_("emission nebula") );
+	Nebula::typeStringMap.insert( NebCn     , q_("cluster associated with nebulosity") );
+	Nebula::typeStringMap.insert( NebHII    , q_("HII region") );
+	Nebula::typeStringMap.insert( NebSNR    , q_("supernova remnant") );
+	Nebula::typeStringMap.insert( NebISM    , q_("interstellar matter") );
+	Nebula::typeStringMap.insert( NebEMO    , q_("emission object") );
+	Nebula::typeStringMap.insert( NebBLL    , q_("BL Lac object") );
+	Nebula::typeStringMap.insert( NebBLA    , q_("blazar") );
+	Nebula::typeStringMap.insert( NebMolCld , q_("molecular cloud") );
+	Nebula::typeStringMap.insert( NebYSO    , q_("young stellar object") );
+	Nebula::typeStringMap.insert( NebPossQSO, q_("possible quasar") );
+	Nebula::typeStringMap.insert( NebPossPN , q_("possible planetary nebula") );
+	Nebula::typeStringMap.insert( NebPPN    , q_("protoplanetary nebula") );
+	Nebula::typeStringMap.insert( NebStar   , q_("star") );
+	Nebula::typeStringMap.insert( NebSymbioticStar   , q_("symbiotic star") );
+	Nebula::typeStringMap.insert( NebEmissionLineStar, q_("emission-line star") );
+	Nebula::typeStringMap.insert( NebSNC    , q_("supernova candidate") );
+	Nebula::typeStringMap.insert( NebSNRC   , q_("supernova remnant candidate") );
+	Nebula::typeStringMap.insert( NebGxCl   , q_("cluster of galaxies") );
+	Nebula::typeStringMap.insert( NebUnknown, q_("object of unknown nature") );
 }
