@@ -38,70 +38,70 @@ class StelPainter;
 class NomenclatureItem : public StelObject
 {
 	friend class NomenclatureMgr;
+	Q_ENUMS(NomenclatureItemType)
 public:
 	static const QString NOMENCLATURE_TYPE;
 
 	// Details: https://planetarynames.wr.usgs.gov/DescriptorTerms
-	Q_ENUMS(NomenclatureItemType)
 	enum NomenclatureItemType
 	{
-		niUNDEFINED		=  0, // Undefined type of feature. THIS IS ONLY IN CASE OF ERROR!
+		niUNDEFINED			=  0, // Undefined type of feature. THIS IS ONLY IN CASE OF ERROR!
 		niAlbedoFeature		=  1, // type="albedo feature"
-		niArcus			=  2, // type="arcus"
-		niAstrum		=  3, // type="astrum"
-		niCatena		=  4, // type="catena"
-		niCavus			=  5, // type="cavus"
-		niChaos			=  6, // type="chaos"
-		niChasma		=  7, // type="chasma"
-		niCollis		=  8, // type="collis"
-		niCorona		=  9, // type="corona"
-		niCrater		= 10, // type="crater"
-		niDorsum		= 11, // type="dorsum"
-		niEruptiveCenter	= 12, // type="eruptive center"
-		niFacula		= 13, // type="facula"
-		niFarrum		= 14, // type="farrum"
-		niFlexus		= 15, // type="flexus"
-		niFluctus		= 16, // type="fluctus"
-		niFlumen		= 17, // type="flumen"
-		niFretum		= 18, // type="fretum"
-		niFossa			= 19, // type="fossa"
-		niInsula		= 20, // type="insula"
-		niLabes			= 21, // type="labes"
-		niLabyrinthus		= 22, // type="labyrinthus"
-		niLacuna		= 23, // type="lacuna"
-		niLacus			= 24, // type="lacus"
+		niArcus				=  2, // type="arcus"
+		niAstrum				=  3, // type="astrum"
+		niCatena				=  4, // type="catena"
+		niCavus				=  5, // type="cavus"
+		niChaos				=  6, // type="chaos"
+		niChasma				=  7, // type="chasma"
+		niCollis				=  8, // type="collis"
+		niCorona				=  9, // type="corona"
+		niCrater				= 10, // type="crater"
+		niDorsum				= 11, // type="dorsum"
+		niEruptiveCenter		= 12, // type="eruptive center"
+		niFacula				= 13, // type="facula"
+		niFarrum				= 14, // type="farrum"
+		niFlexus				= 15, // type="flexus"
+		niFluctus				= 16, // type="fluctus"
+		niFlumen				= 17, // type="flumen"
+		niFretum				= 18, // type="fretum"
+		niFossa				= 19, // type="fossa"
+		niInsula				= 20, // type="insula"
+		niLabes				= 21, // type="labes"
+		niLabyrinthus			= 22, // type="labyrinthus"
+		niLacuna				= 23, // type="lacuna"
+		niLacus				= 24, // type="lacus"
 		niLargeRingedFeature	= 25, // type="large ringed feature"
-		niLinea			= 26, // type="linea"
-		niLingula		= 27, // type="lingula"
-		niMacula		= 28, // type="macula"
-		niMare			= 29, // type="mare"
-		niMensa			= 30, // type="mensa"
-		niMons			= 31, // type="mons"
-		niOceanus		= 32, // type="oceanus"
-		niPalus			= 33, // type="palus"
-		niPatera		= 34, // type="patera"
-		niPlanitia		= 35, // type="planitia"
-		niPlanum		= 36, // type="planum"
-		niPlume			= 37, // type="plume"
+		niLinea				= 26, // type="linea"
+		niLingula				= 27, // type="lingula"
+		niMacula				= 28, // type="macula"
+		niMare				= 29, // type="mare"
+		niMensa				= 30, // type="mensa"
+		niMons				= 31, // type="mons"
+		niOceanus			= 32, // type="oceanus"
+		niPalus				= 33, // type="palus"
+		niPatera				= 34, // type="patera"
+		niPlanitia				= 35, // type="planitia"
+		niPlanum				= 36, // type="planum"
+		niPlume				= 37, // type="plume"
 		niPromontorium		= 38, // type="promontorium"
-		niRegio			= 39, // type="regio"
-		niRima			= 40, // type="rima"
-		niRupes			= 41, // type="rupes"
-		niScopulus		= 42, // type="scopulus"
-		niSerpens		= 43, // type="serpens"
-		niSulcus		= 44, // type="sulcus"
-		niSinus			= 45, // type="sinus"
-		niTerra			= 46, // type="terra"
-		niTholus		= 47, // type="tholus"
-		niUnda			= 48, // type="unda"
-		niVallis		= 49, // type="vallis"
-		niVastitas		= 50, // type="vastitas"
-		niVirga			= 51, // type="virga"
-		niLandingSite		= 52, // type="landing site"
-		niLenticula		= 53, // type="lenticula"
-		niReticulum		= 54, // type="reticulum"
-		niSatelliteFeature	= 55, // type="satellite feature"
-		niTessera		= 56  // type="tessera"
+		niRegio				= 39, // type="regio"
+		niRima				= 40, // type="rima"
+		niRupes				= 41, // type="rupes"
+		niScopulus			= 42, // type="scopulus"
+		niSerpens				= 43, // type="serpens"
+		niSulcus				= 44, // type="sulcus"
+		niSinus				= 45, // type="sinus"
+		niTerra				= 46, // type="terra"
+		niTholus				= 47, // type="tholus"
+		niUnda				= 48, // type="unda"
+		niVallis				= 49, // type="vallis"
+		niVastitas				= 50, // type="vastitas"
+		niVirga				= 51, // type="virga"
+		niLandingSite			= 52, // type="landing site"
+		niLenticula			= 53, // type="lenticula"
+		niReticulum			= 54, // type="reticulum"
+		niSatelliteFeature		= 55, // type="satellite feature"
+		niTessera				= 56  // type="tessera"
 	};
 
 	NomenclatureItem(PlanetP nPlanet, int nId, const QString& nName, const QString& nContext, NomenclatureItemType nItemType, float nLatitude, float nLongitude, float nSize);
@@ -140,11 +140,7 @@ public:
 	virtual void translateName(const StelTranslator &trans);
 
 	void draw(StelCore* core, StelPainter *painter);
-
-	QString getNomenclatureTypeString() const;	
-	QString getNomenclatureTypeDescription() const;
 	NomenclatureItemType getNomenclatureType() const { return nType;}
-
 	void update(double deltaTime);
 
 	void setFlagLabels(bool b){ labelsFader = b; }
@@ -155,6 +151,11 @@ public:
 	PlanetP getPlanet(void) const { return planet;}
 	float getLatitude(void) const {return latitude;}
 	float getLongitude(void) const {return longitude;}
+protected:
+	//! returns a type enum for a given 2-letter code
+	static NomenclatureItemType getNomenclatureItemType(const QString abbrev);
+	//! Should be triggered once at start and then whenever program language setting changes.
+	static void createNameLists();
 
 private:
 	Vec3d XYZpc;                         // holds planetocentric position (from longitude/latitude)
@@ -163,7 +164,11 @@ private:
 	static Vec3f color;
 	static bool hideLocalNomenclature;
 
-	QString getNomenclatureTypeLatinString() const;
+	static QString getNomenclatureTypeLatinString(NomenclatureItemType nType);
+	static QString getNomenclatureTypeString(NomenclatureItemType nType);
+	static QString getNomenclatureTypeDescription(NomenclatureItemType nType, QString englishName);
+	static QMap<NomenclatureItemType, QString>niTypeStringMap;
+	static QMap<NomenclatureItemType, QString>niTypeDescriptionMap;
 
 	PlanetP planet;
 	int identificator;
