@@ -28,6 +28,7 @@
 #include "StelTextureTypes.hpp"
 #include "StelProjectorType.hpp"
 
+#include <QCache>
 #include <QString>
 
 // The callback type for the external position computation function
@@ -77,7 +78,7 @@ class Ring
 {
 public:
 	Ring(float radiusMin, float radiusMax,const QString &texname);
-	double getSize(void) const {return radiusMax;}
+	double getSize(void) const {return static_cast<double>(radiusMax);}
 	const float radiusMin;
 	const float radiusMax;
 	StelTextureSP tex;
@@ -189,6 +190,11 @@ public:
 	//! - elongation-dms (formatted string)
 	//! - elongation-deg (formatted string)
 	//! - type (object type description)
+	//! - velocity (formatted string)
+	//! - heliocentric-velocity (formatted string)
+	//! - scale
+	//! - eclipse-obscuration (for Sun only)
+	//! - eclipse-magnitude (for Sun only)
 	virtual QVariantMap getInfoMap(const StelCore *core) const;
 	virtual double getCloseViewFov(const StelCore* core) const;
 	virtual double getSatellitesFov(const StelCore* core) const;
@@ -229,14 +235,14 @@ public:
 	//! @return the polar radius of the planet in astronomical units.
 	double getPolarRadius(void) const {return equatorialRadius*oneMinusOblateness;}
 	//! Get duration of sidereal day
-	double getSiderealDay(void) const {return re.period;}
+	double getSiderealDay(void) const {return static_cast<double>(re.period);}
 	//! Get duration of sidereal year
 	// must be virtual for Comets.
 	virtual double getSiderealPeriod(void) const { return re.siderealPeriod; }
 	//! Get duration of mean solar day
 	double getMeanSolarDay(void) const;
 	//! Get albedo
-	double getAlbedo(void) const { return albedo; }
+	double getAlbedo(void) const { return static_cast<double>(albedo); }
 
 	const QString& getTextMapName() const {return texMapName;}
 	const QString getPlanetTypeString() const {return pTypeMap.value(pType);}
@@ -270,7 +276,7 @@ public:
 	void setRotationElements(float _period, float _offset, double _epoch,
 				 float _obliquity, float _ascendingNode,
 				 float _precessionRate, double _siderealPeriod);
-	double getRotAscendingNode(void) const {return re.ascendingNode;}
+	double getRotAscendingNode(void) const {return static_cast<double>(re.ascendingNode);}
 	// return angle between axis and normal of ecliptic plane (or, for a moon, equatorial/reference plane defined by parent).
 	// TODO: decide if this is always angle between axis and J2000 ecliptic, or should be axis//current ecliptic!
 	double getRotObliquity(double JDE) const;
@@ -278,7 +284,6 @@ public:
 
 
 	//! Compute the position in the parent Planet coordinate system
-	void computePositionWithoutOrbits(const double dateJDE);
 	virtual void computePosition(const double dateJDE);
 
 	//! Compute the transformation matrix from the local Planet coordinate to the parent Planet coordinate.
@@ -295,13 +300,16 @@ public:
 	float getPhase(const Vec3d& obsPos) const;
 
 	//! Get the Planet position in the parent Planet ecliptic coordinate in AU
-	Vec3d getEclipticPos() const;
+	Vec3d getEclipticPos(double dateJDE) const;
+	Vec3d getEclipticPos() const {return getEclipticPos(lastJDE);}
 
 	//! Return the heliocentric ecliptical position
 	Vec3d getHeliocentricEclipticPos() const {return getHeliocentricPos(eclipticPos);}
+	Vec3d getHeliocentricEclipticPos(double dateJDE) const;
 
 	//! Return the heliocentric transformation for local coordinate
 	Vec3d getHeliocentricPos(Vec3d) const;
+
 	void setHeliocentricEclipticPos(const Vec3d &pos);
 
 	//! Get the planet velocity around the parent planet in ecliptical coordinates in AU/d
@@ -316,8 +324,8 @@ public:
 
 	void setRings(Ring* r) {rings = r;}
 
-	void setSphereScale(float s) { if(s!=sphereScale) { sphereScale = s; if(objModel) objModel->needsRescale=true; } }
-	float getSphereScale() const { return sphereScale; }
+	void setSphereScale(double s) { if(!fuzzyEquals(s, sphereScale)) { sphereScale = s; if(objModel) objModel->needsRescale=true; } }
+	double getSphereScale() const { return sphereScale; }
 
 	const QSharedPointer<Planet> getParent(void) const {return parent;}
 
@@ -351,11 +359,8 @@ public:
 	// draw orbital path of Planet
 	void drawOrbit(const StelCore*);
 	Vec3d orbit[ORBIT_SEGMENTS+1];  // store heliocentric coordinates for drawing the orbit
-	Vec3d orbitP[ORBIT_SEGMENTS+1]; // store local coordinate for orbit
-	double lastOrbitJDE;
 	double deltaJDE;                // time difference between positional updates.
 	double deltaOrbitJDE;
-	bool orbitCached;               // whether orbit calculations are cached for drawing orbit yet
 	bool closeOrbit;                // whether to connect the beginning of the orbit line to
 					// the end: good for elliptical orbits, bad for parabolic
 					// and hyperbolic orbits
@@ -440,7 +445,6 @@ public:
 	static void setNeptuneOrbitColor(const Vec3f& oc) { orbitNeptuneColor = oc;}
 	static const Vec3f& getNeptuneOrbitColor() {return orbitNeptuneColor;}
 
-	static bool permanentDrawingOrbits;
 	static PlanetOrbitColorStyle orbitColorStyle;
 
 	//! Return the list of planets which project some shadow on this planet
@@ -481,6 +485,9 @@ protected:
 
 	void computeModelMatrix(Mat4d &result) const;
 
+	//! Update the orbit position values.
+	void computeOrbit();
+
 	Vec3f getCurrentOrbitColor() const;
 	
 	// Return the information string "ready to print" :)
@@ -525,7 +532,7 @@ protected:
 					 // NEW FEATURE in late 2017. For now, this may be 0/0/0 when we are not yet able to compute it.
 					 // to get velocity, preferrably read getEclipticVelocity() and getHeliocentricEclipticVelocity()
 					 // The "State Vector" [Heafner 1999] can be formed from (JDE, eclipticPos, eclipticVelocity)
-	Vec3d screenPos;                 // Used to store temporarily the 2D position on screen
+	Vec3f screenPos;                 // Used to store temporarily the 2D position on screen
 	Vec3f haloColor;                 // used for drawing the planet halo. Also, when non-spherical (OBJ) model without texture is used, its color is derived from haloColour*albedo.
 
 	float absoluteMagnitude;         // since 2017 this moved to the Planet class: V(1,0) from Explanatory Supplement or WGCCRE2009 paper for the planets, H in the H,G magnitude system for Minor planets, H10 for comets.
@@ -553,7 +560,7 @@ protected:
 	Ring* rings;                     // Planet rings
 	double distance;                 // Temporary variable used to store the distance to a given point
 	// it is used for sorting while drawing
-	float sphereScale;               // Artificial scaling for better viewing.
+	double sphereScale;              // Artificial scaling for better viewing.
 	double lastJDE;                  // caches JDE of last positional computation
 	// The callback for the calculation of the equatorial rect heliocentric position at time JDE.
 	posFuncType coordFunc;
@@ -580,6 +587,8 @@ protected:
 	static StelTextureSP hintCircleTex;
 	static QMap<PlanetType, QString> pTypeMap; // Maps fast type to english name.
 	static QMap<ApparentMagnitudeAlgorithm, QString> vMagAlgorithmMap;
+	//! If true, planet orbits will be drawn even if planet is off screen.
+	static bool permanentDrawingOrbits;
 
 	static bool flagCustomGrsSettings;	// Is enabled usage of custom settings for calculation of position of Great Red Spot?
 	static double customGrsJD;		// Initial JD for calculation of position of Great Red Spot
@@ -685,6 +694,9 @@ private:
 						  const QByteArray& fSrc,
 						  const QByteArray& prefix=QByteArray(),
 						  const QMap<QByteArray,int>& fixedAttributeLocations=QMap<QByteArray,int>());
+
+	// Cache of positions in the parent ecliptic coordinates in AU.
+	mutable QCache<double, Vec3d> positionsCache;
 };
 
 #endif // PLANET_HPP
