@@ -86,6 +86,11 @@ class SolarSystem : public StelObjectModule
 		   WRITE setFlagPlanetsOrbitsOnly
 		   NOTIFY flagPlanetsOrbitsOnlyChanged
 		   )
+	Q_PROPERTY(bool flagPermanentOrbits
+		   READ getFlagPermanentOrbits
+		   WRITE setFlagPermanentOrbits
+		   NOTIFY flagPermanentOrbitsChanged
+		   )
 	Q_PROPERTY(bool flagIsolatedOrbits
 		   READ getFlagIsolatedOrbits
 		   WRITE setFlagIsolatedOrbits
@@ -155,12 +160,37 @@ class SolarSystem : public StelObjectModule
 		   READ getFlagEphemerisDates
 		   WRITE setFlagEphemerisDates
 		   NOTIFY ephemerisDatesChanged
-		   )	
+		   )
 	Q_PROPERTY(bool ephemerisMagnitudesDisplayed
 		   READ getFlagEphemerisMagnitudes
 		   WRITE setFlagEphemerisMagnitudes
 		   NOTIFY ephemerisMagnitudesChanged
 		   )
+	Q_PROPERTY(bool ephemerisLineDisplayed
+		   READ getFlagEphemerisLine
+		   WRITE setFlagEphemerisLine
+		   NOTIFY ephemerisLineChanged
+		   )
+	Q_PROPERTY(bool ephemerisSkippedData
+		   READ getFlagEphemerisSkipData
+		   WRITE setFlagEphemerisSkipData
+		   NOTIFY ephemerisSkipDataChanged
+		   )
+	Q_PROPERTY(int ephemerisDataStep
+		   READ getEphemerisDataStep
+		   WRITE setEphemerisDataStep
+		   NOTIFY ephemerisDataStepChanged
+		   )
+	Q_PROPERTY(bool ephemerisSmartDates
+		   READ getFlagEphemerisSmartDates
+		   WRITE setFlagEphemerisSmartDates
+		   NOTIFY ephemerisSmartDatesChanged
+		   )
+	Q_PROPERTY(bool ephemerisScaleMarkersDisplayed
+		   READ getFlagEphemerisScaleMarkers
+		   WRITE setFlagEphemerisScaleMarkers
+		   NOTIFY ephemerisScaleMarkersChanged
+		   )
 
 	Q_PROPERTY(bool flagCustomGrsSettings
 		   READ getFlagCustomGrsSettings
@@ -293,6 +323,41 @@ class SolarSystem : public StelObjectModule
 		   READ getNeptuneOrbitColor
 		   WRITE setNeptuneOrbitColor
 		   NOTIFY neptuneOrbitColorChanged
+		   )	
+	Q_PROPERTY(Vec3f ephemerisGenericMarkerColor
+		   READ getEphemerisGenericMarkerColor
+		   WRITE setEphemerisGenericMarkerColor
+		   NOTIFY ephemerisGenericMarkerColorChanged
+		   )
+	Q_PROPERTY(Vec3f ephemerisSelectedMarkerColor
+		   READ getEphemerisSelectedMarkerColor
+		   WRITE setEphemerisSelectedMarkerColor
+		   NOTIFY ephemerisSelectedMarkerColorChanged
+		   )
+	Q_PROPERTY(Vec3f ephemerisMercuryMarkerColor
+		   READ getEphemerisMercuryMarkerColor
+		   WRITE setEphemerisMercuryMarkerColor
+		   NOTIFY ephemerisMercuryMarkerColorChanged
+		   )
+	Q_PROPERTY(Vec3f ephemerisVenusMarkerColor
+		   READ getEphemerisVenusMarkerColor
+		   WRITE setEphemerisVenusMarkerColor
+		   NOTIFY ephemerisVenusMarkerColorChanged
+		   )
+	Q_PROPERTY(Vec3f ephemerisMarsMarkerColor
+		   READ getEphemerisMarsMarkerColor
+		   WRITE setEphemerisMarsMarkerColor
+		   NOTIFY ephemerisMarsMarkerColorChanged
+		   )
+	Q_PROPERTY(Vec3f ephemerisJupiterMarkerColor
+		   READ getEphemerisJupiterMarkerColor
+		   WRITE setEphemerisJupiterMarkerColor
+		   NOTIFY ephemerisJupiterMarkerColorChanged
+		   )
+	Q_PROPERTY(Vec3f ephemerisSaturnMarkerColor
+		   READ getEphemerisSaturnMarkerColor
+		   WRITE setEphemerisSaturnMarkerColor
+		   NOTIFY ephemerisSaturnMarkerColorChanged
 		   )
 
 	// Color style
@@ -393,7 +458,7 @@ public slots:
 	//! Set the amount of planet labels. The real amount is also proportional with FOV.
 	//! The limit is set in function of the planets magnitude
 	//! @param a the amount between 0 and 10. 0 is no labels, 10 is maximum of labels
-	void setLabelsAmount(double a) {if(a!=labelsAmount) {labelsAmount=a; emit labelsAmountChanged(a);}}
+	void setLabelsAmount(double a) {if(!fuzzyEquals(a, labelsAmount)) {labelsAmount=a; emit labelsAmountChanged(a);}}
 	//! Get the amount of planet labels. The real amount is also proportional with FOV.
 	//! @return the amount between 0 and 10. 0 is no labels, 10 is maximum of labels
 	double getLabelsAmount(void) const {return labelsAmount;}
@@ -712,7 +777,7 @@ public slots:
 
 	//! Get type for Solar system bodies for scripts
 	//! @param planetName the case in-sensitive English planet name.
-	//! @return a type of planet (planet, moon, asteroid, comet, plutoid)
+	//! @return a type of planet (star, planet, moon, observer, artificial, asteroid, plutino, comet, dwarf planet, cubewano, scattered disc object, Oort cloud object, sednoid, interstellar object)
 	QString getPlanetType(QString planetName) const;
 
 	//! Get distance to Solar system bodies for scripts
@@ -821,6 +886,10 @@ public slots:
 	//! @param objType object type
 	QStringList getObjectsList(QString objType="all") const;
 
+	//! Set flag which enables display of orbits for planets even if they are off screen
+	void setFlagPermanentOrbits(bool b);
+	bool getFlagPermanentOrbits() const;
+
 signals:
 	void labelsDisplayedChanged(bool b);
 	void nomenclatureDisplayedChanged(bool b);
@@ -832,6 +901,7 @@ signals:
 	void flagTranslatedNamesChanged(bool b);
 	void flagPlanetsDisplayedChanged(bool b);
 	void flagPlanetsOrbitsOnlyChanged(bool b);
+	void flagPermanentOrbitsChanged(bool b);
 	void flagIsolatedOrbitsChanged(bool b);
 	void flagIsolatedTrailsChanged(bool b);
 	void numberIsolatedTrailsChanged(int n);
@@ -847,6 +917,11 @@ signals:
 	void ephemerisHorizontalCoordinatesChanged(bool b);
 	void ephemerisDatesChanged(bool b);
 	void ephemerisMagnitudesChanged(bool b);
+	void ephemerisLineChanged(bool b);
+	void ephemerisSkipDataChanged(bool b);
+	void ephemerisDataStepChanged(int s);
+	void ephemerisSmartDatesChanged(bool b);
+	void ephemerisScaleMarkersChanged(bool b);
 	void flagCustomGrsSettingsChanged(bool b);
 	void customGrsLongitudeChanged(int l);
 	void customGrsDriftChanged(double drift);
@@ -875,11 +950,19 @@ signals:
 	void saturnOrbitColorChanged(const Vec3f & color) const;
 	void uranusOrbitColorChanged(const Vec3f & color) const;
 	void neptuneOrbitColorChanged(const Vec3f & color) const;
+	void ephemerisGenericMarkerColorChanged(const Vec3f & color) const;
+	void ephemerisSelectedMarkerColorChanged(const Vec3f & color) const;
+	void ephemerisMercuryMarkerColorChanged(const Vec3f & color) const;
+	void ephemerisVenusMarkerColorChanged(const Vec3f & color) const;
+	void ephemerisMarsMarkerColorChanged(const Vec3f & color) const;
+	void ephemerisJupiterMarkerColorChanged(const Vec3f & color) const;
+	void ephemerisSaturnMarkerColorChanged(const Vec3f & color) const;
 
 	void orbitColorStyleChanged(QString style) const;
 	void apparentMagnitudeAlgorithmOnEarthChanged(QString algorithm) const;
 
 	void solarSystemDataReloaded();
+	void requestEphemerisVisualization();
 
 public:
 	///////////////////////////////////////////////////////////////////////////
@@ -951,6 +1034,9 @@ private slots:
 	void setFlagEphemerisMarkers(bool b);
 	bool getFlagEphemerisMarkers() const;
 
+	void setFlagEphemerisLine(bool b);
+	bool getFlagEphemerisLine() const;
+
 	void setFlagEphemerisHorizontalCoordinates(bool b);
 	bool getFlagEphemerisHorizontalCoordinates() const;
 
@@ -960,9 +1046,44 @@ private slots:
 	void setFlagEphemerisMagnitudes(bool b);
 	bool getFlagEphemerisMagnitudes() const;
 
+	void setFlagEphemerisSkipData(bool b);
+	bool getFlagEphemerisSkipData() const;
+
+	void setFlagEphemerisSmartDates(bool b);
+	bool getFlagEphemerisSmartDates() const;
+
+	void setFlagEphemerisScaleMarkers(bool b);
+	bool getFlagEphemerisScaleMarkers() const;
+
+	void setEphemerisDataStep(int step);
+	int getEphemerisDataStep() const;
+
+	void setEphemerisGenericMarkerColor(const Vec3f& c);
+	Vec3f getEphemerisGenericMarkerColor(void) const;
+
+	void setEphemerisSelectedMarkerColor(const Vec3f& c);
+	Vec3f getEphemerisSelectedMarkerColor(void) const;
+
+	void setEphemerisMercuryMarkerColor(const Vec3f& c);
+	Vec3f getEphemerisMercuryMarkerColor(void) const;
+
+	void setEphemerisVenusMarkerColor(const Vec3f& c);
+	Vec3f getEphemerisVenusMarkerColor(void) const;
+
+	void setEphemerisMarsMarkerColor(const Vec3f& c);
+	Vec3f getEphemerisMarsMarkerColor(void) const;
+
+	void setEphemerisJupiterMarkerColor(const Vec3f& c);
+	Vec3f getEphemerisJupiterMarkerColor(void) const;
+
+	void setEphemerisSaturnMarkerColor(const Vec3f& c);
+	Vec3f getEphemerisSaturnMarkerColor(void) const;
+
 	//! Called when a new Hips survey has been loaded by the hips mgr.
 	void onNewSurvey(HipsSurveyP survey);
 
+	void fillEphemerisDates();
+
 private:
 	//! Search for SolarSystem objects which are close to the position given
 	//! in earth equatorial position.
@@ -981,6 +1102,9 @@ private:
 	//! Draw a nice markers for ephemeris of objects.
 	void drawEphemerisMarkers(const StelCore* core);
 
+	//! Draw a line, who connected markers for ephemeris of objects.
+	void drawEphemerisLine(const StelCore* core);
+
 	//! Load planet data from the Solar System configuration files.
 	//! This function attempts to load every possible instance of the
 	//! Solar System configuration files in the file paths, falling back if a
@@ -992,14 +1116,12 @@ private:
 
 	void recreateTrails();
 
+	Vec3f getEphemerisMarkerColor(int index) const;
+
 	//! Calculate a color of Solar system bodies
 	//! @param bV value of B-V color index
 	unsigned char BvToColorIndex(float bV);
 
-	//! Set flag which enables display of permanent orbits for objects
-	// TODO: DOCUMENT what this really does, under which circumstances etc.
-	void setFlagPermanentOrbits(bool b);
-
 	//! Used to count how many planets actually need shadow information
 	int shadowPlanetCount;
 	PlanetP sun;
@@ -1042,7 +1164,7 @@ private:
 
 	//! The selection pointer texture.
 	StelTextureSP texPointer;
-	StelTextureSP texCircle;                    // The symbolic circle texture
+	StelTextureSP texEphemerisMarker;
 
 	bool flagShow;
 	bool flagPointer;                           // show red cross selection pointer?
@@ -1056,6 +1178,18 @@ private:
 	bool ephemerisDatesDisplayed;
 	bool ephemerisMagnitudesDisplayed;
 	bool ephemerisHorizontalCoordinates;
+	bool ephemerisLineDisplayed;
+	bool ephemerisSkipDataDisplayed;
+	int ephemerisDataStep;
+	bool ephemerisSmartDatesDisplayed;
+	bool ephemerisScaleMarkersDisplayed;
+	Vec3f ephemerisGenericMarkerColor;
+	Vec3f ephemerisSelectedMarkerColor;
+	Vec3f ephemerisMercuryMarkerColor;
+	Vec3f ephemerisVenusMarkerColor;
+	Vec3f ephemerisMarsMarkerColor;
+	Vec3f ephemerisJupiterMarkerColor;
+	Vec3f ephemerisSaturnMarkerColor;
 
 	class TrailGroup* allTrails;
 	QSettings* conf;
