@@ -17,8 +17,8 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
-#ifndef _SPORADICMETEORMGR_HPP_
-#define _SPORADICMETEORMGR_HPP_
+#ifndef SPORADICMETEORMGR_HPP
+#define SPORADICMETEORMGR_HPP
 
 #include "SporadicMeteor.hpp"
 #include "StelModule.hpp"
@@ -46,7 +46,7 @@ public:
 public slots:
 	// Methods callable from script and GUI
 	//! Get the current zenith hourly rate.
-	int getZHR() { return m_zhr; }
+	int getZHR() const { return m_zhr; }
 	//! Set the zenith hourly rate.
 	void setZHR(int zhr);
 
@@ -77,4 +77,4 @@ private:
 	bool m_flagForcedShow;
 };
 
-#endif // _SPORADICMETEORMGR_HPP_
+#endif // SPORADICMETEORMGR_HPP
