@@ -64,10 +64,9 @@ typedef struct
 
 typedef struct
 {
-	unsigned int sao;
-	unsigned int hd;
-	unsigned int hr;
-
+	int sao;
+	int hd;
+	int hr;
 } crossid;
 
 typedef QMap<StelObjectP, float> StelACStarData;
@@ -136,25 +135,26 @@ public:
 
 	//! Update any time-dependent features.
 	//! Includes fading in and out stars and labels when they are turned on and off.
-	virtual void update(double deltaTime) {labelsFader.update((int)(deltaTime*1000)); starsFader.update((int)(deltaTime*1000));}
+	virtual void update(double deltaTime) {labelsFader.update(static_cast<int>(deltaTime*1000)); starsFader.update(static_cast<int>(deltaTime*1000));}
 
 	//! Used to determine the order in which the various StelModules are drawn.
 	virtual double getCallOrder(StelModuleActionName actionName) const;
 
 	///////////////////////////////////////////////////////////////////////////
-	// Methods defined in StelObjectManager class
+	// Methods defined in StelObjectModule class
 	//! Return a list containing the stars located inside the limFov circle around position v
 	virtual QList<StelObjectP > searchAround(const Vec3d& v, double limitFov, const StelCore* core) const;
 
 	//! Return the matching Stars object's pointer if exists or Q_NULLPTR
-	//! @param nameI18n The case in-sensistive star common name or HP
+	//! @param nameI18n The case in-sensitive localized star common name or HIP/HP, SAO, HD, HR, GCVS or WDS number
 	//! catalog name (format can be HP1234 or HP 1234 or HIP 1234) or sci name
 	virtual StelObjectP searchByNameI18n(const QString& nameI18n) const;
 
 	//! Return the matching star if exists or Q_NULLPTR
-	//! @param name The case in-sensistive standard program planet name
+	//! @param name The case in-sensitive english star name
 	virtual StelObjectP searchByName(const QString& name) const;
 
+	//! Same as searchByName(id);
 	virtual StelObjectP searchByID(const QString &id) const;
 
 	//! Find and return the list of at most maxNbItem objects auto-completing the passed object English name.
@@ -333,7 +333,7 @@ public:
 	//! Hipparcos catalogue number.
 	//! @param hip The Hipparcos number of star
 	//! @return position angle in degrees
-	static int getWdsLastPositionAngle(int hip);
+	static float getWdsLastPositionAngle(int hip);
 
 	//! Get separation angle at date of last satisfactory observation of double star with a
 	//! Hipparcos catalogue number.
@@ -341,6 +341,11 @@ public:
 	//! @return separation in arcseconds
 	static float getWdsLastSeparation(int hip);
 
+	//! Get the parallax error for star with a Hipparcos catalogue number.
+	//! @param hip The Hipparcos number of star
+	//! @return the parallax error (mas)
+	static float getPlxError(int hip);
+
 	static QString convertToSpectralType(int index);
 	static QString convertToComponentIds(int index);
 
@@ -403,6 +408,10 @@ private:
 	//! @param the path to a file containing the cross-identification data.
 	void loadCrossIdentificationData(const QString& crossIdFile);
 
+	//! Loads parallax error data from a file.
+	//! @param the path to a file containing the parallax error data.
+	void loadPlxErr(const QString& plxErrFile);
+
 	//! Gets the maximum search level.
 	// TODO: add a non-lame description - what is the purpose of the max search level?
 	int getMaxSearchLevel() const;
@@ -475,6 +484,8 @@ private:
 	static QMap<int, int> hdStarsIndex;
 	static QMap<int, int> hrStarsIndex;
 
+	static QHash<int, float> hipParallaxErrors;
+
 	static QHash<int, QString> referenceMap;
 
 	QFont starFont;
