@@ -33,7 +33,7 @@
 
 template<typename T> inline bool isNan(T value)
 {
-	return value != value;
+	return value != value; // lgtm [cpp/comparison-of-identical-expressions]
 }
 
 template<typename T> inline bool isInf(T value)
@@ -73,13 +73,27 @@ QString StarWrapper1::getEnglishName(void) const
 	return StarWrapperBase::getEnglishName();
 }
 
+QString StarWrapper1::getID(void) const
+{
+	QString hip;
+	if (s->getHip())
+	{
+		if (s->hasComponentID())
+			hip = QString("HIP %1 %2").arg(s->getHip()).arg(StarMgr::convertToComponentIds(s->getComponentIds()));
+		else
+			hip = QString("HIP %1").arg(s->getHip());
+	}
+
+	return hip;
+}
+
 QString StarWrapper1::getInfoString(const StelCore *core, const InfoStringGroup& flags) const
 {
 	QString str;
 	QTextStream oss(&str);
 	double az_app, alt_app;
 	StelUtils::rectToSphe(&az_app,&alt_app,getAltAzPosApparent(core));
-	Q_UNUSED(az_app);
+	Q_UNUSED(az_app)
 
 	const QString varType = StarMgr::getGcvsVariabilityType(s->getHip());
 	const int wdsObs = StarMgr::getWdsLastObservation(s->getHip());
@@ -93,6 +107,7 @@ QString StarWrapper1::getInfoString(const StelCore *core, const InfoStringGroup&
 	const double vEpoch = StarMgr::getGcvsEpoch(s->getHip());
 	const double vPeriod = StarMgr::getGcvsPeriod(s->getHip());
 	const int vMm = StarMgr::getGcvsMM(s->getHip());
+	const float plxErr = StarMgr::getPlxError(s->getHip());
 	if (s->getHip())
 	{
 		if ((flags&Name) || (flags&CatalogNumber))
@@ -192,7 +207,6 @@ QString StarWrapper1::getInfoString(const StelCore *core, const InfoStringGroup&
 		}
 		else
 			oss << QString("%1: <b>%2</b>").arg(q_("Type"), startype) << "<br />";
-
 	}
 
 	oss << getMagnitudeInfoString(core, flags, alt_app, 2);
@@ -208,7 +222,7 @@ QString StarWrapper1::getInfoString(const StelCore *core, const InfoStringGroup&
 		{
 			float minimumM1 = minVMag;
 			float minimumM2 = min2VMag;
-			if (magFlag==1) // Amplitude
+			if (magFlag==1.f) // Amplitude
 			{
 				minimumM1 += maxVMag;
 				minimumM2 += maxVMag;
@@ -221,18 +235,23 @@ QString StarWrapper1::getInfoString(const StelCore *core, const InfoStringGroup&
 					minStr = QString("%1/%2").arg(QString::number(minimumM1, 'f', 2)).arg(QString::number(minimumM2, 'f', 2));
 
 				oss << QString("%1: <b>%2</b>%3<b>%4</b> (%5: %6)").arg(q_("Magnitude range"), QString::number(maxVMag, 'f', 2), QChar(0x00F7), minStr, q_("Photometric system"), photoVSys) << "<br />";
-
 			}
 		}
 	}
 
 	oss << getCommonInfoString(core, flags);
 
-	if ((flags&Distance) && s->getPlx ()&& !isNan(s->getPlx()) && !isInf(s->getPlx()))
+	if ((flags&Distance) && s->getPlx() && !isNan(s->getPlx()) && !isInf(s->getPlx()))
 	{
 		//TRANSLATORS: Unit of measure for distance - Light Years
 		QString ly = qc_("ly", "distance");
-		oss << QString("%1: %2 %3").arg(q_("Distance"), QString::number((AU/(SPEED_OF_LIGHT*86400*365.25))/(s->getPlx()*((0.00001/3600)*(M_PI/180))), 'f', 2), ly) << "<br />";
+		double k = AU/(SPEED_OF_LIGHT*86400*365.25);
+		double d = ((0.00001/3600.)*(M_PI/180));
+		double distance = k/(s->getPlx()*d);
+		if (plxErr>0.f && (0.01f*s->getPlx())>plxErr) // No distance when error of parallax is bigger than parallax!
+			oss << QString("%1: %2%3%4 %5").arg(q_("Distance"), QString::number(distance, 'f', 2), QChar(0x00B1), QString::number(qAbs(k/((100*plxErr + s->getPlx())*d) - distance), 'f', 2), ly) << "<br />";
+		else
+			oss << QString("%1: %2 %3").arg(q_("Distance"), QString::number(distance, 'f', 2), ly) << "<br />";
 	}
 
 	if (flags&Extra)
@@ -241,7 +260,14 @@ QString StarWrapper1::getInfoString(const StelCore *core, const InfoStringGroup&
 			oss << QString("%1: %2").arg(q_("Spectral Type"), StarMgr::convertToSpectralType(s->getSpInt())) << "<br />";
 
 		if (s->getPlx())
-			oss << QString("%1: %2\"").arg(q_("Parallax"), QString::number(0.00001*s->getPlx(), 'f', 5)) << "<br />";
+		{
+			QString plx = q_("Parallax");
+			if (plxErr>0.f)
+				oss <<  QString("%1: %2%3%4 ").arg(plx, QString::number(0.01*s->getPlx(), 'f', 3), QChar(0x00B1), QString::number(plxErr, 'f', 3));
+			else
+				oss << QString("%1: %2 ").arg(plx, QString::number(0.01*s->getPlx(), 'f', 3));
+			oss  << qc_("mas", "parallax") << "<br />";
+		}
 
 		if (vPeriod>0)
 			oss << QString("%1: %2 %3").arg(q_("Period")).arg(vPeriod).arg(qc_("days", "duration")) << "<br />";
@@ -280,9 +306,9 @@ QString StarWrapper1::getInfoString(const StelCore *core, const InfoStringGroup&
 			}
 		}
 
-		float dx = 0.1*s->getDx0();
-		float dy = 0.1*s->getDx1();
-		float pa = 90.f - std::atan2(dy, dx)*180.f/M_PI;
+		float dx = 0.1f*s->getDx0();
+		float dy = 0.1f*s->getDx1();
+		float pa = 90.f - std::atan2(dy, dx)*180.f/M_PIf;
 		if (pa<0)
 			pa += 360.f;
 
@@ -337,7 +363,7 @@ QVariantMap StarWrapper1::getInfoMap(const StelCore *core) const
 	if (s->getPlx ()&& !isNan(s->getPlx()) && !isInf(s->getPlx()))
 	{
 		map.insert("parallax", 0.00001*s->getPlx());
-		map.insert("absolute-mag", getVMagnitude(core)+5.*(1.+std::log10(0.00001*s->getPlx())));
+		map.insert("absolute-mag", getVMagnitude(core)+5.f*(1.f+std::log10(0.00001f*s->getPlx())));
 		map.insert("distance-ly", (AU/(SPEED_OF_LIGHT*86400*365.25)) / (s->getPlx()*((0.00001/3600)*(M_PI/180))));
 	}
 
