@@ -15,8 +15,8 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
 */
-#ifndef _PRECESSION_H_
-#define _PRECESSION_H_
+#ifndef PRECESSION_H
+#define PRECESSION_H
 
 #ifdef __cplusplus
 extern "C" {
