@@ -156,11 +156,11 @@ void ConfigurationDialog::createDialogContent()
 
 	// Kinetic scrolling
 	kineticScrollingList << ui->pluginsListWidget << ui->scriptListWidget;
-	StelGui* gui= dynamic_cast<StelGui*>(StelApp::getInstance().getGui());
-	if (gui)
+	StelGui* appGui= dynamic_cast<StelGui*>(StelApp::getInstance().getGui());
+	if (appGui)
 	{
-		enableKineticScrolling(gui->getFlagUseKineticScrolling());
-		connect(gui, SIGNAL(flagUseKineticScrollingChanged(bool)), this, SLOT(enableKineticScrolling(bool)));
+		enableKineticScrolling(appGui->getFlagUseKineticScrolling());
+		connect(appGui, SIGNAL(flagUseKineticScrollingChanged(bool)), this, SLOT(enableKineticScrolling(bool)));
 	}
 
 	connect(ui->closeStelWindow, SIGNAL(clicked()), this, SLOT(close()));
@@ -222,6 +222,7 @@ void ConfigurationDialog::createDialogContent()
 	connectBoolProperty(ui->checkBoxUMShortNotationSurfaceBrightness, "NebulaMgr.flagSurfaceBrightnessShortNotationUsage");
 	connectBoolProperty(ui->checkBoxUseFormattingOutput, "StelApp.flagUseFormattingOutput");
 	connectBoolProperty(ui->checkBoxUseCCSDesignations,  "StelApp.flagUseCCSDesignation");
+	connectBoolProperty(ui->overwriteTextColorCheckBox,  "StelApp.flagOverwriteInfoColor");
 
 	connect(ui->noSelectedInfoRadio, SIGNAL(released()), this, SLOT(setNoSelectedInfo()));
 	connect(ui->allSelectedInfoRadio, SIGNAL(released()), this, SLOT(setAllSelectedInfo()));
@@ -308,15 +309,15 @@ void ConfigurationDialog::createDialogContent()
 	connect(ui->diskViewportCheckbox, SIGNAL(toggled(bool)), this, SLOT(setDiskViewport(bool)));
 	connectBoolProperty(ui->autoZoomResetsDirectionCheckbox, "StelMovementMgr.flagAutoZoomOutResetsDirection");
 
-	connectBoolProperty(ui->showQuitButtonCheckBox,		"StelGui.flagShowQuitButton");
-	connectBoolProperty(ui->showFlipButtonsCheckbox,	"StelGui.flagShowFlipButtons");
-	connectBoolProperty(ui->showNebulaBgButtonCheckbox,	"StelGui.flagShowNebulaBackgroundButton");
+	connectBoolProperty(ui->showQuitButtonCheckBox,			"StelGui.flagShowQuitButton");
+	connectBoolProperty(ui->showFlipButtonsCheckbox,			"StelGui.flagShowFlipButtons");
+	connectBoolProperty(ui->showNebulaBgButtonCheckbox,		"StelGui.flagShowNebulaBackgroundButton");
 	connectBoolProperty(ui->showBookmarksButtonCheckBox,	"StelGui.flagShowBookmarksButton");
-	connectBoolProperty(ui->showICRSGridButtonCheckBox,	"StelGui.flagShowICRSGridButton");
+	connectBoolProperty(ui->showICRSGridButtonCheckBox,		"StelGui.flagShowICRSGridButton");
 	connectBoolProperty(ui->showGalacticGridButtonCheckBox,	"StelGui.flagShowGalacticGridButton");
 	connectBoolProperty(ui->showEclipticGridButtonCheckBox,	"StelGui.flagShowEclipticGridButton");
-	connectBoolProperty(ui->showHipsButtonCheckBox,		"StelGui.flagShowHiPSButton");
-	connectBoolProperty(ui->showDSSButtonCheckbox,		"StelGui.flagShowDSSButton");
+	connectBoolProperty(ui->showHipsButtonCheckBox,			"StelGui.flagShowHiPSButton");
+	connectBoolProperty(ui->showDSSButtonCheckbox,			"StelGui.flagShowDSSButton");
 	connectBoolProperty(ui->showGotoSelectedButtonCheckBox,	"StelGui.flagShowGotoSelectedObjectButton");
 	connectBoolProperty(ui->showNightmodeButtonCheckBox,	"StelGui.flagShowNightmodeButton");
 	connectBoolProperty(ui->showFullscreenButtonCheckBox,	"StelGui.flagShowFullscreenButton");
@@ -325,14 +326,14 @@ void ConfigurationDialog::createDialogContent()
 	connectBoolProperty(ui->showAsterismLinesButtonCheckBox,	"StelGui.flagShowAsterismLinesButton");
 	connectBoolProperty(ui->showAsterismLabelsButtonCheckBox,	"StelGui.flagShowAsterismLabelsButton");
 
-	connectBoolProperty(ui->decimalDegreeCheckBox, "StelApp.flagShowDecimalDegrees");
-	connectBoolProperty(ui->azimuthFromSouthcheckBox, "StelApp.flagUseAzimuthFromSouth");
+	connectBoolProperty(ui->decimalDegreeCheckBox,			"StelApp.flagShowDecimalDegrees");
+	connectBoolProperty(ui->azimuthFromSouthcheckBox,		"StelApp.flagUseAzimuthFromSouth");
 
-	connectBoolProperty(ui->mouseTimeoutCheckbox, "MainView.flagCursorTimeout");
-	connectDoubleProperty(ui->mouseTimeoutSpinBox, "MainView.cursorTimeout");
-	connectBoolProperty(ui->useButtonsBackgroundCheckBox, "StelGui.flagUseButtonsBackground");
-	connectBoolProperty(ui->indicationMountModeCheckBox, "StelMovementMgr.flagIndicationMountMode");
-	connectBoolProperty(ui->kineticScrollingCheckBox, "StelGui.flagUseKineticScrolling");
+	connectBoolProperty(ui->mouseTimeoutCheckbox,			"MainView.flagCursorTimeout");
+	connectDoubleProperty(ui->mouseTimeoutSpinBox,			"MainView.cursorTimeout");
+	connectBoolProperty(ui->useButtonsBackgroundCheckBox,	"StelGui.flagUseButtonsBackground");
+	connectBoolProperty(ui->indicationMountModeCheckBox,		"StelMovementMgr.flagIndicationMountMode");
+	connectBoolProperty(ui->kineticScrollingCheckBox,			"StelGui.flagUseKineticScrolling");
 
 	// Font selection. We use a hidden, but documented entry in config.ini to optionally show a font selection option.
 	connectIntProperty(ui->screenFontSizeSpinBox, "StelApp.screenFontSize");
@@ -513,7 +514,7 @@ void ConfigurationDialog::setSphericMirror(bool b)
 	}
 	else
 	{
-		core->setCurrentProjectionType((StelCore::ProjectionType)savedProjectionType);
+		core->setCurrentProjectionType(static_cast<StelCore::ProjectionType>(savedProjectionType));
 		StelApp::getInstance().setViewportEffect("none");
 	}
 }
@@ -657,7 +658,7 @@ void ConfigurationDialog::saveAllSettings()
 	// view dialog / sky tab settings
 	conf->setValue("stars/absolute_scale",				QString::number(propMgr->getStelPropertyValue("StelSkyDrawer.absoluteStarScale").toDouble(), 'f', 2));
 	conf->setValue("stars/relative_scale",				QString::number(propMgr->getStelPropertyValue("StelSkyDrawer.relativeStarScale").toDouble(), 'f', 2));
-	conf->setValue("stars/flag_star_twinkle",				QString::number(propMgr->getStelPropertyValue("StelSkyDrawer.flagStarTwinkle").toDouble(), 'f', 2));
+	conf->setValue("stars/flag_star_twinkle",				propMgr->getStelPropertyValue("StelSkyDrawer.flagStarTwinkle").toBool());
 	conf->setValue("stars/star_twinkle_amount",			QString::number(propMgr->getStelPropertyValue("StelSkyDrawer.twinkleAmount").toDouble(), 'f', 2));
 	conf->setValue("astro/flag_star_magnitude_limit",		propMgr->getStelPropertyValue("StelSkyDrawer.flagStarMagnitudeLimit").toBool());
 	conf->setValue("astro/star_magnitude_limit",			QString::number(propMgr->getStelPropertyValue("StelSkyDrawer.customStarMagLimit").toDouble(), 'f', 2));
@@ -669,6 +670,7 @@ void ConfigurationDialog::saveAllSettings()
 	conf->setValue("astro/flag_planets",					propMgr->getStelPropertyValue("SolarSystem.planetsDisplayed").toBool());
 	conf->setValue("astro/flag_planets_hints",			propMgr->getStelPropertyValue("SolarSystem.flagHints").toBool());
 	conf->setValue("astro/flag_planets_orbits",			propMgr->getStelPropertyValue("SolarSystem.flagOrbits").toBool());
+	conf->setValue("astro/flag_permanent_orbits",			propMgr->getStelPropertyValue("SolarSystem.flagPermanentOrbits").toBool());
 	conf->setValue("viewing/flag_isolated_trails",			propMgr->getStelPropertyValue("SolarSystem.flagIsolatedTrails").toBool());
 	conf->setValue("viewing/number_isolated_trails",		propMgr->getStelPropertyValue("SolarSystem.numberIsolatedTrails").toInt());
 	conf->setValue("viewing/flag_isolated_orbits",			propMgr->getStelPropertyValue("SolarSystem.flagIsolatedOrbits").toBool());
@@ -732,6 +734,8 @@ void ConfigurationDialog::saveAllSettings()
 	conf->setValue("viewing/flag_solstice_J2000_points",	propMgr->getStelPropertyValue("GridLinesMgr.solsticeJ2000PointsDisplayed").toBool());
 	conf->setValue("viewing/flag_solstice_points",			propMgr->getStelPropertyValue("GridLinesMgr.solsticePointsDisplayed").toBool());
 	conf->setValue("viewing/flag_antisolar_point",			propMgr->getStelPropertyValue("GridLinesMgr.antisolarPointDisplayed").toBool());
+	conf->setValue("viewing/flag_apex_points",			propMgr->getStelPropertyValue("GridLinesMgr.apexPointsDisplayed").toBool());
+	conf->setValue("viewing/line_thickness",				propMgr->getStelPropertyValue("GridLinesMgr.lineThickness").toInt());
 
 	conf->setValue("viewing/constellation_font_size",		propMgr->getStelPropertyValue("ConstellationMgr.fontSize").toInt());
 	conf->setValue("viewing/flag_constellation_drawing",	propMgr->getStelPropertyValue("ConstellationMgr.linesDisplayed").toBool());
@@ -773,56 +777,59 @@ void ConfigurationDialog::saveAllSettings()
 	conf->setValue("astro/flag_nebula_display_no_texture",	!propMgr->getStelPropertyValue("StelSkyLayerMgr.flagShow").toBool() );
 
 	conf->setValue("astro/flag_size_limits_usage",			propMgr->getStelPropertyValue("NebulaMgr.flagUseSizeLimits").toBool());
-	conf->setValue("astro/size_limit_min",				QString::number(propMgr->getStelPropertyValue("NebulaMgr.minSizeLimit").toFloat(), 'f', 0));
-	conf->setValue("astro/size_limit_max",				QString::number(propMgr->getStelPropertyValue("NebulaMgr.maxSizeLimit").toFloat(), 'f', 0));
+	conf->setValue("astro/size_limit_min",				QString::number(propMgr->getStelPropertyValue("NebulaMgr.minSizeLimit").toDouble(), 'f', 0));
+	conf->setValue("astro/size_limit_max",				QString::number(propMgr->getStelPropertyValue("NebulaMgr.maxSizeLimit").toDouble(), 'f', 0));
 
 	conf->setValue("projection/type",					core->getCurrentProjectionTypeKey());
 	conf->setValue("astro/flag_nutation",				core->getUseNutation());
-	conf->setValue("astro/flag_topocentric_coordinates",	core->getUseTopocentricCoordinates());
+	conf->setValue("astro/flag_topocentric_coordinates",		core->getUseTopocentricCoordinates());
 
 	// view dialog / DSO tag settings
 	const Nebula::CatalogGroup& cflags = nmgr->getCatalogFilters();
 
 	conf->beginGroup("dso_catalog_filters");
-	conf->setValue("flag_show_ngc",	(bool) (cflags & Nebula::CatNGC));
-	conf->setValue("flag_show_ic",		(bool) (cflags & Nebula::CatIC));
-	conf->setValue("flag_show_m",		(bool) (cflags & Nebula::CatM));
-	conf->setValue("flag_show_c",		(bool) (cflags & Nebula::CatC));
-	conf->setValue("flag_show_b",		(bool) (cflags & Nebula::CatB));
-	conf->setValue("flag_show_vdb",	(bool) (cflags & Nebula::CatVdB));
-	conf->setValue("flag_show_sh2",	(bool) (cflags & Nebula::CatSh2));
-	conf->setValue("flag_show_rcw",	(bool) (cflags & Nebula::CatRCW));
-	conf->setValue("flag_show_lbn",	(bool) (cflags & Nebula::CatLBN));
-	conf->setValue("flag_show_ldn",	(bool) (cflags & Nebula::CatLDN));
-	conf->setValue("flag_show_cr",		(bool) (cflags & Nebula::CatCr));
-	conf->setValue("flag_show_mel",	(bool) (cflags & Nebula::CatMel));
-	conf->setValue("flag_show_ced",	(bool) (cflags & Nebula::CatCed));
-	conf->setValue("flag_show_pgc",	(bool) (cflags & Nebula::CatPGC));
-	conf->setValue("flag_show_ugc",	(bool) (cflags & Nebula::CatUGC));
-	conf->setValue("flag_show_arp",	(bool) (cflags & Nebula::CatArp));
-	conf->setValue("flag_show_vv",	(bool) (cflags & Nebula::CatVV));
-	conf->setValue("flag_show_pk",	(bool) (cflags & Nebula::CatPK));
-	conf->setValue("flag_show_png",	(bool) (cflags & Nebula::CatPNG));
-	conf->setValue("flag_show_snrg",	(bool) (cflags & Nebula::CatSNRG));
-	conf->setValue("flag_show_aco",	(bool) (cflags & Nebula::CatACO));
-	conf->setValue("flag_show_hcg",	(bool) (cflags & Nebula::CatHCG));
-	conf->setValue("flag_show_abell",	(bool) (cflags & Nebula::CatAbell));
-	conf->setValue("flag_show_eso",	(bool) (cflags & Nebula::CatESO));
+	conf->setValue("flag_show_ngc",	static_cast<bool>(cflags & Nebula::CatNGC));
+	conf->setValue("flag_show_ic",		static_cast<bool>(cflags & Nebula::CatIC));
+	conf->setValue("flag_show_m",		static_cast<bool>(cflags & Nebula::CatM));
+	conf->setValue("flag_show_c",		static_cast<bool>(cflags & Nebula::CatC));
+	conf->setValue("flag_show_b",		static_cast<bool>(cflags & Nebula::CatB));
+	conf->setValue("flag_show_vdb",	static_cast<bool>(cflags & Nebula::CatVdB));
+	conf->setValue("flag_show_sh2",	static_cast<bool>(cflags & Nebula::CatSh2));
+	conf->setValue("flag_show_rcw",	static_cast<bool>(cflags & Nebula::CatRCW));
+	conf->setValue("flag_show_lbn",	static_cast<bool>(cflags & Nebula::CatLBN));
+	conf->setValue("flag_show_ldn",	static_cast<bool>(cflags & Nebula::CatLDN));
+	conf->setValue("flag_show_cr",		static_cast<bool>(cflags & Nebula::CatCr));
+	conf->setValue("flag_show_mel",	static_cast<bool>(cflags & Nebula::CatMel));
+	conf->setValue("flag_show_ced",	static_cast<bool>(cflags & Nebula::CatCed));
+	conf->setValue("flag_show_pgc",	static_cast<bool>(cflags & Nebula::CatPGC));
+	conf->setValue("flag_show_ugc",	static_cast<bool>(cflags & Nebula::CatUGC));
+	conf->setValue("flag_show_arp",	static_cast<bool>(cflags & Nebula::CatArp));
+	conf->setValue("flag_show_vv",	static_cast<bool>(cflags & Nebula::CatVV));
+	conf->setValue("flag_show_pk",	static_cast<bool>(cflags & Nebula::CatPK));
+	conf->setValue("flag_show_png",	static_cast<bool>(cflags & Nebula::CatPNG));
+	conf->setValue("flag_show_snrg",	static_cast<bool>(cflags & Nebula::CatSNRG));
+	conf->setValue("flag_show_aco",	static_cast<bool>(cflags & Nebula::CatACO));
+	conf->setValue("flag_show_hcg",	static_cast<bool>(cflags & Nebula::CatHCG));
+	conf->setValue("flag_show_abell",	static_cast<bool>(cflags & Nebula::CatAbell));
+	conf->setValue("flag_show_eso",	static_cast<bool>(cflags & Nebula::CatESO));
+	conf->setValue("flag_show_vdbh",	static_cast<bool>(cflags & Nebula::CatVdBH));
+	conf->setValue("flag_show_dwb",	static_cast<bool>(cflags & Nebula::CatDWB));
 	conf->endGroup();
 
 	const Nebula::TypeGroup& tflags = nmgr->getTypeFilters();
 	conf->beginGroup("dso_type_filters");
-	conf->setValue("flag_show_galaxies",			(bool) (tflags & Nebula::TypeGalaxies));
-	conf->setValue("flag_show_active_galaxies",		(bool) (tflags & Nebula::TypeActiveGalaxies));
-	conf->setValue("flag_show_interacting_galaxies",	(bool) (tflags & Nebula::TypeInteractingGalaxies));
-	conf->setValue("flag_show_clusters",			(bool) (tflags & Nebula::TypeStarClusters));
-	conf->setValue("flag_show_bright_nebulae",		(bool) (tflags & Nebula::TypeBrightNebulae));
-	conf->setValue("flag_show_dark_nebulae",		(bool) (tflags & Nebula::TypeDarkNebulae));
-	conf->setValue("flag_show_planetary_nebulae",	(bool) (tflags & Nebula::TypePlanetaryNebulae));
-	conf->setValue("flag_show_hydrogen_regions",	(bool) (tflags & Nebula::TypeHydrogenRegions));
-	conf->setValue("flag_show_supernova_remnants",	(bool) (tflags & Nebula::TypeSupernovaRemnants));
-	conf->setValue("flag_show_galaxy_clusters",		(bool) (tflags & Nebula::TypeGalaxyClusters));
-	conf->setValue("flag_show_other",				(bool) (tflags & Nebula::TypeOther));
+	conf->setValue("flag_show_galaxies",			static_cast<bool>(tflags & Nebula::TypeGalaxies));
+	conf->setValue("flag_show_active_galaxies",		static_cast<bool>(tflags & Nebula::TypeActiveGalaxies));
+	conf->setValue("flag_show_interacting_galaxies",	static_cast<bool>(tflags & Nebula::TypeInteractingGalaxies));
+	conf->setValue("flag_show_open_clusters",		static_cast<bool>(tflags & Nebula::TypeOpenStarClusters));
+	conf->setValue("flag_show_globular_clusters",		static_cast<bool>(tflags & Nebula::TypeGlobularStarClusters));
+	conf->setValue("flag_show_bright_nebulae",		static_cast<bool>(tflags & Nebula::TypeBrightNebulae));
+	conf->setValue("flag_show_dark_nebulae",		static_cast<bool>(tflags & Nebula::TypeDarkNebulae));
+	conf->setValue("flag_show_planetary_nebulae",	static_cast<bool>(tflags & Nebula::TypePlanetaryNebulae));
+	conf->setValue("flag_show_hydrogen_regions",	static_cast<bool>(tflags & Nebula::TypeHydrogenRegions));
+	conf->setValue("flag_show_supernova_remnants",	static_cast<bool>(tflags & Nebula::TypeSupernovaRemnants));
+	conf->setValue("flag_show_galaxy_clusters",		static_cast<bool>(tflags & Nebula::TypeGalaxyClusters));
+	conf->setValue("flag_show_other",				static_cast<bool>(tflags & Nebula::TypeOther));
 	conf->endGroup();
 
 	// view dialog / landscape tab settings
@@ -843,7 +850,7 @@ void ConfigurationDialog::saveAllSettings()
 	conf->setValue("landscape/temperature_C",				propMgr->getStelPropertyValue("StelSkyDrawer.atmosphereTemperature").toFloat());
 
 	// view dialog / starlore tab
-	QObject* scmgr = (QObject*)&StelApp::getInstance().getSkyCultureMgr();
+	QObject* scmgr = reinterpret_cast<QObject*>(&StelApp::getInstance().getSkyCultureMgr());
 	scmgr->setProperty("defaultSkyCultureID", scmgr->property("currentSkyCultureID"));
 
 	// Save default location
@@ -868,45 +875,26 @@ void ConfigurationDialog::saveAllSettings()
 		conf->setValue("gui/selected_object_info", "custom");
 		
 		conf->beginGroup("custom_selected_info");
-		conf->setValue("flag_show_name", (bool) (flags & StelObject::Name));
-		conf->setValue("flag_show_catalognumber",
-		               (bool) (flags & StelObject::CatalogNumber));
-		conf->setValue("flag_show_magnitude",
-		               (bool) (flags & StelObject::Magnitude));
-		conf->setValue("flag_show_absolutemagnitude",
-			       (bool) (flags & StelObject::AbsoluteMagnitude));
-		conf->setValue("flag_show_radecj2000",
-		               (bool) (flags & StelObject::RaDecJ2000));
-		conf->setValue("flag_show_radecofdate",
-			       (bool) (flags & StelObject::RaDecOfDate));
-		conf->setValue("flag_show_hourangle",
-		               (bool) (flags & StelObject::HourAngle));
-		conf->setValue("flag_show_altaz",
-		               (bool) (flags &  StelObject::AltAzi));
-		conf->setValue("flag_show_distance",
-		               (bool) (flags & StelObject::Distance));
-		conf->setValue("flag_show_velocity",
-			       (bool) (flags & StelObject::Velocity));
-		conf->setValue("flag_show_size",
-		               (bool) (flags & StelObject::Size));
-		conf->setValue("flag_show_extra",
-			       (bool) (flags & StelObject::Extra));
-		conf->setValue("flag_show_galcoord",
-			       (bool) (flags & StelObject::GalacticCoord));
-		conf->setValue("flag_show_supergalcoord",
-			       (bool) (flags & StelObject::SupergalacticCoord));
-		conf->setValue("flag_show_type",
-			       (bool) (flags & StelObject::ObjectType));
-		conf->setValue("flag_show_eclcoordofdate",
-			       (bool) (flags & StelObject::EclipticCoordOfDate));
-		conf->setValue("flag_show_eclcoordj2000",
-			       (bool) (flags & StelObject::EclipticCoordJ2000));
-		conf->setValue("flag_show_constellation",
-			       (bool) (flags & StelObject::IAUConstellation));
-		conf->setValue("flag_show_sidereal_time",
-			       (bool) (flags & StelObject::SiderealTime));
-		conf->setValue("flag_show_rts_time",
-			       (bool) (flags & StelObject::RTSTime));
+		conf->setValue("flag_show_name",		static_cast<bool>(flags & StelObject::Name));
+		conf->setValue("flag_show_catalognumber",	static_cast<bool>(flags & StelObject::CatalogNumber));
+		conf->setValue("flag_show_magnitude",		static_cast<bool>(flags & StelObject::Magnitude));
+		conf->setValue("flag_show_absolutemagnitude",	static_cast<bool>(flags & StelObject::AbsoluteMagnitude));
+		conf->setValue("flag_show_radecj2000",		static_cast<bool>(flags & StelObject::RaDecJ2000));
+		conf->setValue("flag_show_radecofdate",		static_cast<bool>(flags & StelObject::RaDecOfDate));
+		conf->setValue("flag_show_hourangle",		static_cast<bool>(flags & StelObject::HourAngle));
+		conf->setValue("flag_show_altaz",		static_cast<bool>(flags &  StelObject::AltAzi));
+		conf->setValue("flag_show_distance",		static_cast<bool>(flags & StelObject::Distance));
+		conf->setValue("flag_show_velocity",		static_cast<bool>(flags & StelObject::Velocity));
+		conf->setValue("flag_show_size",		static_cast<bool>(flags & StelObject::Size));
+		conf->setValue("flag_show_extra",		static_cast<bool>(flags & StelObject::Extra));
+		conf->setValue("flag_show_galcoord",		static_cast<bool>(flags & StelObject::GalacticCoord));
+		conf->setValue("flag_show_supergalcoord",	static_cast<bool>(flags & StelObject::SupergalacticCoord));
+		conf->setValue("flag_show_type",		static_cast<bool>(flags & StelObject::ObjectType));
+		conf->setValue("flag_show_eclcoordofdate",	static_cast<bool>(flags & StelObject::EclipticCoordOfDate));
+		conf->setValue("flag_show_eclcoordj2000",	static_cast<bool>(flags & StelObject::EclipticCoordJ2000));
+		conf->setValue("flag_show_constellation",	static_cast<bool>(flags & StelObject::IAUConstellation));
+		conf->setValue("flag_show_sidereal_time",	static_cast<bool>(flags & StelObject::SiderealTime));
+		conf->setValue("flag_show_rts_time",		static_cast<bool>(flags & StelObject::RTSTime));
 		conf->endGroup();
 	}
 
@@ -914,7 +902,7 @@ void ConfigurationDialog::saveAllSettings()
 	conf->setValue("gui/auto_hide_horizontal_toolbar",		propMgr->getStelPropertyValue("StelGui.autoHideHorizontalButtonBar").toBool());
 	conf->setValue("gui/auto_hide_vertical_toolbar",		propMgr->getStelPropertyValue("StelGui.autoHideVerticalButtonBar").toBool());
 	conf->setValue("gui/flag_show_quit_button",			propMgr->getStelPropertyValue("StelGui.flagShowQuitButton").toBool());
-	conf->setValue("gui/flag_show_nebulae_background_button",	propMgr->getStelPropertyValue("StelGui.flagShowNebulaBackgroundButton").toBool());
+	conf->setValue("gui/flag_show_nebulae_background_button",propMgr->getStelPropertyValue("StelGui.flagShowNebulaBackgroundButton").toBool());
 	conf->setValue("gui/flag_show_dss_button",			propMgr->getStelPropertyValue("StelGui.flagShowDSSButton").toBool());
 	conf->setValue("gui/flag_show_hips_button",			propMgr->getStelPropertyValue("StelGui.flagShowHiPSButton").toBool());
 	conf->setValue("gui/flag_show_goto_selected_button",	propMgr->getStelPropertyValue("StelGui.flagShowGotoSelectedObjectButton").toBool());
@@ -931,6 +919,7 @@ void ConfigurationDialog::saveAllSettings()
 	conf->setValue("gui/flag_use_azimuth_from_south",		propMgr->getStelPropertyValue("StelApp.flagUseAzimuthFromSouth").toBool());
 	conf->setValue("gui/flag_use_formatting_output",		propMgr->getStelPropertyValue("StelApp.flagUseFormattingOutput").toBool());
 	conf->setValue("gui/flag_use_ccs_designations",		propMgr->getStelPropertyValue("StelApp.flagUseCCSDesignation").toBool());
+	conf->setValue("gui/flag_overwrite_info_color",			propMgr->getStelPropertyValue("StelApp.flagOverwriteInfoColor").toBool());
 	conf->setValue("gui/flag_time_jd",					gui->getButtonBar()->getFlagTimeJd());
 	conf->setValue("gui/flag_show_buttons_background",	propMgr->getStelPropertyValue("StelGui.flagUseButtonsBackground").toBool());
 	conf->setValue("gui/flag_indication_mount_mode",		mvmgr->getFlagIndicationMountMode());
@@ -966,7 +955,7 @@ void ConfigurationDialog::saveAllSettings()
 	conf->setValue("gui/mouse_cursor_timeout",			propMgr->getStelPropertyValue("MainView.cursorTimeout").toFloat());
 	conf->setValue("gui/base_font_name",				QGuiApplication::font().family());
 	conf->setValue("gui/screen_font_size",				propMgr->getStelPropertyValue("StelApp.screenFontSize").toInt());
-	conf->setValue("gui/gui_font_size",				propMgr->getStelPropertyValue("StelApp.guiFontSize").toInt());
+	conf->setValue("gui/gui_font_size",					propMgr->getStelPropertyValue("StelApp.guiFontSize").toInt());
 
 
 	conf->setValue("main/screenshot_dir",				StelFileMgr::getScreenshotDir());
@@ -994,6 +983,8 @@ void ConfigurationDialog::saveAllSettings()
 	conf->setValue("main/restore_defaults", false);
 
 	updateConfigLabels();
+
+	emit core->configurationDataSaved();
 }
 
 void ConfigurationDialog::updateConfigLabels()
@@ -1065,7 +1056,13 @@ void ConfigurationDialog::pluginsSelectionChanged(QListWidgetItem* item, QListWi
 			QString d = desc.info.description;
 			d.replace("\n", "<br />");
 			html += "<p>" + q_(d) + "</p>";
-			html += "<p><strong>" + q_("Authors") + "</strong>: " + desc.info.authors;
+			html += "<p>";
+			QString thanks = desc.info.acknowledgements;
+			if (!thanks.isEmpty())
+			{
+				html += "<strong>" + q_("Acknowledgements") + "</strong>: " + q_(thanks) + "<br/>";
+			}
+			html += "<strong>" + q_("Authors") + "</strong>: " + desc.info.authors;
 			html += "<br /><strong>" + q_("Contact") + "</strong>: " + desc.info.contact;
 			if (!desc.info.version.isEmpty())
 				html += "<br /><strong>" + q_("Version") + "</strong>: " + desc.info.version;
@@ -1278,7 +1275,7 @@ void ConfigurationDialog::updateStarCatalogControlsText()
 			const QVariantList& magRange = nextStarCatalogToDownload.value("magRange").toList();
 			ui->downloadLabel->setText(q_("Download size: %1MB\nStar count: %2 Million\nMagnitude range: %3 - %4")
 				.arg(nextStarCatalogToDownload.value("sizeMb").toString())
-				.arg(QString::number(nextStarCatalogToDownload.value("count").toFloat(), 'f', 1))
+				.arg(QString::number(nextStarCatalogToDownload.value("count").toDouble(), 'f', 1))
 				.arg(magRange.first().toString())
 				.arg(magRange.last().toString()));
 		}
@@ -1302,8 +1299,8 @@ void ConfigurationDialog::newStarCatalogData()
 	// Ignore data from redirection.  (Not needed after Qt 5.6)
 	if (!starCatalogDownloadReply->attribute(QNetworkRequest::RedirectionTargetAttribute).isNull())
 		return;
-	int size = starCatalogDownloadReply->bytesAvailable();
-	progressBar->setValue((float)progressBar->getValue()+(float)size/1024);
+	qint64 size = starCatalogDownloadReply->bytesAvailable();
+	progressBar->setValue(progressBar->getValue()+static_cast<int>(size/1024));
 	currentDownloadFile->write(starCatalogDownloadReply->read(size));
 }
 
@@ -1346,7 +1343,7 @@ void ConfigurationDialog::downloadStars()
 
 	progressBar = StelApp::getInstance().addProgressBar();
 	progressBar->setValue(0);
-	progressBar->setRange(0, nextStarCatalogToDownload.value("sizeMb").toDouble()*1024);
+	progressBar->setRange(0, static_cast<int>(nextStarCatalogToDownload.value("sizeMb").toDouble()*1024));
 	progressBar->setFormat(QString("%1: %p%").arg(nextStarCatalogToDownload.value("id").toString()));
 
 	qDebug() << "Downloading file" << nextStarCatalogToDownload.value("url").toString();
@@ -1531,7 +1528,7 @@ void ConfigurationDialog::updateTabBarListWidgetWidth()
 	int width = 0;
 	for (int row = 0; row < model->rowCount(); row++)
 	{
-		int textWidth = fontMetrics.width(ui->stackListWidget->item(row)->text());
+		int textWidth = fontMetrics.boundingRect(ui->stackListWidget->item(row)->text()).width();
 		width += iconSize > textWidth ? iconSize : textWidth; // use the wider one
 		width += 24; // margin - 12px left and 12px right
 	}
@@ -1642,13 +1639,14 @@ void ConfigurationDialog::populateDateFormatsList()
 	int index = dfmts->currentIndex();
 	QVariant selectedDateFormat = dfmts->itemData(index);
 	dfmts->clear();
-	//For each format, display the localized name and store the key as user
-	//data. Unfortunately, there's no other way to do this than with a cycle.
+	//For each format, display the localized name and store the key as user data.
 	dfmts->addItem(q_("System default"), "system_default");
 	dfmts->addItem(q_("yyyy-mm-dd (ISO 8601)"), "yyyymmdd");
 	dfmts->addItem(q_("dd-mm-yyyy"), "ddmmyyyy");
 	dfmts->addItem(q_("mm-dd-yyyy"), "mmddyyyy");
-
+	dfmts->addItem(q_("ww, yyyy-mm-dd"), "wwyyyymmdd");
+	dfmts->addItem(q_("ww, dd-mm-yyyy"), "wwddmmyyyy");
+	dfmts->addItem(q_("ww, mm-dd-yyyy"), "wwmmddyyyy");
 	//Restore the selection
 	index = dfmts->findData(selectedDateFormat, Qt::UserRole, Qt::MatchCaseSensitive);
 	dfmts->setCurrentIndex(index);
@@ -1749,7 +1747,7 @@ void ConfigurationDialog::handleFontBoxWritingSystem(int index)
 {
 	Q_UNUSED(index)
 	QComboBox *sender=dynamic_cast<QComboBox *>(QObject::sender());
-	ui->fontComboBox->setWritingSystem((QFontDatabase::WritingSystem) sender->currentData().toInt());
+	ui->fontComboBox->setWritingSystem(static_cast<QFontDatabase::WritingSystem>(sender->currentData().toInt()));
 }
 
 void ConfigurationDialog::populateScreenshotFileformatsCombo()
