@@ -42,6 +42,7 @@ public slots:
 	void retranslate();
 	//! In addition to StelDialog's inherited solution, puts the arrow on the right spot in the map.
 	virtual void handleDialogSizeChanged(QSizeF size);
+
 protected:
 	//! Initialize the dialog widgets and connect the signals/slots
 	virtual void createDialogContent();
@@ -106,17 +107,17 @@ private slots:
 	
 	//! Called when the map is clicked.
 	//! create new list for places nearby and feed into location list box.
-	void setPositionFromMap(double longitude, double latitude);
+	void setLocationFromMap(double longitude, double latitude);
 	
 	//! Called when the user activates an item from the locations list.
-	void setPositionFromList(const QModelIndex& index);
+	void setLocationFromList(const QModelIndex& index);
 	
 	//! Called when the planet is manually changed.
 	void moveToAnotherPlanet(const QString& text);
 
 	//! Called when latitude/longitude/altitude is modified
 	//! The int argument is required by the Altitude spinbox signal connection, but unused.
-	void setPositionFromCoords(int i=0);
+	void setLocationFromCoords(int i=0);
 
 	//! Called when the user clicks on the add to list button
 	void addCurrentLocationToList();
@@ -128,7 +129,7 @@ private slots:
 	void filterSitesByCountry();
 
 	//! reset city list to complete list (may have been reduced to picked list)
-	void resetCompleteList();
+	void resetLocationList();
 
 	//! called when the user wants get location from network.
 	//! This is actually a toggle setting which will influence Stellarium's behaviour
@@ -143,7 +144,6 @@ private slots:
 	//! On Windows (and Mac?), or where GPSD is not available, we must process the NMEA-183 messages and take care of the Serial port.
 	//! The GPS connection stays open (blocking serial GPS device for other programs if not on GPSD) even with the dialog closed, until disabled again.
 	//! @param enable true to start a repeating series of GPS queries, false to stop it.
-	//void gpsQueryLocation(); // ONCE: This was the original implementation.
 	void gpsEnableQueryLocation(bool enable); // Can be toggled by QToolButton
 	//! handle a few GUI elements when GPS query returns. Should be connected to LocationMgr's signal gpsResult().
 	//! @param success true if location was found
@@ -160,8 +160,8 @@ private slots:
 	void updateTimeZoneControls(bool useCustomTimeZone);
 
 private:
-	QString lastPlanet;
-	QString customTimeZone;
+	QString lastPlanet; // for caching when switching map
+	QString customTimeZone;  // for caching when switching around timezones.
 	QStringListModel* allModel;
 	QStringListModel* pickedModel;
 	QSortFilterProxyModel *proxyModel;
@@ -173,7 +173,6 @@ private:
 
 	//! Updates the check state and the enabled/disabled status.
 	void updateDefaultLocationControls(bool currentIsDefault);
-
 };
 
 #endif // _LOCATIONDIALOG_HPP
