@@ -61,6 +61,20 @@ private:
 	QComboBox* combo;
 };
 
+//! A StelPropertyProxy that works with QComboBox widgets.
+//! When the property changes, the widget's value is updated, while preventing widget signals to be sent.
+//! This avoids emitting the valueChanged() signal, which would unnecessarily set the property value again, which may lead to problems.
+class QComboBoxStelStringPropertyConnectionHelper : public StelPropertyProxy
+{
+	Q_OBJECT
+public:
+	QComboBoxStelStringPropertyConnectionHelper(StelProperty* prop,QComboBox* combo);
+
+protected slots:
+	virtual void onPropertyChanged(const QVariant& value) Q_DECL_OVERRIDE;
+private:
+	QComboBox* combo;
+};
 
 //! A StelPropertyProxy that works with QLineEdit widgets.
 //! When the property changes, the widget's value is updated, while preventing widget signals to be sent.
