@@ -244,7 +244,7 @@ void StelGui::init(QGraphicsWidget *atopLevelGraphicsWidget)
 	actionsMgr->addAction("actionShow_Shortcuts_Window_Global", windowsGroup, N_("Shortcuts window"), shortcutsDialog, "visible", "F7", "", true);
 	actionsMgr->addAction("actionShow_AstroCalc_Window_Global", windowsGroup, N_("Astronomical calculations window"), astroCalcDialog, "visible", "F10", "", true);
 	actionsMgr->addAction("actionShow_Bookmarks_Window_Global", windowsGroup, N_("Bookmarks"), bookmarksDialog, "visible", "Alt+B", "", true);
-	actionsMgr->addAction("actionSave_Copy_Object_Information_Global", miscGroup, N_("Copy selected object information to clipboard"), this, "copySelectedObjectInfo()", "Ctrl+C", "", true);	
+	actionsMgr->addAction("actionSave_Copy_Object_Information_Global", miscGroup, N_("Copy selected object information to clipboard"), this, "copySelectedObjectInfo()", "Ctrl+Shift+C", "", true);
 
 	QSettings* conf = StelApp::getInstance().getSettings();
 	Q_ASSERT(conf);
@@ -455,7 +455,7 @@ void StelGui::init(QGraphicsWidget *atopLevelGraphicsWidget)
 	p.setColor(QPalette::Active, QPalette::Button, QColor(255,255,255));
 	QGuiApplication::setPalette(p);
 	
-	// FIXME: Workaround for set UI language when app is started --AW
+	// Set UI language when app is started
 	updateI18n();
 
 	StelApp *app = &StelApp::getInstance();
@@ -550,7 +550,7 @@ void StelGui::update()
         if (buttonTimeForward->isChecked())
 			buttonTimeForward->setChecked(false);
 	}
-	if (core->getTimeRate() == 0) {
+	if (core->getTimeRate() == 0.) {
 		if (buttonTimeRealTimeSpeed->isChecked() != StelButton::ButtonStateNoChange)
 			buttonTimeRealTimeSpeed->setChecked(StelButton::ButtonStateNoChange);
 	} else if (core->getRealTimeSpeed()) {
@@ -1068,7 +1068,7 @@ void StelGui::setFlagShowNightmodeButton(bool b)
 				QPixmap pxmapGlow32x32(":/graphicGui/glow32x32.png");
 				QPixmap pxmapOn(":/graphicGui/btNightView-on.png");
 				QPixmap pxmapOff(":/graphicGui/btNightView-off.png");
-				btShowHiPS = new StelButton(Q_NULLPTR, pxmapOn, pxmapOff, pxmapGlow32x32, "actionShow_Night_Mode");
+				buttonNightmode = new StelButton(Q_NULLPTR, pxmapOn, pxmapOff, pxmapGlow32x32, "actionShow_Night_Mode");
 			}
 			getButtonBar()->addButton(buttonNightmode, "060-othersGroup");
 		} else {
@@ -1093,7 +1093,7 @@ void StelGui::setFlagShowFullscreenButton(bool b)
 				QPixmap pxmapGlow32x32(":/graphicGui/glow32x32.png");
 				QPixmap pxmapOn(":/graphicGui/btFullScreen-on.png");
 				QPixmap pxmapOff(":/graphicGui/btFullScreen-off.png");
-				btShowHiPS = new StelButton(Q_NULLPTR, pxmapOn, pxmapOff, pxmapGlow32x32, "actionSet_Full_Screen_Global");
+				buttonFullscreen = new StelButton(Q_NULLPTR, pxmapOn, pxmapOff, pxmapGlow32x32, "actionSet_Full_Screen_Global");
 			}
 			getButtonBar()->addButton(buttonFullscreen, "060-othersGroup");
 		} else {
@@ -1117,7 +1117,7 @@ void StelGui::setFlagShowQuitButton(bool b)
 				// Create the fullscreen button
 				QPixmap pxmapGlow32x32(":/graphicGui/glow32x32.png");
 				QPixmap pxmapOn(":/graphicGui/btQuit.png");
-				btShowHiPS = new StelButton(Q_NULLPTR, pxmapOn, pxmapOn, pxmapGlow32x32, "actionQuit_Global");
+				buttonQuit = new StelButton(Q_NULLPTR, pxmapOn, pxmapOn, pxmapGlow32x32, "actionQuit_Global");
 			}
 			getButtonBar()->addButton(buttonQuit, "080-quitGroup");
 		} else {
