@@ -19,6 +19,7 @@
  */
 
 #include "StelMainView.hpp"
+#include "StelSplashScreen.hpp"
 #include "StelTranslator.hpp"
 #include "StelLogger.hpp"
 #include "StelFileMgr.hpp"
@@ -45,7 +46,6 @@
 #include <QFontDatabase>
 #include <QGuiApplication>
 #include <QSettings>
-#include <QSplashScreen>
 #include <QString>
 #include <QStringList>
 #include <QTextStream>
@@ -56,10 +56,29 @@
 #include <clocale>
 
 #ifdef Q_OS_WIN
-	#include <windows.h>
+	#include <Windows.h>
 	//we use WIN32_LEAN_AND_MEAN so this needs to be included
 	//to use timeBeginPeriod/timeEndPeriod
 	#include <mmsystem.h>
+
+	// Default to High Performance Mode on machines with hybrid graphics
+	// Details: https://stackoverflow.com/questions/44174859/how-to-give-an-option-to-select-graphics-adapter-in-a-directx-11-application
+	extern "C"
+	{
+	#ifdef _MSC_VER
+		__declspec(dllexport) DWORD NvOptimusEnablement = 0x00000001;
+		__declspec(dllexport) int AmdPowerXpressRequestHighPerformance = 0x00000001;
+	#else
+		__attribute__((dllexport)) DWORD NvOptimusEnablement = 0x00000001;
+		__attribute__((dllexport)) int AmdPowerXpressRequestHighPerformance = 0x00000001;
+	#endif
+	}
+#else
+	extern "C"
+	{
+		int NvOptimusEnablement = 1;
+		int AmdPowerXpressRequestHighPerformance = 1;
+	}
 #endif //Q_OS_WIN
 
 //! @class CustomQTranslator
@@ -75,7 +94,7 @@ public:
 	//! @param context Qt context string - IGNORED.
 	//! @param sourceText the source message.
 	//! @param comment optional parameter
-	virtual QString translate(const char *context, const char *sourceText, const char *disambiguation = 0, int n = -1) const
+	virtual QString translate(const char *context, const char *sourceText, const char *disambiguation = Q_NULLPTR, int n = -1) const
 	{
 		Q_UNUSED(context);
 		Q_UNUSED(n);
@@ -109,28 +128,6 @@ void clearCache()
 	cacheMgr->clear(); // Removes all items from the cache.
 }
 
-class SplashScreen : public QSplashScreen
-{
-    bool painted=false;
-    void paintEvent(QPaintEvent* e) override
-    {
-        QSplashScreen::paintEvent(e);
-        painted=true;
-    }
-public:
-    SplashScreen(QPixmap const& pixmap)
-        : QSplashScreen(pixmap)
-    {}
-    void ensureFirstPaint() const
-    {
-        while(!painted)
-        {
-            QThread::usleep(1000);
-            qApp->processEvents();
-        }
-    }
-};
-
 // Main stellarium procedure
 int main(int argc, char **argv)
 {
@@ -158,11 +155,17 @@ int main(int argc, char **argv)
 	QCoreApplication::setOrganizationDomain("stellarium.org");
 	QCoreApplication::setOrganizationName("stellarium");
 
+	// Support high DPI pixmaps and fonts
+	QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+	#if (QT_VERSION>=QT_VERSION_CHECK(5, 6, 0))
+	QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
+	#endif
+
 	#if defined(Q_OS_MAC)
 	QFileInfo appInfo(QString::fromUtf8(argv[0]));
 	QDir appDir(appInfo.absolutePath());
 	appDir.cdUp();
-	QCoreApplication::addLibraryPath(appDir.absoluteFilePath("plugins"));
+	QCoreApplication::addLibraryPath(appDir.absoluteFilePath("PlugIns"));
 	#elif defined(Q_OS_WIN)
 	QFileInfo appInfo(QString::fromUtf8(argv[0]));
 	QCoreApplication::addLibraryPath(appInfo.absolutePath());
@@ -190,11 +193,7 @@ int main(int argc, char **argv)
 	// Init the file manager
 	StelFileMgr::init();
 
-	QPixmap pixmap(StelFileMgr::findFile("data/splash.png"));
-	SplashScreen splash(pixmap);
-	splash.show();
-	splash.showMessage(StelUtils::getApplicationVersion() , Qt::AlignLeft, Qt::white);
-	splash.ensureFirstPaint();
+	SplashScreen::present();
 
 	// Log command line arguments.
 	QString argStr;
@@ -274,17 +273,14 @@ int main(int argc, char **argv)
 	QSettings* confSettings = Q_NULLPTR;
 	if (StelFileMgr::exists(configFileFullPath))
 	{
+		confSettings = new QSettings(configFileFullPath, StelIniFormat, Q_NULLPTR);
 		// Implement "restore default settings" feature.
 		bool restoreDefaultConfigFile = false;
 		if (CLIProcessor::argsGetOption(argList, "", "--restore-defaults"))
-		{
 			restoreDefaultConfigFile=true;
-		}
 		else
-		{
-			confSettings = new QSettings(configFileFullPath, StelIniFormat, Q_NULLPTR);
 			restoreDefaultConfigFile = confSettings->value("main/restore_defaults", false).toBool();
-		}
+
 		if (!restoreDefaultConfigFile)
 		{
 			QString version = confSettings->value("main/version", "0.0.0").toString();
@@ -313,13 +309,16 @@ int main(int argc, char **argv)
 				}
 			}
 		}
+
 		if (restoreDefaultConfigFile)
 		{
 			if (confSettings)
 				delete confSettings;
+
 			QString backupFile(configFileFullPath.left(configFileFullPath.length()-3) + QString("old"));
 			if (QFileInfo(backupFile).exists())
 				QFile(backupFile).remove();
+
 			QFile(configFileFullPath).rename(backupFile);
 			copyDefaultConfigFile(configFileFullPath);
 			confSettings = new QSettings(configFileFullPath, StelIniFormat);
@@ -344,13 +343,9 @@ int main(int argc, char **argv)
 	StelScriptOutput::init(outputFile);
 	#endif
 
-
 	// Override config file values from CLI.
 	CLIProcessor::parseCLIArgsPostConfig(argList, confSettings);
 
-	// Support hi-dpi pixmaps
-	app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);	
-
 	// Add the DejaVu font that we use everywhere in the program
 	const QString& fName = StelFileMgr::findFile("data/DejaVuSans.ttf");
 	if (!fName.isEmpty())
@@ -390,7 +385,7 @@ int main(int argc, char **argv)
 
 	StelMainView mainWin(confSettings);
 	mainWin.show();
-	splash.finish(&mainWin);
+	SplashScreen::finish(&mainWin);
 	app.exec();
 	mainWin.deinit();
 
