@@ -175,7 +175,7 @@ QString StelMainScriptAPI::getDate(const QString& spec)
 	if (spec=="utc")
 		return StelUtils::julianDayToISO8601String(getJDay());
 	else
-		return StelUtils::julianDayToISO8601String(getJDay()+StelApp::getInstance().getCore()->getUTCOffset(getJDay())/24);
+		return StelUtils::julianDayToISO8601String(getJDay()+static_cast<double>(StelApp::getInstance().getCore()->getUTCOffset(getJDay()))/24);
 }
 
 QString StelMainScriptAPI::getDeltaT()
@@ -234,17 +234,17 @@ void StelMainScriptAPI::setObserverLocation(double longitude, double latitude, d
 	StelCore* core = StelApp::getInstance().getCore();
 	StelObjectP ssObj = GETSTELMODULE(SolarSystem)->searchByName(planet);
 	StelLocation loc = core->getCurrentLocation();
-	loc.longitude = longitude;
-	loc.latitude = latitude;
+	loc.longitude = static_cast<float>(longitude);
+	loc.latitude = static_cast<float>(latitude);
 	if (altitude > -1000)
-		loc.altitude = altitude;
+		loc.altitude = qRound(altitude);
 	if (!ssObj.isNull())
 		loc.planetName = ssObj->getEnglishName();
 	loc.name = name;
 	core->moveObserverTo(loc, duration, duration);
 }
 
-void StelMainScriptAPI::setObserverLocation(const QString &id, float duration)
+void StelMainScriptAPI::setObserverLocation(const QString &id, double duration)
 {
 	StelCore* core = StelApp::getInstance().getCore();
 	StelLocation loc = StelApp::getInstance().getLocationMgr().locationForString(id);
@@ -276,7 +276,7 @@ QVariantMap StelMainScriptAPI::getObserverLocationInfo()
 	unsigned int h, m;
 	double s;
 	StelUtils::radToHms(core->getLocalSiderealTime(), h, m, s);
-	map.insert("local-sidereal-time", (double)h + (double)m/60 + s/3600);
+	map.insert("local-sidereal-time", static_cast<double>(h) + static_cast<double>(m)/60. + s/3600);
 	map.insert("local-sidereal-time-hms", StelUtils::radToHmsStr(core->getLocalSiderealTime()));
 	map.insert("location-timezone", core->getCurrentLocation().ianaTimeZone);
 	map.insert("timezone", core->getCurrentTimeZone());
@@ -290,7 +290,7 @@ void StelMainScriptAPI::setTimezone(QString tz, int markAsCustom)
 	core->setCurrentTimeZone(tz);
 	switch (markAsCustom){
 		case 0: // and
-		case 1:	core->setUseCustomTimeZone((bool) markAsCustom);
+		case 1:	core->setUseCustomTimeZone(static_cast<bool>(markAsCustom));
 			break;
 		default: break;
 	}
@@ -479,10 +479,10 @@ void StelMainScriptAPI::loadSkyImage(const QString& id, const QString& filename,
 				     double minRes, double maxBright, bool visible, const QString& frame)
 {
 	loadSkyImage(id, filename,
-		     StelUtils::getDecAngle(lon0) *180./M_PI, StelUtils::getDecAngle(lat0)*180./M_PI,
-		     StelUtils::getDecAngle(lon1) *180./M_PI, StelUtils::getDecAngle(lat1)*180./M_PI,
-		     StelUtils::getDecAngle(lon2) *180./M_PI, StelUtils::getDecAngle(lat2)*180./M_PI,
-		     StelUtils::getDecAngle(lon3) *180./M_PI, StelUtils::getDecAngle(lat3)*180./M_PI,
+		     StelUtils::getDecAngle(lon0) *M_180_PI, StelUtils::getDecAngle(lat0)*M_180_PI,
+		     StelUtils::getDecAngle(lon1) *M_180_PI, StelUtils::getDecAngle(lat1)*M_180_PI,
+		     StelUtils::getDecAngle(lon2) *M_180_PI, StelUtils::getDecAngle(lat2)*M_180_PI,
+		     StelUtils::getDecAngle(lon3) *M_180_PI, StelUtils::getDecAngle(lat3)*M_180_PI,
 		     minRes, maxBright, visible, frame);
 }
 
@@ -493,13 +493,13 @@ void StelMainScriptAPI::loadSkyImage(const QString& id, const QString& filename,
 {
 	Vec3f XYZ;
 	static const float RADIUS_NEB = 1.f;
-	StelUtils::spheToRect(lon*M_PI/180., lat*M_PI/180., XYZ);
+	StelUtils::spheToRect(static_cast<float>(lon*M_PI_180), static_cast<float>(lat*M_PI_180), XYZ);
 	XYZ*=RADIUS_NEB;
-	float texSize = RADIUS_NEB * sin(angSize/2./60.*M_PI/180.);
+	float texSize = RADIUS_NEB * static_cast<float>(sin(angSize/2./60.*M_PI_180));
 	Mat4f matPrecomp = Mat4f::translation(XYZ) *
-			   Mat4f::zrotation(lon*M_PI/180.) *
-			   Mat4f::yrotation(-lat*M_PI/180.) *
-			   Mat4f::xrotation((rotation+90.0)*M_PI/180.);
+			   Mat4f::zrotation(static_cast<float>(lon*M_PI_180)) *
+			   Mat4f::yrotation(static_cast<float>(-lat*M_PI_180)) *
+			   Mat4f::xrotation(static_cast<float>((rotation+90.0)*M_PI_180));
 
 	Vec3f corners[4];
 	corners[0] = matPrecomp * Vec3f(0.f,-texSize,-texSize);
@@ -513,10 +513,10 @@ void StelMainScriptAPI::loadSkyImage(const QString& id, const QString& filename,
 		StelUtils::rectToSphe(&cornersRaDec[i][0], &cornersRaDec[i][1], corners[i]);
 
 	loadSkyImage(id, filename,
-		     cornersRaDec[0][0]*180./M_PI, cornersRaDec[0][1]*180./M_PI,
-		     cornersRaDec[1][0]*180./M_PI, cornersRaDec[1][1]*180./M_PI,
-		     cornersRaDec[3][0]*180./M_PI, cornersRaDec[3][1]*180./M_PI,
-		     cornersRaDec[2][0]*180./M_PI, cornersRaDec[2][1]*180./M_PI,
+		     static_cast<double>(cornersRaDec[0][0])*(M_180_PI), static_cast<double>(cornersRaDec[0][1])*(M_180_PI),
+		     static_cast<double>(cornersRaDec[1][0])*(M_180_PI), static_cast<double>(cornersRaDec[1][1])*(M_180_PI),
+		     static_cast<double>(cornersRaDec[3][0])*(M_180_PI), static_cast<double>(cornersRaDec[3][1])*(M_180_PI),
+		     static_cast<double>(cornersRaDec[2][0])*(M_180_PI), static_cast<double>(cornersRaDec[2][1])*(M_180_PI),
 		     minRes, maxBright, visible, frame);
 }
 
@@ -526,8 +526,8 @@ void StelMainScriptAPI::loadSkyImage(const QString& id, const QString& filename,
 				     double angSize, double rotation,
 				     double minRes, double maxBright, bool visible, const QString &frame)
 {
-	loadSkyImage(id, filename, StelUtils::getDecAngle(lon)*180./M_PI,
-		     StelUtils::getDecAngle(lat)*180./M_PI, angSize,
+	loadSkyImage(id, filename, StelUtils::getDecAngle(lon)*M_180_PI,
+		     StelUtils::getDecAngle(lat)*M_180_PI, angSize,
 		     rotation, minRes, maxBright, visible, frame);
 }
 
@@ -832,7 +832,7 @@ double StelMainScriptAPI::jdFromDateString(const QString& dt, const QString& spe
 
 void StelMainScriptAPI::wait(double t) {
 	QEventLoop loop;
-	QTimer::singleShot(1000*t, &loop, SLOT(quit()));
+	QTimer::singleShot(qRound(1000*t), &loop, SLOT(quit()));
 	loop.exec();
 }
 
@@ -845,7 +845,7 @@ void StelMainScriptAPI::waitFor(const QString& dt, const QString& spec)
 		qDebug() << "waitFor() called with no time passing - would be infinite. Not waiting!";
 		return;
 	}
-	int interval=1000*deltaJD*86400/timeRate;
+	int interval=qRound(1000*deltaJD*86400/timeRate);
 	if (interval<=0)
 	{
 		qDebug() << "waitFor() called, but negative interval (time exceeded before starting timer). Not waiting!";
@@ -901,6 +901,24 @@ QVariantMap StelMainScriptAPI::getSelectedObjectInfo()
 	return StelObjectMgr::getObjectInfo(obj);
 }
 
+void StelMainScriptAPI::addToSelectedObjectInfoString(const QString &str, bool replace)
+{
+	StelObjectMgr* omgr = GETSTELMODULE(StelObjectMgr);
+	if (omgr->getSelectedObject().isEmpty())
+	{
+		debug("addToSelectedObjectInfoString WARNING - no object selected");
+		return;
+	}
+
+	StelObjectP obj = omgr->getSelectedObject()[0];
+	if (replace)
+		obj->setExtraInfoString(str);
+	else
+		obj->addToExtraInfoString(str);
+}
+
+
+
 void StelMainScriptAPI::clear(const QString& state)
 {
 	int stateInt = 0;
@@ -1070,6 +1088,29 @@ double StelMainScriptAPI::getViewDecJ2000Angle()
 	return dec*180/M_PI; // convert to degrees from radians
 }
 
+void StelMainScriptAPI::moveToObject(const QString& name, float duration)
+{
+	if (name.isEmpty())
+		return;
+
+	StelMovementMgr* mvmgr = GETSTELMODULE(StelMovementMgr);
+	StelObjectMgr* omgr = GETSTELMODULE(StelObjectMgr);
+	StelObjectP obj = omgr->searchByName(name);
+
+	if (!obj.isNull())
+		mvmgr->moveToObject(obj, duration);
+}
+
+void StelMainScriptAPI::moveToSelectedObject(float duration)
+{
+	StelObjectMgr* omgr = GETSTELMODULE(StelObjectMgr);
+	if (omgr->getSelectedObject().isEmpty())
+		return;
+
+	StelMovementMgr* mvmgr = GETSTELMODULE(StelMovementMgr);
+	mvmgr->moveToObject(omgr->getSelectedObject()[0], duration); // Object may be without English name
+}
+
 void StelMainScriptAPI::moveToAltAzi(const QString& alt, const QString& azi, float duration)
 {
 	StelMovementMgr* mvmgr = GETSTELMODULE(StelMovementMgr);
@@ -1247,6 +1288,24 @@ void StelMainScriptAPI::setBortleScaleIndex(int index)
 	StelApp::getInstance().getCore()->getSkyDrawer()->setBortleScaleIndex(index);
 }
 
+double StelMainScriptAPI::refraction(double altitude, bool apparent)
+{
+	Vec3d pos(1., 0., 0.);
+	// rotate to set altitude.
+	pos=Mat4d::yrotation(-altitude*M_PI_180)*pos;
+
+	const Refraction refraction=StelApp::getInstance().getCore()->getSkyDrawer()->getRefraction();
+	if (apparent)
+	{
+		refraction.backward(pos);
+	}
+	else
+	{
+		refraction.forward(pos);
+	}
+	return asin(pos[2])*M_180_PI;
+}
+
 void StelMainScriptAPI::setDSSMode(bool b)
 {
 	// TODO: This method should be removed in version 0.20
@@ -1296,7 +1355,7 @@ QString StelMainScriptAPI::getEnv(const QString &var)
 bool StelMainScriptAPI::isModuleLoaded(const QString &moduleID)
 {
 	StelModule *module= StelApp::getInstance().getModuleMgr().getModule (moduleID, true);
-	return (bool)module;
+	return module != Q_NULLPTR;
 }
 
 // return the name of platform where running Stellarium
