@@ -423,10 +423,18 @@ class Translations
 		N_("Abell Catalog of Planetary Nebulae");
 		// TRANSLATORS: Catalogue of objects (for "Lists" in the search tool)
 		N_("ESO/Uppsala Survey of the ESO(B) Atlas")
+		// TRANSLATORS: Catalogue of objects (for "Lists" in the search tool)
+		N_("Catalogue of southern stars embedded in nebulosity")
+		// TRANSLATORS: Catalogue of objects (for "Lists" in the search tool)
+		N_("Catalogue and distances of optically visible H II regions")
 		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
 		N_("Dwarf galaxies");
 		// TRANSLATORS: Catalogue of objects (for "Lists" in the search tool)
 		N_("Herschel 400 Catalogue");
+		// TRANSLATORS: Catalogue of objects (for "Lists" in the search tool)
+		N_("Jack Bennett's deep sky catalogue");
+		// TRANSLATORS: Catalogue of objects (for "Lists" in the search tool)
+		N_("James Dunlop's southern deep sky catalogue");
 		
 		// =====================================================================
 		// List of stars types
@@ -444,10 +452,14 @@ class Translations
 		// =====================================================================
 		// Constellation cultures
 		// TRANSLATORS: Name of the sky culture
+		N_("Anutan");
+		// TRANSLATORS: Name of the sky culture
 		N_("Arabic");
 		// TRANSLATORS: Name of the sky culture
 		N_("Arabic Moon Stations");
 		// TRANSLATORS: Name of the sky culture
+		N_("Armintxe");
+		// TRANSLATORS: Name of the sky culture
 		N_("Aztec");
 		// TRANSLATORS: Name of the sky culture
 		N_("Belarusian");
@@ -458,6 +470,8 @@ class Translations
 		// TRANSLATORS: Name of the sky culture
 		N_("Chinese Contemporary");
 		// TRANSLATORS: Name of the sky culture
+		N_("Chinese Medieval");
+		// TRANSLATORS: Name of the sky culture
 		N_("Egyptian");
 		// TRANSLATORS: Name of the sky culture
 		N_("Hawaiian Starlines");
@@ -478,6 +492,8 @@ class Translations
 		// TRANSLATORS: Name of the sky culture
 		N_("Maori");
 		// TRANSLATORS: Name of the sky culture
+		N_("Maya");
+		// TRANSLATORS: Name of the sky culture
 		N_("Mongolian");
 		// TRANSLATORS: Name of the sky culture
 		N_("Lokono");
@@ -511,7 +527,14 @@ class Translations
 		N_("Western (Sky & Telescope)");
 		// TRANSLATORS: Name of the sky culture
 		N_("Northern Andes");
-
+		// TRANSLATORS: Name of the sky culture
+		N_("Babylonian (MUL.APIN)");
+		// TRANSLATORS: Name of the sky culture
+		N_("Babylonian (Seleucid)");
+		// TRANSLATORS: Name of the sky culture and landscape
+		N_("Armintxe Cave");
+		// TRANSLATORS: Name of the sky culture
+		N_("Vanuatu (Netwar)");
 		
 		// =====================================================================
 		// Landscape names
@@ -586,6 +609,8 @@ class Translations
 		// TRANSLATORS: Name of script
 		N_("Constellations Tour");
 		// TRANSLATORS: Name of script
+		N_("Western Constellations Tour");
+		// TRANSLATORS: Name of script
 		N_("Sun from different planets");
 		// TRANSLATORS: Name of script
 		N_("Earth best views from other bodies");
@@ -635,6 +660,16 @@ class Translations
 		N_("Mutual occultations of planets");
 		// TRANSLATORS: Name of script
 		N_("Planet Objects Tour");
+		// TRANSLATORS: Name of script
+		N_("Analemma");
+		// TRANSLATORS: Name of script
+		N_("Martian analemma");
+		// TRANSLATORS: Name of script
+		N_("Saturnian analemma");
+		// TRANSLATORS: Name of script
+		N_("Uranian analemma");
+		// TRANSLATORS: Name of script
+		N_("Messier Marathon");
 		
 		// =====================================================================
 		// Script descriptions
@@ -657,6 +692,7 @@ class Translations
 		N_("Phobos races ahead of Mars and transits the sun, passes through it and then retrogrades back towards the sun and just partially transits it again (only seen in the southern hemisphere of Deimos), then Mars totally eclipses the sun while Phobos transits in darkness between Mars and Deimos. When Phobos emerges from Mars it is still eclipsed and dimmed in Mars' shadow, only to light up later.");
 		N_("Screensaver of various happenings in the Solar System. 300 events in all!");
 		N_("A tour of the western constellations.");
+		N_("A tour of the constellations of the selected sky culture.");
 		N_("Look at the Sun from big planets of Solar System and Pluto.");
 		N_("Best views of Earth from other Solar System bodies in the 21st Century.");
 		N_("Transit of Venus as seen from Sydney Australia, 6th June 2012.");
@@ -677,6 +713,11 @@ class Translations
 		N_("This script demonstrates interesting phenomena - occultations bright stars by planets, 2000 to 2040.");
 		N_("This script demonstrates interesting and very rare phenomena - mutual occultations of planets, 0 to 2500.");
 		N_("A tour of the Solar System planets");
+		N_("A demonstration of the analemma - the path of the Sun across the sky during the year on Earth.");
+		N_("A demonstration of the analemma - the path of the Sun across the sky during the year on Mars.");
+		N_("A demonstration of the analemma - the path of the Sun across the sky during the year on Saturn.");
+		N_("A demonstration of the analemma - the path of the Sun across the sky during the year on Uranus.");
+		N_("Messier Marathon on March 20, 2020. The data for the script are taken from GaoXing's observation log: http://www.xjltp.com/2_huodong/2_030301.htm");
 		
 		// =====================================================================
 		// List of GUI elements (Qt's dialogs)
